@@ -21,7 +21,6 @@
 #include <AppDef_MyLineTool.hxx>
 #include <AppParCurves_MultiCurve.hxx>
 #include <math_Matrix.hxx>
- 
 
 #define MultiLine AppDef_MultiLine
 #define MultiLine_hxx <AppDef_MultiLine.hxx>
@@ -29,5 +28,4 @@
 #define ToolLine_hxx <AppDef_MyLineTool.hxx>
 #define AppParCurves_ResolConstraint AppDef_ResConstraintOfMyGradientbisOfBSplineCompute
 #define AppParCurves_ResolConstraint_hxx <AppDef_ResConstraintOfMyGradientbisOfBSplineCompute.hxx>
-#include <AppParCurves_ResolConstraint.gxx>
-
+#include "../AppParCurves/AppParCurves_ResolConstraint.gxx"
