@@ -31,69 +31,73 @@
 #include <IntRes2d_IntersectionPoint.hxx>
 
 //=======================================================================
-//function : Project 
-//purpose  : Projection orthogonal d'un point sur une courbe
+// function : Project
+// purpose  : Projection orthogonal d'un point sur une courbe
 // pmn 8/10/98 : On retourne toujours une distance. (BUC60360)
 //=======================================================================
 Standard_Boolean BRepBlend_BlendTool::Project(const gp_Pnt2d& P,
                                               const Handle(Adaptor3d_Surface)&,
                                               const Handle(Adaptor2d_Curve2d)& C,
-                                              Standard_Real& Paramproj,
-                                              Standard_Real& Dist)
+                                              Standard_Real&                   Paramproj,
+                                              Standard_Real&                   Dist)
 {
-  Paramproj =  BRepBlend_HCurve2dTool::FirstParameter(C);
+  Paramproj = BRepBlend_HCurve2dTool::FirstParameter(C);
   gp_Pnt2d P2d;
   BRepBlend_HCurve2dTool::D0(C, Paramproj, P2d);
   Dist = P2d.Distance(P);
 
-  const Standard_Real t =  BRepBlend_HCurve2dTool::LastParameter(C);
+  const Standard_Real t = BRepBlend_HCurve2dTool::LastParameter(C);
   BRepBlend_HCurve2dTool::D0(C, t, P2d);
-  if (P2d.Distance(P) < Dist) {
+  if (P2d.Distance(P) < Dist)
+  {
     Paramproj = t;
-    Dist = P2d.Distance(P);
+    Dist      = P2d.Distance(P);
   }
 
-  const Standard_Real epsX = 1.e-8;
-  const Standard_Integer Nbu = 20;
-  const Standard_Real Tol = 1.e-5;
-  Extrema_EPCOfExtPC2d extrema(P, *C, Nbu, epsX, Tol);
+  const Standard_Real    epsX = 1.e-8;
+  const Standard_Integer Nbu  = 20;
+  const Standard_Real    Tol  = 1.e-5;
+  Extrema_EPCOfExtPC2d   extrema(P, *C, Nbu, epsX, Tol);
   if (!extrema.IsDone())
     return Standard_True;
 
-  const Standard_Integer Nbext = extrema.NbExt(); 
-  Standard_Real aDist2 = Dist * Dist;
-  for (Standard_Integer i=1; i<=Nbext; i++) {
-    if (extrema.SquareDistance(i) < aDist2) {
-      aDist2 = extrema.SquareDistance(i);
+  const Standard_Integer Nbext  = extrema.NbExt();
+  Standard_Real          aDist2 = Dist * Dist;
+  for (Standard_Integer i = 1; i <= Nbext; i++)
+  {
+    if (extrema.SquareDistance(i) < aDist2)
+    {
+      aDist2    = extrema.SquareDistance(i);
       Paramproj = extrema.Point(i).Parameter();
     }
   }
-  Dist = sqrt (aDist2);
+  Dist = sqrt(aDist2);
 
   return Standard_True;
 }
 
 //=======================================================================
-//function : Inters 
-//purpose  : Intersection d'un segment avec une courbe
+// function : Inters
+// purpose  : Intersection d'un segment avec une courbe
 //=======================================================================
 Standard_Boolean BRepBlend_BlendTool::Inters(const gp_Pnt2d& P1,
                                              const gp_Pnt2d& P2,
                                              const Handle(Adaptor3d_Surface)&,
                                              const Handle(Adaptor2d_Curve2d)& C,
-                                             Standard_Real& Param,
-                                             Standard_Real& Dist)
+                                             Standard_Real&                   Param,
+                                             Standard_Real&                   Dist)
 {
   const Standard_Real Tol = 1.e-8;
-  const gp_Vec2d v(P1,P2);
+  const gp_Vec2d      v(P1, P2);
   const Standard_Real mag = v.Magnitude();
-  if(mag < Tol) return Standard_False;
+  if (mag < Tol)
+    return Standard_False;
 
-  gp_Dir2d d(v);
-  Handle(Geom2d_Line) bid = new Geom2d_Line(P1,d);
-  Geom2dAdaptor_Curve seg(bid,-0.01*mag,1.01*mag);
+  gp_Dir2d            d(v);
+  Handle(Geom2d_Line) bid = new Geom2d_Line(P1, d);
+  Geom2dAdaptor_Curve seg(bid, -0.01 * mag, 1.01 * mag);
 
-  Geom2dInt_GInter inter (seg, *C, Tol, Tol);
+  Geom2dInt_GInter inter(seg, *C, Tol, Tol);
   if (!inter.IsDone())
     return Standard_False;
 
@@ -102,30 +106,28 @@ Standard_Boolean BRepBlend_BlendTool::Inters(const gp_Pnt2d& P1,
     return Standard_False;
 
   IntRes2d_IntersectionPoint ip = inter.Point(1);
-  Param = ip.ParamOnSecond();
-  Dist = P1.Distance(ip.Value());
+  Param                         = ip.ParamOnSecond();
+  Dist                          = P1.Distance(ip.Value());
   return Standard_True;
 }
 
-Standard_Integer BRepBlend_BlendTool::NbSamplesV
-  (const Handle(Adaptor3d_Surface)&,
-   const Standard_Real,
-   const Standard_Real)
+Standard_Integer BRepBlend_BlendTool::NbSamplesV(const Handle(Adaptor3d_Surface)&,
+                                                 const Standard_Real,
+                                                 const Standard_Real)
 {
   return 10;
 }
 
-Standard_Integer BRepBlend_BlendTool::NbSamplesU
-  (const Handle(Adaptor3d_Surface)&,
-   const Standard_Real,
-   const Standard_Real)
+Standard_Integer BRepBlend_BlendTool::NbSamplesU(const Handle(Adaptor3d_Surface)&,
+                                                 const Standard_Real,
+                                                 const Standard_Real)
 {
   return 10;
 }
 
 void BRepBlend_BlendTool::Bounds(const Handle(Adaptor2d_Curve2d)& A,
-                                 Standard_Real& Ufirst,
-                                 Standard_Real& Ulast)
+                                 Standard_Real&                   Ufirst,
+                                 Standard_Real&                   Ulast)
 {
   Ufirst = BRepBlend_HCurve2dTool::FirstParameter(A);
   Ulast  = BRepBlend_HCurve2dTool::LastParameter(A);
