@@ -33,15 +33,13 @@
 #include <TopTools_ListOfShape.hxx>
 #include <TopTools_MapOfShape.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(BRepCheck_Shell,BRepCheck_Result)
+IMPLEMENT_STANDARD_RTTIEXT(BRepCheck_Shell, BRepCheck_Result)
+
+//=================================================================================================
 
-//=======================================================================
-//function : Propagate
-//purpose  : 
-//=======================================================================
 static void Propagate(const TopTools_IndexedDataMapOfShapeListOfShape& mapEF,
-                      const TopoDS_Shape& theFace,
-                      TopTools_IndexedMapOfShape& theMapF)
+                      const TopoDS_Shape&                              theFace,
+                      TopTools_IndexedMapOfShape&                      theMapF)
 {
   // Base for the traverse procedure.
   theMapF.Add(theFace);
@@ -57,7 +55,7 @@ static void Propagate(const TopTools_IndexedDataMapOfShapeListOfShape& mapEF,
       // Test if the edge is in the map (only oriented edges are present).
       const TopTools_ListOfShape* aList = mapEF.Seek(edg);
 
-      if ( aList == NULL )
+      if (aList == NULL)
         continue;
 
       for (TopTools_ListIteratorOfListOfShape itl(*aList); itl.More(); itl.Next())
@@ -71,56 +69,49 @@ static void Propagate(const TopTools_IndexedDataMapOfShapeListOfShape& mapEF,
   }
 }
 
-//=======================================================================
-//function : BRepCheck_Trace
-//purpose  : 
-//=======================================================================
-Standard_EXPORT Standard_Integer BRepCheck_Trace(const Standard_Integer phase) {
+//=================================================================================================
+
+Standard_EXPORT Standard_Integer BRepCheck_Trace(const Standard_Integer phase)
+{
   static int BRC_Trace = 0;
-  if (phase < 0) BRC_Trace =0;
-  else if (phase > 0) BRC_Trace=phase;
+  if (phase < 0)
+    BRC_Trace = 0;
+  else if (phase > 0)
+    BRC_Trace = phase;
   return BRC_Trace;
 }
 
-void PrintShape(const TopoDS_Shape& theShape) {
-  if (!theShape.IsNull()) {
+void PrintShape(const TopoDS_Shape& theShape)
+{
+  if (!theShape.IsNull())
+  {
     size_t code = TopTools_ShapeMapHasher{}(theShape);
-    std::cout << TopAbs::ShapeTypeToString (theShape.ShapeType()) << " : " << code
-       << " " << TopAbs::ShapeOrientationToString(theShape.Orientation()) << std::endl;
+    std::cout << TopAbs::ShapeTypeToString(theShape.ShapeType()) << " : " << code << " "
+              << TopAbs::ShapeOrientationToString(theShape.Orientation()) << std::endl;
   }
 }
-    
-//=======================================================================
-//function : IsOriented
-//purpose  : 
-//=======================================================================
+
+//=================================================================================================
+
 inline Standard_Boolean IsOriented(const TopoDS_Shape& S)
 {
-  return (S.Orientation() == TopAbs_FORWARD ||
-	  S.Orientation() == TopAbs_REVERSED);
+  return (S.Orientation() == TopAbs_FORWARD || S.Orientation() == TopAbs_REVERSED);
 }
 
-
-//=======================================================================
-//function : BRepCheck_Shell
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 BRepCheck_Shell::BRepCheck_Shell(const TopoDS_Shell& S)
-: myNbori(0),
-  myCdone(Standard_False),
-  myCstat(BRepCheck_NoError),
-  myOdone(Standard_False),
-  myOstat(BRepCheck_NoError)
+    : myNbori(0),
+      myCdone(Standard_False),
+      myCstat(BRepCheck_NoError),
+      myOdone(Standard_False),
+      myOstat(BRepCheck_NoError)
 {
   Init(S);
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : Minimum
-//purpose  : 
-//=======================================================================
 void BRepCheck_Shell::Minimum()
 {
   myCdone = Standard_False;
@@ -129,21 +120,20 @@ void BRepCheck_Shell::Minimum()
   if (!myMin)
   {
     Handle(BRepCheck_HListOfStatus) aNewList = new BRepCheck_HListOfStatus();
-    BRepCheck_ListOfStatus& lst = **myMap.Bound(myShape, aNewList);
+    BRepCheck_ListOfStatus&         lst      = **myMap.Bound(myShape, aNewList);
 
     // it is checked if the shell is "connected"
-    TopExp_Explorer exp(myShape,TopAbs_FACE);
+    TopExp_Explorer  exp(myShape, TopAbs_FACE);
     Standard_Integer nbface = 0;
     myMapEF.Clear();
     for (; exp.More(); exp.Next())
     {
       nbface++;
       TopExp_Explorer expe;
-      for (expe.Init(exp.Current(),TopAbs_EDGE);
-                        expe.More(); expe.Next())
+      for (expe.Init(exp.Current(), TopAbs_EDGE); expe.More(); expe.Next())
       {
-        const TopoDS_Shape& edg = expe.Current();
-        Standard_Integer index = myMapEF.FindIndex(edg);
+        const TopoDS_Shape& edg   = expe.Current();
+        Standard_Integer    index = myMapEF.FindIndex(edg);
         if (index == 0)
         {
           TopTools_ListOfShape thelist1;
@@ -152,118 +142,113 @@ void BRepCheck_Shell::Minimum()
 
         myMapEF(index).Append(exp.Current());
       }
-    }//for (; exp.More(); exp.Next())
+    } // for (; exp.More(); exp.Next())
 
     if (nbface == 0)
     {
-      BRepCheck::Add(lst,BRepCheck_EmptyShell);
+      BRepCheck::Add(lst, BRepCheck_EmptyShell);
     }
     else if (nbface >= 2)
     {
       TopTools_IndexedMapOfShape mapF;
       exp.ReInit();
 
-      Propagate(myMapEF,exp.Current(),mapF);
+      Propagate(myMapEF, exp.Current(), mapF);
 
       if (mapF.Extent() != nbface)
       {
-        BRepCheck::Add(lst,BRepCheck_NotConnected);
+        BRepCheck::Add(lst, BRepCheck_NotConnected);
       }
-    }//else if (nbface >= 2)
+    } // else if (nbface >= 2)
 
     if (lst.IsEmpty())
     {
       lst.Append(BRepCheck_NoError);
     }
-    
+
     myMapEF.Clear();
     myMin = Standard_True;
   }
 }
 
-//=======================================================================
-//function : InContext
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void BRepCheck_Shell::InContext(const TopoDS_Shape& S)
 {
   Handle(BRepCheck_HListOfStatus) aHList;
   {
     Standard_Mutex::Sentry aLock(myMutex.get());
-    if (myMap.IsBound (S))
+    if (myMap.IsBound(S))
     {
       return;
     }
     Handle(BRepCheck_HListOfStatus) aNewList = new BRepCheck_HListOfStatus();
-    aHList = *myMap.Bound(S, aNewList);
+    aHList                                   = *myMap.Bound(S, aNewList);
   }
   BRepCheck_ListOfStatus& lst = *aHList;
 
   //  for (TopExp_Explorer exp(S,TopAbs_SHELL); exp.More(); exp.Next()) {
   TopExp_Explorer exp(S, TopAbs_SHELL);
-  for (; exp.More(); exp.Next()) {
-    if (exp.Current().IsSame(myShape)) {
+  for (; exp.More(); exp.Next())
+  {
+    if (exp.Current().IsSame(myShape))
+    {
       break;
     }
   }
-  if (!exp.More()) {
-    BRepCheck::Add(lst,BRepCheck_SubshapeNotInShape);
+  if (!exp.More())
+  {
+    BRepCheck::Add(lst, BRepCheck_SubshapeNotInShape);
     return;
   }
 
   TopAbs_ShapeEnum styp = S.ShapeType();
-  switch (styp) {
+  switch (styp)
+  {
 
-  case TopAbs_SOLID:
-    {
+    case TopAbs_SOLID: {
       BRepCheck_Status fst = Closed();
-      if ((fst == BRepCheck_NotClosed && S.Closed()) ||
-	  (fst != BRepCheck_NoError)) {
-	BRepCheck::Add(lst,fst);
+      if ((fst == BRepCheck_NotClosed && S.Closed()) || (fst != BRepCheck_NoError))
+      {
+        BRepCheck::Add(lst, fst);
       }
-      else if (!IsUnorientable()) {
-	fst = Orientation();
-	BRepCheck::Add(lst,fst);
+      else if (!IsUnorientable())
+      {
+        fst = Orientation();
+        BRepCheck::Add(lst, fst);
       }
     }
     break;
 
-  default:
-    break;
+    default:
+      break;
   }
 
-
-  if (lst.IsEmpty()) {
+  if (lst.IsEmpty())
+  {
     lst.Append(BRepCheck_NoError);
   }
 }
 
-
-//=======================================================================
-//function : Blind
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void BRepCheck_Shell::Blind()
 {
-  if (!myBlind) {
+  if (!myBlind)
+  {
     // nothing more than in the minimum
     myBlind = Standard_True;
   }
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : Closed
-//purpose  : 
-//=======================================================================
 BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
 {
   Handle(BRepCheck_HListOfStatus) aHList;
   {
     Standard_Mutex::Sentry aLock(myMutex.get());
-    aHList = myMap (myShape);
+    aHList = myMap(myShape);
   }
 
   BRepCheck_ListOfStatus& aStatusList = *aHList;
@@ -271,7 +256,7 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
   {
     if (Update)
     {
-      BRepCheck::Add (aStatusList, myCstat);
+      BRepCheck::Add(aStatusList, myCstat);
     }
 
     return myCstat;
@@ -279,7 +264,7 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
 
   myCdone = Standard_True; // it will be done...
 
-  BRepCheck_ListIteratorOfListOfStatus itl (aStatusList);
+  BRepCheck_ListIteratorOfListOfStatus itl(aStatusList);
   if (itl.Value() != BRepCheck_NoError)
   {
     myCstat = itl.Value();
@@ -288,27 +273,26 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
 
   myCstat = BRepCheck_NoError;
   //
-  Standard_Integer index, aNbF;
-  TopExp_Explorer exp, ede;
+  Standard_Integer           index, aNbF;
+  TopExp_Explorer            exp, ede;
   TopTools_IndexedMapOfShape mapS;
-  TopTools_MapOfShape aMEToAvoid;
+  TopTools_MapOfShape        aMEToAvoid;
   myMapEF.Clear();
-  
 
   // Checks if the oriented faces of the shell give a "closed" shell,
   // i-e if each oriented edge on oriented faces is found 2 times.
   //
-  //modified by NIZNHY-PKV Mon Jun  4 13:59:21 2007f
-  exp.Init(myShape,TopAbs_FACE);
+  // modified by NIZNHY-PKV Mon Jun  4 13:59:21 2007f
+  exp.Init(myShape, TopAbs_FACE);
   for (; exp.More(); exp.Next())
   {
-    const TopoDS_Shape& aF=exp.Current();
+    const TopoDS_Shape& aF = exp.Current();
     if (IsOriented(aF))
     {
-      ede.Init(exp.Current(),TopAbs_EDGE);
+      ede.Init(exp.Current(), TopAbs_EDGE);
       for (; ede.More(); ede.Next())
       {
-        const TopoDS_Shape& aE=ede.Current();
+        const TopoDS_Shape& aE = ede.Current();
         if (!IsOriented(aE))
         {
           aMEToAvoid.Add(aE);
@@ -316,38 +300,38 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
       }
     }
   }
-  //modified by NIZNHY-PKV Mon Jun  4 13:59:23 2007t
+  // modified by NIZNHY-PKV Mon Jun  4 13:59:23 2007t
   //
-  exp.Init(myShape,TopAbs_FACE);
+  exp.Init(myShape, TopAbs_FACE);
   for (; exp.More(); exp.Next())
   {
-    const TopoDS_Shape& aF=exp.Current();
+    const TopoDS_Shape& aF = exp.Current();
     if (IsOriented(aF))
     {
       if (!mapS.Add(aF))
       {
         myCstat = BRepCheck_RedundantFace;
-        
+
         if (Update)
         {
-          BRepCheck::Add (aStatusList, myCstat);
+          BRepCheck::Add(aStatusList, myCstat);
         }
 
         return myCstat;
       }
 
       //
-      ede.Init(exp.Current(),TopAbs_EDGE);
+      ede.Init(exp.Current(), TopAbs_EDGE);
       for (; ede.More(); ede.Next())
       {
-        const TopoDS_Shape& aE=ede.Current();
-        //modified by NIZNHY-PKV Mon Jun  4 14:07:57 2007f
-        //if (IsOriented(aE)) {
+        const TopoDS_Shape& aE = ede.Current();
+        // modified by NIZNHY-PKV Mon Jun  4 14:07:57 2007f
+        // if (IsOriented(aE)) {
         if (!aMEToAvoid.Contains(aE))
         {
-          //modified by NIZNHY-PKV Mon Jun  4 14:08:01 2007
+          // modified by NIZNHY-PKV Mon Jun  4 14:08:01 2007
           index = myMapEF.FindIndex(aE);
-          
+
           if (!index)
           {
             TopTools_ListOfShape thelist;
@@ -368,9 +352,9 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
     // Search for the first oriented face
     TopoDS_Shape aF;
     exp.Init(myShape, TopAbs_FACE);
-    for (;exp.More(); exp.Next())
+    for (; exp.More(); exp.Next())
     {
-      aF=exp.Current();
+      aF = exp.Current();
       if (IsOriented(aF))
       {
         break;
@@ -382,13 +366,13 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
   //
 
   //
-  aNbF=mapS.Extent();
+  aNbF = mapS.Extent();
   if (myNbori != aNbF)
   {
     myCstat = BRepCheck_NotConnected;
     if (Update)
     {
-      BRepCheck::Add (aStatusList, myCstat);
+      BRepCheck::Add(aStatusList, myCstat);
     }
     return myCstat;
   }
@@ -397,21 +381,21 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
   Standard_Integer i, Nbedges, nboc, nbSet;
   //
   Nbedges = myMapEF.Extent();
-  for (i = 1; i<=Nbedges; ++i)
+  for (i = 1; i <= Nbedges; ++i)
   {
     nboc = myMapEF(i).Extent();
     if (nboc == 0 || nboc >= 3)
     {
       TopTools_ListOfShape theSet;
-      nbSet=NbConnectedSet(theSet);
+      nbSet = NbConnectedSet(theSet);
       // If there is more than one closed cavity the shell is considered invalid
       // this corresponds to the criteria of a solid (not those of a shell)
-      if (nbSet>1)
+      if (nbSet > 1)
       {
         myCstat = BRepCheck_InvalidMultiConnexity;
         if (Update)
         {
-          BRepCheck::Add (aStatusList, myCstat);
+          BRepCheck::Add(aStatusList, myCstat);
         }
 
         return myCstat;
@@ -421,99 +405,107 @@ BRepCheck_Status BRepCheck_Shell::Closed(const Standard_Boolean Update)
     {
       if (!BRep_Tool::Degenerated(TopoDS::Edge(myMapEF.FindKey(i))))
       {
-        myCstat=BRepCheck_NotClosed;
+        myCstat = BRepCheck_NotClosed;
         if (Update)
         {
-          BRepCheck::Add (aStatusList ,myCstat);
+          BRepCheck::Add(aStatusList, myCstat);
         }
 
         return myCstat;
       }
     }
   }
-  
-  if (Update) {
-    BRepCheck::Add (aStatusList, myCstat);
+
+  if (Update)
+  {
+    BRepCheck::Add(aStatusList, myCstat);
   }
   return myCstat;
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : Orientation
-//purpose  :
-//=======================================================================
 BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
 {
   Handle(BRepCheck_HListOfStatus) aHList;
   {
     Standard_Mutex::Sentry aLock(myMutex.get());
-    aHList = myMap (myShape);
+    aHList = myMap(myShape);
   }
   BRepCheck_ListOfStatus& aStatusList = *aHList;
 
-  if (myOdone) {
-    if (Update) {
-      BRepCheck::Add (aStatusList, myOstat);
+  if (myOdone)
+  {
+    if (Update)
+    {
+      BRepCheck::Add(aStatusList, myOstat);
     }
     return myOstat;
   }
   myOdone = Standard_True;
 
   myOstat = Closed();
-  if (myOstat != BRepCheck_NotClosed && myOstat != BRepCheck_NoError) {
-    if (Update) {
-      BRepCheck::Add (aStatusList, myOstat);
+  if (myOstat != BRepCheck_NotClosed && myOstat != BRepCheck_NoError)
+  {
+    if (Update)
+    {
+      BRepCheck::Add(aStatusList, myOstat);
     }
     return myOstat;
   }
 
   myOstat = BRepCheck_NoError;
 
-
-// First the orientation of each face in relation to the shell is found.
-// It is used to check BRepCheck_RedundantFace
+  // First the orientation of each face in relation to the shell is found.
+  // It is used to check BRepCheck_RedundantFace
 
   TopTools_DataMapOfShapeInteger MapOfShapeOrientation;
-  TopExp_Explorer exp,ede;
+  TopExp_Explorer                exp, ede;
 
-  for (exp.Init(myShape,TopAbs_FACE); exp.More(); exp.Next()) {
-    if (!MapOfShapeOrientation.Bind(exp.Current(), (Standard_Integer)(exp.Current().Orientation()))) {
+  for (exp.Init(myShape, TopAbs_FACE); exp.More(); exp.Next())
+  {
+    if (!MapOfShapeOrientation.Bind(exp.Current(), (Standard_Integer)(exp.Current().Orientation())))
+    {
       myOstat = BRepCheck_RedundantFace;
-      if (Update) {
-	BRepCheck::Add (aStatusList, myOstat);
+      if (Update)
+      {
+        BRepCheck::Add(aStatusList, myOstat);
       }
-      else {
-	return myOstat;
+      else
+      {
+        return myOstat;
       }
     }
   }
 
 #ifdef OCCT_DEBUG
-  if (BRepCheck_Trace(0) > 1) {
+  if (BRepCheck_Trace(0) > 1)
+  {
     TopTools_DataMapIteratorOfDataMapOfShapeInteger itt(MapOfShapeOrientation);
     std::cout << "La map shape Orientation :" << std::endl;
-    for (; itt.More(); itt.Next()) {
+    for (; itt.More(); itt.Next())
+    {
       PrintShape(itt.Key());
     }
     std::cout << std::endl;
   }
 #endif
 
+  // Then the orientation of faces by their connectivity is checked
+  // BRepCheck_BadOrientationOfSubshape and
+  //         BRepCheck_SubshapeNotInShape are checked;
 
-// Then the orientation of faces by their connectivity is checked
-// BRepCheck_BadOrientationOfSubshape and 
-//         BRepCheck_SubshapeNotInShape are checked;
-
-  Standard_Integer Nbedges = myMapEF.Extent();
-  TopoDS_Face Fref;
+  Standard_Integer   Nbedges = myMapEF.Extent();
+  TopoDS_Face        Fref;
   TopAbs_Orientation orf;
 
-  for (Standard_Integer i = 1; i<= Nbedges; i++) {
+  for (Standard_Integer i = 1; i <= Nbedges; i++)
+  {
 
     const TopoDS_Edge& edg = TopoDS::Edge(myMapEF.FindKey(i));
-    if (BRep_Tool::Degenerated(edg)) continue;
-    TopTools_ListOfShape& lface = myMapEF(i);
+    if (BRep_Tool::Degenerated(edg))
+      continue;
+    TopTools_ListOfShape&              lface = myMapEF(i);
     TopTools_ListIteratorOfListOfShape lite(lface);
 
     if (lface.Extent() <= 2)
@@ -524,27 +516,27 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
       if (!MapOfShapeOrientation.IsBound(Fref))
       {
         myOstat = BRepCheck_SubshapeNotInShape;
-        if (Update) 
+        if (Update)
         {
-          BRepCheck::Add (aStatusList, myOstat);
+          BRepCheck::Add(aStatusList, myOstat);
         }
         // quit because no workaround for the incoherence is possible
         return myOstat;
       }
       lite.Next();
-      
+
       if (lite.More()) // Edge of connectivity
       {
-        //JR/Hp :
+        // JR/Hp :
         Standard_Integer iorf = MapOfShapeOrientation.Find(Fref);
-        orf = (TopAbs_Orientation) iorf;
-        //orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fref);
+        orf                   = (TopAbs_Orientation)iorf;
+        // orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fref);
         Fref.Orientation(orf);
 
         // edge is examined
         if (!lite.Value().IsSame(Fref)) // edge non "closed"
         {
-          for (ede.Init(Fref,TopAbs_EDGE); ede.More(); ede.Next())
+          for (ede.Init(Fref, TopAbs_EDGE); ede.More(); ede.Next())
           {
             if (ede.Current().IsSame(edg))
             {
@@ -552,21 +544,21 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
             }
           }
           TopAbs_Orientation orient = ede.Current().Orientation();
-          TopoDS_Face Fcur = TopoDS::Face(lite.Value());
+          TopoDS_Face        Fcur   = TopoDS::Face(lite.Value());
           if (!MapOfShapeOrientation.IsBound(Fcur))
           {
             myOstat = BRepCheck_SubshapeNotInShape;
             if (Update)
             {
-              BRepCheck::Add (aStatusList, myOstat);
+              BRepCheck::Add(aStatusList, myOstat);
             }
             // quit because no workaround for the incoherence is possible
             return myOstat;
           }
 
-          //JR/Hp :
+          // JR/Hp :
           Standard_Integer anOriFCur = MapOfShapeOrientation.Find(Fcur);
-          orf = (TopAbs_Orientation)anOriFCur;
+          orf                        = (TopAbs_Orientation)anOriFCur;
           //	orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
           Fcur.Orientation(orf);
 
@@ -579,7 +571,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
           }
           if (ede.Current().Orientation() == orient)
           {
-            // The loop is continued on the edges as many times 
+            // The loop is continued on the edges as many times
             // as the same edge is present in the wire
 
             // modified by NIZHNY-MKK  Tue Sep 30 11:11:42 2003
@@ -596,12 +588,12 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
             }
             // if (ede.Current().Orientation() == orient) {
             // modified by NIZHNY-MKK  Thu Oct  2 17:56:47 2003
-            if (!bfound || (ede.Current().Orientation() == orient)) 
+            if (!bfound || (ede.Current().Orientation() == orient))
             {
               myOstat = BRepCheck_BadOrientationOfSubshape;
-              if (Update) 
+              if (Update)
               {
-                BRepCheck::Add (aStatusList, myOstat);
+                BRepCheck::Add(aStatusList, myOstat);
                 break;
               }
               return myOstat;
@@ -610,36 +602,36 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
         }
       }
     }
-    else //more than two faces
+    else // more than two faces
     {
-      Standard_Integer numF = 0, numR = 0;
+      Standard_Integer    numF = 0, numR = 0;
       TopTools_MapOfShape Fmap;
 
       for (lite.Initialize(lface); lite.More(); lite.Next())
       {
-        TopoDS_Face Fcur= TopoDS::Face(lite.Value());
+        TopoDS_Face Fcur = TopoDS::Face(lite.Value());
         if (!MapOfShapeOrientation.IsBound(Fcur))
         {
           myOstat = BRepCheck_SubshapeNotInShape;
           if (Update)
           {
-            BRepCheck::Add (aStatusList, myOstat);
+            BRepCheck::Add(aStatusList, myOstat);
           }
           // quit because no workaround for the incoherence is possible
           return myOstat;
         }
 
         Standard_Integer iorf = MapOfShapeOrientation.Find(Fcur);
-        orf = (TopAbs_Orientation) iorf;
-        //orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
+        orf                   = (TopAbs_Orientation)iorf;
+        // orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
         Fcur.Orientation(orf);
-    
-        for (ede.Init(Fcur,TopAbs_EDGE); ede.More(); ede.Next())
-        if (ede.Current().IsSame(edg))
-        {
-          break;
-        }
-        if (Fmap.Contains(Fcur)) //edge is "closed" on Fcur, we meet Fcur twice
+
+        for (ede.Init(Fcur, TopAbs_EDGE); ede.More(); ede.Next())
+          if (ede.Current().IsSame(edg))
+          {
+            break;
+          }
+        if (Fmap.Contains(Fcur)) // edge is "closed" on Fcur, we meet Fcur twice
         {
           ede.Next();
           for (; ede.More(); ede.Next())
@@ -660,7 +652,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
           numR++;
         }
 
-        Fmap.Add (Fcur);
+        Fmap.Add(Fcur);
       }
 
       if (numF != numR)
@@ -668,7 +660,7 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
         myOstat = BRepCheck_BadOrientationOfSubshape;
         if (Update)
         {
-          BRepCheck::Add (aStatusList, myOstat);
+          BRepCheck::Add(aStatusList, myOstat);
           break;
         }
         return myOstat;
@@ -676,10 +668,11 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
     }
   }
 
-// If at least one incorrectly oriented face has been found, it is checked if the shell can be oriented. 
-//          i.e. : if by modification of the orientation of a face it is possible to find 
-//          a coherent orientation. (it is not possible on a Moebius band)
-//          BRepCheck_UnorientableShape is checked
+  // If at least one incorrectly oriented face has been found, it is checked if the shell can be
+  // oriented.
+  //          i.e. : if by modification of the orientation of a face it is possible to find
+  //          a coherent orientation. (it is not possible on a Moebius band)
+  //          BRepCheck_UnorientableShape is checked
 
   if (myOstat == BRepCheck_BadOrientationOfSubshape)
   {
@@ -687,55 +680,55 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
     {
       if (Nbedges > 0)
       {
-        TopTools_MapOfShape alre;
+        TopTools_MapOfShape  alre;
         TopTools_ListOfShape voisin;
-        voisin.Append (Fref);
+        voisin.Append(Fref);
         alre.Clear();
         while (!voisin.IsEmpty())
         {
-          Fref=TopoDS::Face (voisin.First());
+          Fref = TopoDS::Face(voisin.First());
           voisin.RemoveFirst();
-          if (!MapOfShapeOrientation.IsBound (Fref))
+          if (!MapOfShapeOrientation.IsBound(Fref))
           {
             myOstat = BRepCheck_SubshapeNotInShape;
-            if (Update) 
+            if (Update)
             {
-              BRepCheck::Add (aStatusList, myOstat);
+              BRepCheck::Add(aStatusList, myOstat);
             }
             // quit because no workaround for the incoherence is possible
             return myOstat;
           }
-//JR/Hp :
-          Standard_Integer iorf = MapOfShapeOrientation.Find(Fref) ;
-          orf = (TopAbs_Orientation) iorf ;
-//        orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fref);
+          // JR/Hp :
+          Standard_Integer iorf = MapOfShapeOrientation.Find(Fref);
+          orf                   = (TopAbs_Orientation)iorf;
+          //        orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fref);
           Fref.Orientation(orf);
 
 #ifdef OCCT_DEBUG
-  if (BRepCheck_Trace(0) > 3)
-  {
-    std::cout << "Fref : " ;
-    PrintShape(Fref);
-  }
+          if (BRepCheck_Trace(0) > 3)
+          {
+            std::cout << "Fref : ";
+            PrintShape(Fref);
+          }
 #endif
 
           TopExp_Explorer edFcur;
           alre.Add(Fref);
 
-          for (ede.Init(Fref,TopAbs_EDGE); ede.More(); ede.Next())
+          for (ede.Init(Fref, TopAbs_EDGE); ede.More(); ede.Next())
           {
-            const TopoDS_Edge& edg = TopoDS::Edge (ede.Current());
-            TopAbs_Orientation orient = edg.Orientation();
-            TopTools_ListOfShape& lface = myMapEF.ChangeFromKey (edg);
-            TopTools_ListIteratorOfListOfShape lite (lface);
+            const TopoDS_Edge&                 edg    = TopoDS::Edge(ede.Current());
+            TopAbs_Orientation                 orient = edg.Orientation();
+            TopTools_ListOfShape&              lface  = myMapEF.ChangeFromKey(edg);
+            TopTools_ListIteratorOfListOfShape lite(lface);
 
-            TopoDS_Face Fcur = TopoDS::Face (lite.Value());
+            TopoDS_Face Fcur = TopoDS::Face(lite.Value());
             if (Fcur.IsSame(Fref))
             {
               lite.Next();
               if (lite.More())
               {
-                Fcur = TopoDS::Face (lite.Value());
+                Fcur = TopoDS::Face(lite.Value());
               }
               else
               {
@@ -749,24 +742,24 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
               myOstat = BRepCheck_SubshapeNotInShape;
               if (Update)
               {
-                BRepCheck::Add (aStatusList, myOstat);
+                BRepCheck::Add(aStatusList, myOstat);
               }
               // quit because no workaround for the incoherence is possible
               return myOstat;
             }
 
-//JR/Hp :
-            Standard_Integer anOriFCur = MapOfShapeOrientation.Find(Fcur) ;
-            orf = (TopAbs_Orientation)anOriFCur;
-//          orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
+            // JR/Hp :
+            Standard_Integer anOriFCur = MapOfShapeOrientation.Find(Fcur);
+            orf                        = (TopAbs_Orientation)anOriFCur;
+            //          orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
             Fcur.Orientation(orf);
 
 #ifdef OCCT_DEBUG
-  if (BRepCheck_Trace(0) > 3)
-  {
-    std::cout << "    Fcur : " ;
-    PrintShape(Fcur);
-  }
+            if (BRepCheck_Trace(0) > 3)
+            {
+              std::cout << "    Fcur : ";
+              PrintShape(Fcur);
+            }
 #endif
             for (edFcur.Init(Fcur, TopAbs_EDGE); edFcur.More(); edFcur.Next())
             {
@@ -784,38 +777,37 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
                 myOstat = BRepCheck_UnorientableShape;
                 if (Update)
                 {
-                  BRepCheck::Add (aStatusList, myOstat);
+                  BRepCheck::Add(aStatusList, myOstat);
                 }
                 // quit, otherwise there is a risk of taking too much time.
 #ifdef OCCT_DEBUG
-  if (BRepCheck_Trace(0) > 3) {
-    orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
-    Fcur.Orientation(orf);
-    std::cout << "    Error : this face has been already examined " << std::endl;
-    std::cout << "    Impossible to return it ";
-    PrintShape(Fcur);
-  }
+                if (BRepCheck_Trace(0) > 3)
+                {
+                  orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
+                  Fcur.Orientation(orf);
+                  std::cout << "    Error : this face has been already examined " << std::endl;
+                  std::cout << "    Impossible to return it ";
+                  PrintShape(Fcur);
+                }
 #endif
                 return myOstat;
               }
-              orf = TopAbs::Reverse(orf);
-              MapOfShapeOrientation(Fcur)=orf;
-
+              orf                         = TopAbs::Reverse(orf);
+              MapOfShapeOrientation(Fcur) = orf;
 
 #ifdef OCCT_DEBUG
-  if (BRepCheck_Trace(0) > 3)
-  {
-    orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
-    Fcur.Orientation(orf);
-    std::cout << "    Resulting Fcur is returned : " ;
-    PrintShape(Fcur);
-  }
+              if (BRepCheck_Trace(0) > 3)
+              {
+                orf = (TopAbs_Orientation)MapOfShapeOrientation.Find(Fcur);
+                Fcur.Orientation(orf);
+                std::cout << "    Resulting Fcur is returned : ";
+                PrintShape(Fcur);
+              }
 #endif
-
             }
-            if (alre.Add (Fcur))
+            if (alre.Add(Fcur))
             {
-              voisin.Append (Fcur);
+              voisin.Append(Fcur);
             }
           }
         }
@@ -823,27 +815,23 @@ BRepCheck_Status BRepCheck_Shell::Orientation(const Standard_Boolean Update)
     }
   }
 
-  if (Update) 
+  if (Update)
   {
-    BRepCheck::Add (aStatusList, myOstat);
+    BRepCheck::Add(aStatusList, myOstat);
   }
   return myOstat;
 }
 
-//=======================================================================
-//function : SetUnorientable
-//purpose  :
-//=======================================================================
+//=================================================================================================
+
 void BRepCheck_Shell::SetUnorientable()
 {
   Standard_Mutex::Sentry aLock(myMutex.get());
-  BRepCheck::Add (*myMap (myShape), BRepCheck_UnorientableShape);
+  BRepCheck::Add(*myMap(myShape), BRepCheck_UnorientableShape);
 }
 
-//=======================================================================
-//function : IsUnorientable
-//purpose  :
-//=======================================================================
+//=================================================================================================
+
 Standard_Boolean BRepCheck_Shell::IsUnorientable() const
 {
   if (myOdone)
@@ -854,7 +842,7 @@ Standard_Boolean BRepCheck_Shell::IsUnorientable() const
   Handle(BRepCheck_HListOfStatus) aHList;
   {
     Standard_Mutex::Sentry aLock(myMutex.get());
-    aHList = myMap (myShape);
+    aHList = myMap(myShape);
   }
   BRepCheck_ListOfStatus& aStatusList = *aHList;
 
@@ -868,82 +856,97 @@ Standard_Boolean BRepCheck_Shell::IsUnorientable() const
   return Standard_False;
 }
 
-//=======================================================================
-//function : NbConnectedSet
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 Standard_Integer BRepCheck_Shell::NbConnectedSet(TopTools_ListOfShape& theSets)
 {
-  // The connections are found 
+  // The connections are found
   TopTools_IndexedDataMapOfShapeListOfShape parents;
   TopExp::MapShapesAndAncestors(myShape, TopAbs_EDGE, TopAbs_FACE, parents);
   // All faces are taken
   TopTools_MapOfShape theFaces;
-  TopExp_Explorer exsh(myShape, TopAbs_FACE);
-  for (; exsh.More(); exsh.Next()) theFaces.Add(exsh.Current());
+  TopExp_Explorer     exsh(myShape, TopAbs_FACE);
+  for (; exsh.More(); exsh.Next())
+    theFaces.Add(exsh.Current());
   // The edges that are not oriented or have more than 2 connections are missing
-  Standard_Integer iCur;
+  Standard_Integer    iCur;
   TopTools_MapOfShape theMultiEd;
   TopTools_MapOfShape theUnOriEd;
-  for (iCur=1; iCur<=parents.Extent(); iCur++) {
+  for (iCur = 1; iCur <= parents.Extent(); iCur++)
+  {
     const TopoDS_Edge& Ed = TopoDS::Edge(parents.FindKey(iCur));
-    if (parents(iCur).Extent()> 2) theMultiEd.Add(Ed);
-    if (Ed.Orientation()!=TopAbs_REVERSED &&
-	Ed.Orientation()!=TopAbs_FORWARD) theUnOriEd.Add(Ed);
+    if (parents(iCur).Extent() > 2)
+      theMultiEd.Add(Ed);
+    if (Ed.Orientation() != TopAbs_REVERSED && Ed.Orientation() != TopAbs_FORWARD)
+      theUnOriEd.Add(Ed);
   }
   // Starting from multiconnected edges propagation by simple connections
   TopTools_ListIteratorOfListOfShape lconx1, lconx2;
-  TopTools_MapIteratorOfMapOfShape itmsh(theMultiEd);
-  TopoDS_Shell CurShell;
-  TopoDS_Shape adFac;
-  TopTools_ListOfShape lesCur;
-  BRep_Builder BRB;
-  Standard_Boolean newCur=Standard_True;
+  TopTools_MapIteratorOfMapOfShape   itmsh(theMultiEd);
+  TopoDS_Shell                       CurShell;
+  TopoDS_Shape                       adFac;
+  TopTools_ListOfShape               lesCur;
+  BRep_Builder                       BRB;
+  Standard_Boolean                   newCur = Standard_True;
   BRB.MakeShell(CurShell);
-  for (; itmsh.More(); itmsh.Next()) {
+  for (; itmsh.More(); itmsh.Next())
+  {
     const TopoDS_Shape& Ed = itmsh.Key();
-    if (!theUnOriEd.Contains(Ed)) {
-      for (lconx1.Initialize(parents.FindFromKey(Ed)); lconx1.More(); lconx1.Next()) {
-	if (theFaces.Contains(lconx1.Value())) {
-	  adFac=lconx1.Value();
-	  BRB.Add(CurShell, adFac);
-	  theFaces.Remove(adFac);
-	  newCur=Standard_False;
-	  if (theFaces.IsEmpty()) break;
-	  lesCur.Append(adFac);
-	  while (!lesCur.IsEmpty()) {
-	    adFac=lesCur.First();
-	    lesCur.RemoveFirst();
-	    for (exsh.Init(adFac, TopAbs_EDGE); exsh.More(); exsh.Next()) {
-	      const TopoDS_Shape& ced = exsh.Current();
-	      if (!theMultiEd.Contains(ced)) {
-		for (lconx2.Initialize(parents.FindFromKey(ced)); lconx2.More(); lconx2.Next()) {
-		  if (theFaces.Contains(lconx2.Value())) {
-		    adFac=lconx2.Value();
-		    BRB.Add(CurShell, adFac);
-		    theFaces.Remove(adFac);
-		    newCur=Standard_False;
-		    if (theFaces.IsEmpty()) break;
-		    lesCur.Append(adFac);
-		  }
-		}
-	      }
-	      if (theFaces.IsEmpty()) break;
-	    }
-	  }
-	  if (!newCur) {
-            CurShell.Closed (BRep_Tool::IsClosed (CurShell));
+    if (!theUnOriEd.Contains(Ed))
+    {
+      for (lconx1.Initialize(parents.FindFromKey(Ed)); lconx1.More(); lconx1.Next())
+      {
+        if (theFaces.Contains(lconx1.Value()))
+        {
+          adFac = lconx1.Value();
+          BRB.Add(CurShell, adFac);
+          theFaces.Remove(adFac);
+          newCur = Standard_False;
+          if (theFaces.IsEmpty())
+            break;
+          lesCur.Append(adFac);
+          while (!lesCur.IsEmpty())
+          {
+            adFac = lesCur.First();
+            lesCur.RemoveFirst();
+            for (exsh.Init(adFac, TopAbs_EDGE); exsh.More(); exsh.Next())
+            {
+              const TopoDS_Shape& ced = exsh.Current();
+              if (!theMultiEd.Contains(ced))
+              {
+                for (lconx2.Initialize(parents.FindFromKey(ced)); lconx2.More(); lconx2.Next())
+                {
+                  if (theFaces.Contains(lconx2.Value()))
+                  {
+                    adFac = lconx2.Value();
+                    BRB.Add(CurShell, adFac);
+                    theFaces.Remove(adFac);
+                    newCur = Standard_False;
+                    if (theFaces.IsEmpty())
+                      break;
+                    lesCur.Append(adFac);
+                  }
+                }
+              }
+              if (theFaces.IsEmpty())
+                break;
+            }
+          }
+          if (!newCur)
+          {
+            CurShell.Closed(BRep_Tool::IsClosed(CurShell));
             theSets.Append(CurShell);
             CurShell.Nullify();
-            newCur=Standard_True;
+            newCur = Standard_True;
             BRB.MakeShell(CurShell);
-	  }
-	}
-	if (theFaces.IsEmpty()) break;
+          }
+        }
+        if (theFaces.IsEmpty())
+          break;
       }
     }
-    if (theFaces.IsEmpty()) break;
+    if (theFaces.IsEmpty())
+      break;
   }
   return theSets.Extent();
 }
