@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <BRep_Tool.hxx>
 #include <BRepAlgoAPI_Cut.hxx>
 #include <BRepAlgoAPI_Fuse.hxx>
@@ -37,54 +36,55 @@ extern Standard_Boolean BRepFeat_GettraceFEAT();
 #endif
 
 static void MajMap(const TopoDS_Shape&, // base
-		   LocOpe_Pipe&,
-		   TopTools_DataMapOfShapeListOfShape&, // myMap
-		   TopoDS_Shape&,  // myFShape
-		   TopoDS_Shape&); // myLShape
+                   LocOpe_Pipe&,
+                   TopTools_DataMapOfShapeListOfShape&, // myMap
+                   TopoDS_Shape&,                       // myFShape
+                   TopoDS_Shape&);                      // myLShape
 
-//=======================================================================
-//function : Init
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
-void BRepFeat_MakePipe::Init(const TopoDS_Shape& Sbase,
-			     const TopoDS_Shape& Pbase,
-			     const TopoDS_Face& Skface,
-			     const TopoDS_Wire& Spine,
-			     const Standard_Integer Mode,
-			     const Standard_Boolean Modify)
+void BRepFeat_MakePipe::Init(const TopoDS_Shape&    Sbase,
+                             const TopoDS_Shape&    Pbase,
+                             const TopoDS_Face&     Skface,
+                             const TopoDS_Wire&     Spine,
+                             const Standard_Integer Mode,
+                             const Standard_Boolean Modify)
 {
 #ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
-  if (trc) std::cout << "BRepFeat_MakePipe::Init" << std::endl;
+  if (trc)
+    std::cout << "BRepFeat_MakePipe::Init" << std::endl;
 #endif
-  mySbase  = Sbase;
+  mySbase = Sbase;
   BasisShapeValid();
   mySkface = Skface;
   SketchFaceValid();
-  myPbase  = Pbase;
+  myPbase = Pbase;
   mySlface.Clear();
-  mySpine   = Spine;
-  if(Mode == 0) {
-    myFuse   = Standard_False;
+  mySpine = Spine;
+  if (Mode == 0)
+  {
+    myFuse     = Standard_False;
     myJustFeat = Standard_False;
   }
-  else if(Mode == 1) {
-    myFuse   = Standard_True;
+  else if (Mode == 1)
+  {
+    myFuse     = Standard_True;
     myJustFeat = Standard_False;
   }
-  else if(Mode == 2) {
-    myFuse   = Standard_True;
+  else if (Mode == 2)
+  {
+    myFuse     = Standard_True;
     myJustFeat = Standard_True;
   }
-  else {    
+  else
+  {
   }
-  myModify = Modify;
+  myModify    = Modify;
   myJustGluer = Standard_False;
 
-
   //-------------- ifv
-  //mySkface.Nullify();
+  // mySkface.Nullify();
   //-------------- ifv
 
   myShape.Nullify();
@@ -92,79 +92,91 @@ void BRepFeat_MakePipe::Init(const TopoDS_Shape& Sbase,
   myFShape.Nullify();
   myLShape.Nullify();
   TopExp_Explorer exp;
-  for (exp.Init(mySbase,TopAbs_FACE);exp.More();exp.Next()) {
+  for (exp.Init(mySbase, TopAbs_FACE); exp.More(); exp.Next())
+  {
     TopTools_ListOfShape thelist;
     myMap.Bind(exp.Current(), thelist);
     myMap(exp.Current()).Append(exp.Current());
   }
 #ifdef OCCT_DEBUG
-  if (trc) {
-    if (myJustFeat)  std::cout << " Just Feature" << std::endl;
-    if (myFuse)  std::cout << " Fuse" << std::endl;
-    if (!myFuse)  std::cout << " Cut" << std::endl;
-    if (!myModify) std::cout << " Modify = 0" << std::endl;
+  if (trc)
+  {
+    if (myJustFeat)
+      std::cout << " Just Feature" << std::endl;
+    if (myFuse)
+      std::cout << " Fuse" << std::endl;
+    if (!myFuse)
+      std::cout << " Cut" << std::endl;
+    if (!myModify)
+      std::cout << " Modify = 0" << std::endl;
   }
-#endif 
+#endif
 }
 
-
 //=======================================================================
-//function : Add
-//purpose  : add faces of gluing
+// function : Add
+// purpose  : add faces of gluing
 //=======================================================================
 
-void BRepFeat_MakePipe::Add(const TopoDS_Edge& E,
-			     const TopoDS_Face& F)
+void BRepFeat_MakePipe::Add(const TopoDS_Edge& E, const TopoDS_Face& F)
 {
 #ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
-  if (trc) std::cout << "BRepFeat_MakePipe::Add(Edge,face)" << std::endl;
+  if (trc)
+    std::cout << "BRepFeat_MakePipe::Add(Edge,face)" << std::endl;
 #endif
   TopExp_Explorer exp;
-  for (exp.Init(mySbase,TopAbs_FACE);exp.More();exp.Next()) {
-    if (exp.Current().IsSame(F)) {
+  for (exp.Init(mySbase, TopAbs_FACE); exp.More(); exp.Next())
+  {
+    if (exp.Current().IsSame(F))
+    {
       break;
     }
   }
-  if (!exp.More()) {
+  if (!exp.More())
+  {
     throw Standard_ConstructionError();
   }
 
-  for (exp.Init(myPbase,TopAbs_EDGE);exp.More();exp.Next()) {
-    if (exp.Current().IsSame(E)) {
+  for (exp.Init(myPbase, TopAbs_EDGE); exp.More(); exp.Next())
+  {
+    if (exp.Current().IsSame(E))
+    {
       break;
     }
   }
-  if (!exp.More()) {
+  if (!exp.More())
+  {
     throw Standard_ConstructionError();
   }
 
-  if (!mySlface.IsBound(F)) {
+  if (!mySlface.IsBound(F))
+  {
     TopTools_ListOfShape thelist1;
-    mySlface.Bind(F,thelist1);
+    mySlface.Bind(F, thelist1);
   }
   TopTools_ListIteratorOfListOfShape itl(mySlface(F));
-  for (; itl.More();itl.Next()) {
-    if (itl.Value().IsSame(E)) {
+  for (; itl.More(); itl.Next())
+  {
+    if (itl.Value().IsSame(E))
+    {
       break;
     }
   }
-  if (!itl.More()) {
+  if (!itl.More())
+  {
     mySlface(F).Append(E);
   }
 }
 
-
-//=======================================================================
-//function : Perform
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void BRepFeat_MakePipe::Perform()
 {
 #ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
-  if (trc) std::cout << "BRepFeat_MakePipe::Perform()" << std::endl;
+  if (trc)
+    std::cout << "BRepFeat_MakePipe::Perform()" << std::endl;
 #endif
   mySFrom.Nullify();
   ShapeFromValid();
@@ -174,59 +186,66 @@ void BRepFeat_MakePipe::Perform()
   myPerfSelection = BRepFeat_NoSelection;
   PerfSelectionValid();
   TopoDS_Shape theBase = myPbase;
-  LocOpe_Pipe thePipe(mySpine,theBase);
+  LocOpe_Pipe  thePipe(mySpine, theBase);
   TopoDS_Shape VraiPipe = thePipe.Shape();
-  MajMap(myPbase,thePipe,myMap,myFShape,myLShape);
+  MajMap(myPbase, thePipe, myMap, myFShape, myLShape);
   myGShape = VraiPipe;
   GeneratedShapeValid();
 
   GluedFacesValid();
 
-  if(myGluedF.IsEmpty()) {
-    if(myFuse == 1) {
+  if (myGluedF.IsEmpty())
+  {
+    if (myFuse == 1)
+    {
       BRepAlgoAPI_Fuse f(mySbase, myGShape);
       myShape = f.Shape();
       UpdateDescendants(f, myShape, Standard_False);
       Done();
     }
-    else if(myFuse == 0) {
+    else if (myFuse == 0)
+    {
       BRepAlgoAPI_Cut c(mySbase, myGShape);
       myShape = c.Shape();
       UpdateDescendants(c, myShape, Standard_False);
       Done();
     }
-    else {
+    else
+    {
       myShape = myGShape;
       Done();
     }
   }
-  else {
+  else
+  {
     myFShape = thePipe.FirstShape();
     TColgp_SequenceOfPnt spt;
-    LocOpe::SampleEdges(myFShape,spt); 
+    LocOpe::SampleEdges(myFShape, spt);
     myCurves = thePipe.Curves(spt);
     myBCurve = thePipe.BarycCurve();
     GlobalPerform();
   }
 }
 
-
 //=======================================================================
-//function : Perform
-//purpose  : till shape Until
+// function : Perform
+// purpose  : till shape Until
 //=======================================================================
 
 void BRepFeat_MakePipe::Perform(const TopoDS_Shape& Until)
 {
 #ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
-  if (trc) std::cout << "BRepFeat_MakePipe::Perform(Until)" << std::endl;
+  if (trc)
+    std::cout << "BRepFeat_MakePipe::Perform(Until)" << std::endl;
 #endif
-  if (Until.IsNull()) {
+  if (Until.IsNull())
+  {
     throw Standard_ConstructionError();
   }
   TopExp_Explorer exp(Until, TopAbs_FACE);
-  if (!exp.More()) {
+  if (!exp.More())
+  {
     throw Standard_ConstructionError();
   }
   myGluedF.Clear();
@@ -237,9 +256,9 @@ void BRepFeat_MakePipe::Perform(const TopoDS_Shape& Until)
   mySUntil = Until;
   TransformShapeFU(1);
   ShapeUntilValid();
-  LocOpe_Pipe thePipe(mySpine,myPbase);
+  LocOpe_Pipe  thePipe(mySpine, myPbase);
   TopoDS_Shape VraiTuyau = thePipe.Shape();
-  MajMap(myPbase,thePipe,myMap,myFShape,myLShape);
+  MajMap(myPbase, thePipe, myMap, myFShape, myLShape);
   myGShape = VraiTuyau;
   GeneratedShapeValid();
 
@@ -247,34 +266,37 @@ void BRepFeat_MakePipe::Perform(const TopoDS_Shape& Until)
 
   myFShape = thePipe.FirstShape();
   TColgp_SequenceOfPnt spt;
-  LocOpe::SampleEdges(myFShape,spt); 
+  LocOpe::SampleEdges(myFShape, spt);
   myCurves = thePipe.Curves(spt);
   myBCurve = thePipe.BarycCurve();
   GlobalPerform();
 }
 
-
 //=======================================================================
-//function : Perform
-//purpose  : between From and Until
+// function : Perform
+// purpose  : between From and Until
 //=======================================================================
 
-void BRepFeat_MakePipe::Perform(const TopoDS_Shape& From,
-				const TopoDS_Shape& Until)
+void BRepFeat_MakePipe::Perform(const TopoDS_Shape& From, const TopoDS_Shape& Until)
 {
 #ifdef OCCT_DEBUG
   Standard_Boolean trc = BRepFeat_GettraceFEAT();
-  if (trc) std::cout << "BRepFeat_MakePipe::Perform(From,Until)" << std::endl;
+  if (trc)
+    std::cout << "BRepFeat_MakePipe::Perform(From,Until)" << std::endl;
 #endif
-  if (From.IsNull() || Until.IsNull()) {
+  if (From.IsNull() || Until.IsNull())
+  {
     throw Standard_ConstructionError();
   }
-  if (!mySkface.IsNull()) {
-    if (From.IsSame(mySkface)) {
+  if (!mySkface.IsNull())
+  {
+    if (From.IsSame(mySkface))
+    {
       Perform(Until);
       return;
     }
-    else if (Until.IsSame(mySkface)) {
+    else if (Until.IsSame(mySkface))
+    {
       Perform(From);
       return;
     }
@@ -283,11 +305,13 @@ void BRepFeat_MakePipe::Perform(const TopoDS_Shape& From,
   myPerfSelection = BRepFeat_SelectionFU;
   PerfSelectionValid();
   TopExp_Explorer exp(From, TopAbs_FACE);
-  if (!exp.More()) {
+  if (!exp.More())
+  {
     throw Standard_ConstructionError();
   }
   exp.Init(Until, TopAbs_FACE);
-  if (!exp.More()) {
+  if (!exp.More())
+  {
     throw Standard_ConstructionError();
   }
   mySFrom = From;
@@ -295,28 +319,27 @@ void BRepFeat_MakePipe::Perform(const TopoDS_Shape& From,
   ShapeFromValid();
   mySUntil = Until;
   TransformShapeFU(1);
-  ShapeUntilValid();  
-  LocOpe_Pipe thePipe(mySpine,myPbase);
+  ShapeUntilValid();
+  LocOpe_Pipe  thePipe(mySpine, myPbase);
   TopoDS_Shape VraiTuyau = thePipe.Shape();
-  MajMap(myPbase,thePipe,myMap,myFShape,myLShape);
+  MajMap(myPbase, thePipe, myMap, myFShape, myLShape);
   myGShape = VraiTuyau;
   GeneratedShapeValid();
 
-	//	mySbase, myPbase, mySlface, thePipe, myGluedF);
+  //	mySbase, myPbase, mySlface, thePipe, myGluedF);
   GluedFacesValid();
 
   myFShape = thePipe.FirstShape();
   TColgp_SequenceOfPnt spt;
-  LocOpe::SampleEdges(myFShape,spt); 
+  LocOpe::SampleEdges(myFShape, spt);
   myCurves = thePipe.Curves(spt);
   myBCurve = thePipe.BarycCurve();
   GlobalPerform();
 }
 
-
 //=======================================================================
-//function : Curves
-//purpose  : curves parallel to the generating wire of the pipe
+// function : Curves
+// purpose  : curves parallel to the generating wire of the pipe
 //=======================================================================
 
 void BRepFeat_MakePipe::Curves(TColGeom_SequenceOfCurve& scur)
@@ -325,8 +348,8 @@ void BRepFeat_MakePipe::Curves(TColGeom_SequenceOfCurve& scur)
 }
 
 //=======================================================================
-//function : BarycCurve
-//purpose  : pass through the center of mass
+// function : BarycCurve
+// purpose  : pass through the center of mass
 //=======================================================================
 
 Handle(Geom_Curve) BRepFeat_MakePipe::BarycCurve()
@@ -335,55 +358,47 @@ Handle(Geom_Curve) BRepFeat_MakePipe::BarycCurve()
 }
 
 //=======================================================================
-//function : MajMap
-//purpose  : management of descendants
+// function : MajMap
+// purpose  : management of descendants
 //=======================================================================
 
-static void MajMap(const TopoDS_Shape& theB,
-		   LocOpe_Pipe& theP,
-		   TopTools_DataMapOfShapeListOfShape& theMap, // myMap
-		   TopoDS_Shape& theFShape,  // myFShape
-		   TopoDS_Shape& theLShape) // myLShape
+static void MajMap(const TopoDS_Shape&                 theB,
+                   LocOpe_Pipe&                        theP,
+                   TopTools_DataMapOfShapeListOfShape& theMap,    // myMap
+                   TopoDS_Shape&                       theFShape, // myFShape
+                   TopoDS_Shape&                       theLShape)                       // myLShape
 {
-  TopExp_Explorer exp(theP.FirstShape(),TopAbs_WIRE);
-  if (exp.More()) {
+  TopExp_Explorer exp(theP.FirstShape(), TopAbs_WIRE);
+  if (exp.More())
+  {
     theFShape = exp.Current();
     TopTools_ListOfShape thelist2;
     theMap.Bind(theFShape, thelist2);
-    for (exp.Init(theP.FirstShape(),TopAbs_FACE);exp.More();exp.Next()) {
+    for (exp.Init(theP.FirstShape(), TopAbs_FACE); exp.More(); exp.Next())
+    {
       theMap(theFShape).Append(exp.Current());
     }
   }
-  
-  exp.Init(theP.LastShape(),TopAbs_WIRE);
-  if (exp.More()) {
+
+  exp.Init(theP.LastShape(), TopAbs_WIRE);
+  if (exp.More())
+  {
     theLShape = exp.Current();
     TopTools_ListOfShape thelist3;
     theMap.Bind(theLShape, thelist3);
-    for (exp.Init(theP.LastShape(),TopAbs_FACE);exp.More();exp.Next()) {
+    for (exp.Init(theP.LastShape(), TopAbs_FACE); exp.More(); exp.Next())
+    {
       theMap(theLShape).Append(exp.Current());
     }
   }
 
-  for (exp.Init(theB,TopAbs_EDGE); exp.More(); exp.Next()) {
-    if (!theMap.IsBound(exp.Current())) {
+  for (exp.Init(theB, TopAbs_EDGE); exp.More(); exp.Next())
+  {
+    if (!theMap.IsBound(exp.Current()))
+    {
       TopTools_ListOfShape thelist4;
       theMap.Bind(exp.Current(), thelist4);
       theMap(exp.Current()) = theP.Shapes(exp.Current());
     }
   }
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
