@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <BRep_Tool.hxx>
 #include <BRepAdaptor_Surface.hxx>
 #include <BRepFill_CurveConstraint.hxx>
@@ -26,43 +25,45 @@
 #include <ProjLib_ProjectOnPlane.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(BRepFill_CurveConstraint,GeomPlate_CurveConstraint)
+IMPLEMENT_STANDARD_RTTIEXT(BRepFill_CurveConstraint, GeomPlate_CurveConstraint)
 
 //---------------------------------------------------------
 //         Constructeurs avec courbe sur surface
 //---------------------------------------------------------
-BRepFill_CurveConstraint :: BRepFill_CurveConstraint (const Handle(Adaptor3d_CurveOnSurface)& Boundary,
-						const Standard_Integer Tang,
-						const Standard_Integer NPt,
-						const Standard_Real TolDist,
-						const Standard_Real TolAng,
-						const Standard_Real TolCurv
-)
-{ 
-  myFrontiere=Boundary;
-  myTolDist=TolDist;
-  myTolAng=TolAng;
-  myTolCurv=TolCurv;
-  GeomLProp_SLProps SLP(2,TolDist);
-  myLProp=SLP;
-  myOrder=Tang;
-  if ((Tang<-1)||(Tang>2))
+BRepFill_CurveConstraint ::BRepFill_CurveConstraint(
+  const Handle(Adaptor3d_CurveOnSurface)& Boundary,
+  const Standard_Integer                  Tang,
+  const Standard_Integer                  NPt,
+  const Standard_Real                     TolDist,
+  const Standard_Real                     TolAng,
+  const Standard_Real                     TolCurv)
+{
+  myFrontiere = Boundary;
+  myTolDist   = TolDist;
+  myTolAng    = TolAng;
+  myTolCurv   = TolCurv;
+  GeomLProp_SLProps SLP(2, TolDist);
+  myLProp = SLP;
+  myOrder = Tang;
+  if ((Tang < -1) || (Tang > 2))
     throw Standard_Failure("BRepFill : The continuity is not G0 G1 or G2");
-  myNbPoints=NPt;
-myConstG0=Standard_True;
-myConstG1=Standard_True;
-myConstG2=Standard_True;
- if (myFrontiere.IsNull())
+  myNbPoints = NPt;
+  myConstG0  = Standard_True;
+  myConstG1  = Standard_True;
+  myConstG2  = Standard_True;
+  if (myFrontiere.IsNull())
     throw Standard_Failure("BRepFill_CurveConstraint : Curve must be on a Surface");
-  Handle(Geom_Surface) Surf;
+  Handle(Geom_Surface)        Surf;
   Handle(GeomAdaptor_Surface) GS1;
   GS1 = Handle(GeomAdaptor_Surface)::DownCast(myFrontiere->GetSurface());
-  if (!GS1.IsNull()) {
+  if (!GS1.IsNull())
+  {
     Surf = GS1->Surface();
   }
-  else {
+  else
+  {
     Handle(BRepAdaptor_Surface) BS1;
-    BS1=Handle(BRepAdaptor_Surface)::DownCast(myFrontiere->GetSurface());
+    BS1  = Handle(BRepAdaptor_Surface)::DownCast(myFrontiere->GetSurface());
     Surf = BRep_Tool::Surface(BS1->Face());
   }
   myLProp.SetSurface(Surf);
@@ -71,16 +72,11 @@ myConstG2=Standard_True;
 //---------------------------------------------------------
 //    Constructeurs avec courbe 3d (pour continuite G0 G-1)
 //---------------------------------------------------------
-BRepFill_CurveConstraint :: BRepFill_CurveConstraint (const Handle(Adaptor3d_Curve)& Boundary,
-						const Standard_Integer Tang, 
-						const Standard_Integer NPt,
-						const Standard_Real TolDist) 
-: GeomPlate_CurveConstraint(Boundary,Tang,NPt,TolDist)
+BRepFill_CurveConstraint ::BRepFill_CurveConstraint(const Handle(Adaptor3d_Curve)& Boundary,
+                                                    const Standard_Integer         Tang,
+                                                    const Standard_Integer         NPt,
+                                                    const Standard_Real            TolDist)
+    : GeomPlate_CurveConstraint(Boundary, Tang, NPt, TolDist)
 
-{ 
+{
 }
-
-
-
-
-
