@@ -14,38 +14,23 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <BRepSweep_Iterator.hxx>
 #include <TopoDS_Shape.hxx>
 
-//=======================================================================
-//function : BRepSweep_Iterator
-//purpose  : 
-//=======================================================================
-BRepSweep_Iterator::BRepSweep_Iterator()
-{
-}
+//=================================================================================================
 
+BRepSweep_Iterator::BRepSweep_Iterator() {}
 
-//=======================================================================
-//function : Init
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
-void  BRepSweep_Iterator::Init(const TopoDS_Shape& aShape)
+void BRepSweep_Iterator::Init(const TopoDS_Shape& aShape)
 {
   myIterator.Initialize(aShape);
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : Next
-//purpose  : 
-//=======================================================================
-
-void  BRepSweep_Iterator::Next()
+void BRepSweep_Iterator::Next()
 {
   myIterator.Next();
 }
-
-
