@@ -21,8 +21,8 @@
 #include <BRepTest.hxx>
 
 //=======================================================================
-//function : prj
-//purpose  : Draw command for Conical and Cylindrical projection
+// function : prj
+// purpose  : Draw command for Conical and Cylindrical projection
 //=======================================================================
 static Standard_Integer prj(Draw_Interpretor& di, Standard_Integer n, const char** a)
 {
@@ -32,7 +32,7 @@ static Standard_Integer prj(Draw_Interpretor& di, Standard_Integer n, const char
     return 1;
   }
   //
-  TopoDS_Shape anInputWire =  DBRep::Get(a[2]);
+  TopoDS_Shape anInputWire  = DBRep::Get(a[2]);
   TopoDS_Shape anInputShape = DBRep::Get(a[3]);
   if (anInputWire.IsNull() || anInputShape.IsNull())
   {
@@ -40,15 +40,13 @@ static Standard_Integer prj(Draw_Interpretor& di, Standard_Integer n, const char
     return 1;
   }
   //
-  Standard_Real X = Draw::Atof(a[4]),
-                Y = Draw::Atof(a[5]),
-                Z = Draw::Atof(a[6]);
+  Standard_Real X = Draw::Atof(a[4]), Y = Draw::Atof(a[5]), Z = Draw::Atof(a[6]);
   //
   Standard_Boolean bCylProj = !strcmp(a[0], "prj");
   //
-  BRepProj_Projection aPrj = bCylProj ?
-    BRepProj_Projection(anInputWire, anInputShape, gp_Dir(X, Y, Z)) :
-    BRepProj_Projection(anInputWire, anInputShape, gp_Pnt(X, Y, Z));
+  BRepProj_Projection aPrj = bCylProj
+                               ? BRepProj_Projection(anInputWire, anInputShape, gp_Dir(X, Y, Z))
+                               : BRepProj_Projection(anInputWire, anInputShape, gp_Pnt(X, Y, Z));
   //
   if (!aPrj.IsDone())
   {
@@ -73,16 +71,23 @@ static Standard_Integer prj(Draw_Interpretor& di, Standard_Integer n, const char
 void BRepTest::ProjectionCommands(Draw_Interpretor& theCommands)
 {
   static Standard_Boolean loaded = Standard_False;
-  if (loaded) return;
+  if (loaded)
+    return;
   loaded = Standard_True;
 
   const char* g = "Projection of wire commands";
 
-  theCommands.Add("prj","prj result w s x y z: "
-    "Cylindrical projection of w (wire or edge) on s (faces) along direction.\n",
-    __FILE__, prj, g);
+  theCommands.Add("prj",
+                  "prj result w s x y z: "
+                  "Cylindrical projection of w (wire or edge) on s (faces) along direction.\n",
+                  __FILE__,
+                  prj,
+                  g);
   //
-  theCommands.Add("cprj","cprj result w s x y z: "
-    "Conical projection of w (wire or edge) on s (faces).\n",
-    __FILE__, prj, g);
+  theCommands.Add("cprj",
+                  "cprj result w s x y z: "
+                  "Conical projection of w (wire or edge) on s (faces).\n",
+                  __FILE__,
+                  prj,
+                  g);
 }
