@@ -19,9 +19,10 @@
 #include <Poly_Triangulation.hxx>
 #include <TopoDS_Face.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(BRepTools_Modification,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(BRepTools_Modification, Standard_Transient)
 
-Standard_Boolean BRepTools_Modification::NewTriangulation(const TopoDS_Face&, Handle(Poly_Triangulation)&)
+Standard_Boolean BRepTools_Modification::NewTriangulation(const TopoDS_Face&,
+                                                          Handle(Poly_Triangulation)&)
 {
   return Standard_False;
 }
@@ -31,7 +32,10 @@ Standard_Boolean BRepTools_Modification::NewPolygon(const TopoDS_Edge&, Handle(P
   return Standard_False;
 }
 
-Standard_Boolean BRepTools_Modification::NewPolygonOnTriangulation(const TopoDS_Edge&, const TopoDS_Face&, Handle(Poly_PolygonOnTriangulation)&)
+Standard_Boolean BRepTools_Modification::NewPolygonOnTriangulation(
+  const TopoDS_Edge&,
+  const TopoDS_Face&,
+  Handle(Poly_PolygonOnTriangulation)&)
 {
   return Standard_False;
 }
