@@ -13,7 +13,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <BinMDataStd_RealListDriver.hxx>
 #include <BinMDataStd.hxx>
 #include <BinObjMgt_Persistent.hxx>
@@ -23,70 +22,71 @@
 #include <TDataStd_RealList.hxx>
 #include <TDF_Attribute.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(BinMDataStd_RealListDriver,BinMDF_ADriver)
+IMPLEMENT_STANDARD_RTTIEXT(BinMDataStd_RealListDriver, BinMDF_ADriver)
 
-//=======================================================================
-//function : BinMDataStd_RealListDriver
-//purpose  : Constructor
-//=======================================================================
-BinMDataStd_RealListDriver::BinMDataStd_RealListDriver(const Handle(Message_Messenger)& theMsgDriver)
-     : BinMDF_ADriver (theMsgDriver, STANDARD_TYPE(TDataStd_RealList)->Name())
+//=================================================================================================
+
+BinMDataStd_RealListDriver::BinMDataStd_RealListDriver(
+  const Handle(Message_Messenger)& theMsgDriver)
+    : BinMDF_ADriver(theMsgDriver, STANDARD_TYPE(TDataStd_RealList)->Name())
 {
-
 }
 
-//=======================================================================
-//function : NewEmpty
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 Handle(TDF_Attribute) BinMDataStd_RealListDriver::NewEmpty() const
 {
   return new TDataStd_RealList();
 }
 
 //=======================================================================
-//function : Paste
-//purpose  : persistent -> transient (retrieve)
+// function : Paste
+// purpose  : persistent -> transient (retrieve)
 //=======================================================================
 Standard_Boolean BinMDataStd_RealListDriver::Paste(const BinObjMgt_Persistent&  theSource,
                                                    const Handle(TDF_Attribute)& theTarget,
                                                    BinObjMgt_RRelocationTable&  theRelocTable) const
 {
   Standard_Integer aIndex, aFirstInd, aLastInd;
-  if (! (theSource >> aFirstInd >> aLastInd))
+  if (!(theSource >> aFirstInd >> aLastInd))
     return Standard_False;
 
   const Handle(TDataStd_RealList) anAtt = Handle(TDataStd_RealList)::DownCast(theTarget);
-  if(aLastInd > 0) {
+  if (aLastInd > 0)
+  {
     const Standard_Integer aLength = aLastInd - aFirstInd + 1;
-    if (aLength > 0) {    
+    if (aLength > 0)
+    {
       TColStd_Array1OfReal aTargetArray(aFirstInd, aLastInd);
-      theSource.GetRealArray (&aTargetArray(aFirstInd), aLength);
+      theSource.GetRealArray(&aTargetArray(aFirstInd), aLength);
       for (aIndex = aFirstInd; aIndex <= aLastInd; aIndex++)
-        anAtt->Append(aTargetArray.Value(aIndex));  
+        anAtt->Append(aTargetArray.Value(aIndex));
     }
   }
 
-  BinMDataStd::SetAttributeID(theSource, anAtt, theRelocTable.GetHeaderData()->StorageVersion().IntegerValue());
+  BinMDataStd::SetAttributeID(theSource,
+                              anAtt,
+                              theRelocTable.GetHeaderData()->StorageVersion().IntegerValue());
   return Standard_True;
 }
 
 //=======================================================================
-//function : Paste
-//purpose  : transient -> persistent (store)
+// function : Paste
+// purpose  : transient -> persistent (store)
 //=======================================================================
 void BinMDataStd_RealListDriver::Paste(const Handle(TDF_Attribute)& theSource,
                                        BinObjMgt_Persistent&        theTarget,
-                                       BinObjMgt_SRelocationTable&  ) const
+                                       BinObjMgt_SRelocationTable&) const
 {
-  const Handle(TDataStd_RealList) anAtt = Handle(TDataStd_RealList)::DownCast(theSource);
-  const Standard_Integer aFirstInd = (anAtt->Extent()> 0) ? 1 : 0;
-  const Standard_Integer aLastInd(anAtt->Extent());  
-  const Standard_Integer aLength   = aLastInd - aFirstInd + 1;
+  const Handle(TDataStd_RealList) anAtt     = Handle(TDataStd_RealList)::DownCast(theSource);
+  const Standard_Integer          aFirstInd = (anAtt->Extent() > 0) ? 1 : 0;
+  const Standard_Integer          aLastInd(anAtt->Extent());
+  const Standard_Integer          aLength = aLastInd - aFirstInd + 1;
   if (aLength <= 0)
     return;
   theTarget << aFirstInd << aLastInd;
-  if(aLastInd == 0) return;
+  if (aLastInd == 0)
+    return;
   TColStd_Array1OfReal aSourceArray(aFirstInd, aLastInd);
   if (aLastInd >= 1)
   {
@@ -95,11 +95,11 @@ void BinMDataStd_RealListDriver::Paste(const Handle(TDF_Attribute)& theSource,
     {
       aSourceArray.SetValue(i, itr.Value());
     }
-    Standard_Real *aPtr = (Standard_Real *) &aSourceArray(aFirstInd);
+    Standard_Real* aPtr = (Standard_Real*)&aSourceArray(aFirstInd);
     theTarget.PutRealArray(aPtr, aLength);
   }
 
   // process user defined guid
-  if(anAtt->ID() != TDataStd_RealList::GetID()) 
+  if (anAtt->ID() != TDataStd_RealList::GetID())
     theTarget << anAtt->ID();
 }
