@@ -14,30 +14,36 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <CDM_Document.hxx>
 #include <CDM_Reference.hxx>
 #include <CDM_ReferenceIterator.hxx>
 
-CDM_ReferenceIterator::CDM_ReferenceIterator(const Handle(CDM_Document)& aDocument):myIterator(aDocument->myToReferences){}
+CDM_ReferenceIterator::CDM_ReferenceIterator(const Handle(CDM_Document)& aDocument)
+    : myIterator(aDocument->myToReferences)
+{
+}
 
-Standard_Boolean CDM_ReferenceIterator::More() const {
+Standard_Boolean CDM_ReferenceIterator::More() const
+{
   return myIterator.More();
 }
 
-void CDM_ReferenceIterator::Next() {
+void CDM_ReferenceIterator::Next()
+{
   myIterator.Next();
 }
 
-Standard_Integer CDM_ReferenceIterator::ReferenceIdentifier() const{
+Standard_Integer CDM_ReferenceIterator::ReferenceIdentifier() const
+{
   return myIterator.Value()->ReferenceIdentifier();
 }
 
-Handle(CDM_Document) CDM_ReferenceIterator::Document() const {
+Handle(CDM_Document) CDM_ReferenceIterator::Document() const
+{
   return myIterator.Value()->ToDocument();
 }
 
-
-Standard_Integer CDM_ReferenceIterator::DocumentVersion() const {
+Standard_Integer CDM_ReferenceIterator::DocumentVersion() const
+{
   return myIterator.Value()->DocumentVersion();
 }
