@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Expr.hxx>
 #include <Expr_GeneralExpression.hxx>
 #include <Expr_GreaterThan.hxx>
@@ -22,22 +21,25 @@
 #include <Standard_Type.hxx>
 #include <TCollection_AsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(Expr_GreaterThan,Expr_SingleRelation)
+IMPLEMENT_STANDARD_RTTIEXT(Expr_GreaterThan, Expr_SingleRelation)
 
-Expr_GreaterThan::Expr_GreaterThan (const Handle(Expr_GeneralExpression)& exp1, const Handle(Expr_GeneralExpression)& exp2)
+Expr_GreaterThan::Expr_GreaterThan(const Handle(Expr_GeneralExpression)& exp1,
+                                   const Handle(Expr_GeneralExpression)& exp2)
 {
   SetFirstMember(exp1);
   SetSecondMember(exp2);
 }
 
-Standard_Boolean Expr_GreaterThan::IsSatisfied () const
+Standard_Boolean Expr_GreaterThan::IsSatisfied() const
 {
   Handle(Expr_GeneralExpression) fm = FirstMember();
   Handle(Expr_GeneralExpression) sm = SecondMember();
-  fm = fm->Simplified();
-  sm = sm->Simplified();
-  if (fm->IsKind(STANDARD_TYPE(Expr_NumericValue))) {
-    if (sm->IsKind(STANDARD_TYPE(Expr_NumericValue))) {
+  fm                                = fm->Simplified();
+  sm                                = sm->Simplified();
+  if (fm->IsKind(STANDARD_TYPE(Expr_NumericValue)))
+  {
+    if (sm->IsKind(STANDARD_TYPE(Expr_NumericValue)))
+    {
       Handle(Expr_NumericValue) nfm = Handle(Expr_NumericValue)::DownCast(fm);
       Handle(Expr_NumericValue) nsm = Handle(Expr_NumericValue)::DownCast(sm);
       return (nfm->GetValue() > nsm->GetValue());
@@ -46,14 +48,14 @@ Standard_Boolean Expr_GreaterThan::IsSatisfied () const
   return Standard_False;
 }
 
-Handle(Expr_GeneralRelation) Expr_GreaterThan::Simplified () const
+Handle(Expr_GeneralRelation) Expr_GreaterThan::Simplified() const
 {
   Handle(Expr_GeneralExpression) fm = FirstMember();
   Handle(Expr_GeneralExpression) sm = SecondMember();
-  return new Expr_GreaterThan(fm->Simplified(),sm->Simplified());
+  return new Expr_GreaterThan(fm->Simplified(), sm->Simplified());
 }
 
-void Expr_GreaterThan::Simplify ()
+void Expr_GreaterThan::Simplify()
 {
   Handle(Expr_GeneralExpression) fm = FirstMember();
   Handle(Expr_GeneralExpression) sm = SecondMember();
@@ -61,10 +63,9 @@ void Expr_GreaterThan::Simplify ()
   SetSecondMember(sm->Simplified());
 }
 
-Handle(Expr_GeneralRelation) Expr_GreaterThan::Copy () const
+Handle(Expr_GeneralRelation) Expr_GreaterThan::Copy() const
 {
-  return new Expr_GreaterThan(Expr::CopyShare(FirstMember()),
-			      Expr::CopyShare(SecondMember()));
+  return new Expr_GreaterThan(Expr::CopyShare(FirstMember()), Expr::CopyShare(SecondMember()));
 }
 
 TCollection_AsciiString Expr_GreaterThan::String() const
