@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Expr.hxx>
 #include <Expr_RelationIterator.hxx>
 #include <Expr_RUIterator.hxx>
@@ -22,49 +21,54 @@
 #include <Expr_UnknownIterator.hxx>
 #include <Standard_NoMoreObject.hxx>
 
-Expr_RUIterator::Expr_RUIterator (const Handle(Expr_GeneralRelation)& rel)
+Expr_RUIterator::Expr_RUIterator(const Handle(Expr_GeneralRelation)& rel)
 {
-  Expr_RelationIterator ri(rel);
+  Expr_RelationIterator       ri(rel);
   Handle(Expr_SingleRelation) srel;
-  Handle(Expr_NamedUnknown) var;
-  myCurrent =1;
-  while (ri.More()) {
+  Handle(Expr_NamedUnknown)   var;
+  myCurrent = 1;
+  while (ri.More())
+  {
     srel = ri.Value();
     ri.Next();
     Expr_UnknownIterator ui1(srel->FirstMember());
-    while (ui1.More()) {
+    while (ui1.More())
+    {
       var = ui1.Value();
       ui1.Next();
-      if (!myMap.Contains(var)) {
-	myMap.Add(var);
+      if (!myMap.Contains(var))
+      {
+        myMap.Add(var);
       }
     }
     Expr_UnknownIterator ui2(srel->SecondMember());
-    while (ui2.More()) {
+    while (ui2.More())
+    {
       var = ui2.Value();
       ui2.Next();
-      if (!myMap.Contains(var)) {
-	myMap.Add(var);
+      if (!myMap.Contains(var))
+      {
+        myMap.Add(var);
       }
     }
   }
 }
 
-Standard_Boolean Expr_RUIterator::More () const
+Standard_Boolean Expr_RUIterator::More() const
 {
   return (myCurrent <= myMap.Extent());
 }
 
-void Expr_RUIterator::Next ()
+void Expr_RUIterator::Next()
 {
-  if (!More()) {
+  if (!More())
+  {
     throw Standard_NoMoreObject();
   }
   myCurrent++;
 }
 
-Handle(Expr_NamedUnknown) Expr_RUIterator::Value () const
+Handle(Expr_NamedUnknown) Expr_RUIterator::Value() const
 {
   return myMap(myCurrent);
 }
-
