@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Extrema_GenExtCS.hxx>
 #include <Geom_OffsetCurve.hxx>
 #include <Extrema_GlobOptFuncCS.hxx>
@@ -35,31 +34,42 @@
 #include <ElCLib.hxx>
 #include <Extrema_GenLocateExtPS.hxx>
 
-
-const Standard_Real MaxParamVal = 1.0e+10;
+const Standard_Real MaxParamVal    = 1.0e+10;
 const Standard_Real aBorderDivisor = 1.0e+4;
-const Standard_Real HyperbolaLimit = 23.; //ln(MaxParamVal)
+const Standard_Real HyperbolaLimit = 23.; // ln(MaxParamVal)
 
 static Standard_Boolean IsQuadric(const GeomAbs_SurfaceType theSType)
 {
-  if (theSType == GeomAbs_Plane) return Standard_True;
-  if (theSType == GeomAbs_Cylinder) return Standard_True;
-  if (theSType == GeomAbs_Cone) return Standard_True;
-  if (theSType == GeomAbs_Sphere) return Standard_True;
-  if (theSType == GeomAbs_Torus) return Standard_True;
-  return  Standard_False;
+  if (theSType == GeomAbs_Plane)
+    return Standard_True;
+  if (theSType == GeomAbs_Cylinder)
+    return Standard_True;
+  if (theSType == GeomAbs_Cone)
+    return Standard_True;
+  if (theSType == GeomAbs_Sphere)
+    return Standard_True;
+  if (theSType == GeomAbs_Torus)
+    return Standard_True;
+  return Standard_False;
 }
+
 static Standard_Boolean IsConic(const GeomAbs_CurveType theCType)
 {
-  if (theCType == GeomAbs_Line) return Standard_True;
-  if (theCType == GeomAbs_Circle) return Standard_True;
-  if (theCType == GeomAbs_Ellipse) return Standard_True;
-  if (theCType == GeomAbs_Hyperbola) return Standard_True;
-  if (theCType == GeomAbs_Parabola) return Standard_True;
-  return  Standard_False;
+  if (theCType == GeomAbs_Line)
+    return Standard_True;
+  if (theCType == GeomAbs_Circle)
+    return Standard_True;
+  if (theCType == GeomAbs_Ellipse)
+    return Standard_True;
+  if (theCType == GeomAbs_Hyperbola)
+    return Standard_True;
+  if (theCType == GeomAbs_Parabola)
+    return Standard_True;
+  return Standard_False;
 }
+
 // restrict maximal parameter on hyperbola to avoid FPE
-static Standard_Real GetCurvMaxParamVal (const Adaptor3d_Curve& theC)
+static Standard_Real GetCurvMaxParamVal(const Adaptor3d_Curve& theC)
 {
   if (theC.GetType() == GeomAbs_Hyperbola)
   {
@@ -67,176 +77,164 @@ static Standard_Real GetCurvMaxParamVal (const Adaptor3d_Curve& theC)
   }
   if (theC.GetType() == GeomAbs_OffsetCurve)
   {
-    Handle(Geom_Curve) aBC (theC.OffsetCurve()->BasisCurve());
-    Handle(Geom_TrimmedCurve) aTC = Handle(Geom_TrimmedCurve)::DownCast (aBC);
-    if (! aTC.IsNull())
+    Handle(Geom_Curve)        aBC(theC.OffsetCurve()->BasisCurve());
+    Handle(Geom_TrimmedCurve) aTC = Handle(Geom_TrimmedCurve)::DownCast(aBC);
+    if (!aTC.IsNull())
     {
       aBC = aTC->BasisCurve();
     }
-    if (aBC->IsKind (STANDARD_TYPE(Geom_Hyperbola)))
+    if (aBC->IsKind(STANDARD_TYPE(Geom_Hyperbola)))
       return HyperbolaLimit;
   }
   return MaxParamVal;
 }
 
 // restrict maximal parameter on surfaces based on hyperbola to avoid FPE
-static void GetSurfMaxParamVals (const Adaptor3d_Surface& theS,
-                                 Standard_Real& theUmax, Standard_Real& theVmax)
+static void GetSurfMaxParamVals(const Adaptor3d_Surface& theS,
+                                Standard_Real&           theUmax,
+                                Standard_Real&           theVmax)
 {
   theUmax = theVmax = MaxParamVal;
 
   if (theS.GetType() == GeomAbs_SurfaceOfExtrusion)
   {
-    theUmax = GetCurvMaxParamVal (*theS.BasisCurve());
+    theUmax = GetCurvMaxParamVal(*theS.BasisCurve());
   }
   else if (theS.GetType() == GeomAbs_SurfaceOfRevolution)
   {
-    theVmax = GetCurvMaxParamVal (*theS.BasisCurve());
+    theVmax = GetCurvMaxParamVal(*theS.BasisCurve());
   }
   else if (theS.GetType() == GeomAbs_OffsetSurface)
   {
-    GetSurfMaxParamVals (*theS.BasisSurface(), theUmax, theVmax);
+    GetSurfMaxParamVals(*theS.BasisSurface(), theUmax, theVmax);
   }
 }
 
-//=======================================================================
-//function : Extrema_GenExtCS
-//purpose  : 
-//=======================================================================
+//=================================================================================================
+
 Extrema_GenExtCS::Extrema_GenExtCS()
-: myDone(Standard_False),
-  mytmin(0.0),
-  mytsup(0.0),
-  myumin(0.0),
-  myusup(0.0),
-  myvmin(0.0),
-  myvsup(0.0),
-  mytsample(0),
-  myusample(0),
-  myvsample(0),
-  mytol1(0.0),
-  mytol2(0.0),
-  myS(NULL)
+    : myDone(Standard_False),
+      mytmin(0.0),
+      mytsup(0.0),
+      myumin(0.0),
+      myusup(0.0),
+      myvmin(0.0),
+      myvsup(0.0),
+      mytsample(0),
+      myusample(0),
+      myvsample(0),
+      mytol1(0.0),
+      mytol2(0.0),
+      myS(NULL)
 {
 }
 
-// =======================================================================
-// function : ~Extrema_GenExtCS
-// purpose  :
-// =======================================================================
+//=================================================================================================
+
 Extrema_GenExtCS::~Extrema_GenExtCS()
 {
   //
 }
 
-//=======================================================================
-//function : Extrema_GenExtCS
-//purpose  : 
-//=======================================================================
-Extrema_GenExtCS::Extrema_GenExtCS(const Adaptor3d_Curve& C,
+//=================================================================================================
+
+Extrema_GenExtCS::Extrema_GenExtCS(const Adaptor3d_Curve&   C,
                                    const Adaptor3d_Surface& S,
-                                   const Standard_Integer NbT,
-                                   const Standard_Integer NbU,
-                                   const Standard_Integer NbV,
-                                   const Standard_Real Tol1,
-                                   const Standard_Real Tol2)
+                                   const Standard_Integer   NbT,
+                                   const Standard_Integer   NbU,
+                                   const Standard_Integer   NbV,
+                                   const Standard_Real      Tol1,
+                                   const Standard_Real      Tol2)
 {
   Initialize(S, NbU, NbV, Tol2);
   Perform(C, NbT, Tol1);
 }
 
-//=======================================================================
-//function : Extrema_GenExtCS
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
-Extrema_GenExtCS::Extrema_GenExtCS (const Adaptor3d_Curve& C,
-                                    const Adaptor3d_Surface& S,
-                                    const Standard_Integer NbT,
-                                    const Standard_Integer NbU,
-                                    const Standard_Integer NbV,
-                                    const Standard_Real tmin,
-                                    const Standard_Real tsup,
-                                    const Standard_Real Umin,
-                                    const Standard_Real Usup,
-                                    const Standard_Real Vmin,
-                                    const Standard_Real Vsup,
-                                    const Standard_Real Tol1,
-                                    const Standard_Real Tol2)
+Extrema_GenExtCS::Extrema_GenExtCS(const Adaptor3d_Curve&   C,
+                                   const Adaptor3d_Surface& S,
+                                   const Standard_Integer   NbT,
+                                   const Standard_Integer   NbU,
+                                   const Standard_Integer   NbV,
+                                   const Standard_Real      tmin,
+                                   const Standard_Real      tsup,
+                                   const Standard_Real      Umin,
+                                   const Standard_Real      Usup,
+                                   const Standard_Real      Vmin,
+                                   const Standard_Real      Vsup,
+                                   const Standard_Real      Tol1,
+                                   const Standard_Real      Tol2)
 {
-  Initialize(S, NbU, NbV, Umin,Usup,Vmin,Vsup,Tol2);
+  Initialize(S, NbU, NbV, Umin, Usup, Vmin, Vsup, Tol2);
   Perform(C, NbT, tmin, tsup, Tol1);
 }
 
-//=======================================================================
-//function : Initialize
-//purpose  : 
-//=======================================================================
-void Extrema_GenExtCS::Initialize (const Adaptor3d_Surface& S,
-                                   const Standard_Integer NbU,
-                                   const Standard_Integer NbV,
-                                   const Standard_Real Tol2)
+//=================================================================================================
+
+void Extrema_GenExtCS::Initialize(const Adaptor3d_Surface& S,
+                                  const Standard_Integer   NbU,
+                                  const Standard_Integer   NbV,
+                                  const Standard_Real      Tol2)
 {
   myumin = S.FirstUParameter();
   myusup = S.LastUParameter();
   myvmin = S.FirstVParameter();
   myvsup = S.LastVParameter();
-  Initialize(S,NbU,NbV,myumin,myusup,myvmin,myvsup,Tol2);
+  Initialize(S, NbU, NbV, myumin, myusup, myvmin, myvsup, Tol2);
 }
 
-//=======================================================================
-//function : Initialize
-//purpose  : 
-//=======================================================================
-void Extrema_GenExtCS::Initialize (const Adaptor3d_Surface& S,
-                                   const Standard_Integer NbU,
-                                   const Standard_Integer NbV,
-                                   const Standard_Real Umin,
-                                   const Standard_Real Usup,
-                                   const Standard_Real Vmin,
-                                   const Standard_Real Vsup,
-                                   const Standard_Real Tol2)
+//=================================================================================================
+
+void Extrema_GenExtCS::Initialize(const Adaptor3d_Surface& S,
+                                  const Standard_Integer   NbU,
+                                  const Standard_Integer   NbV,
+                                  const Standard_Real      Umin,
+                                  const Standard_Real      Usup,
+                                  const Standard_Real      Vmin,
+                                  const Standard_Real      Vsup,
+                                  const Standard_Real      Tol2)
 {
-  myS = &S;
+  myS       = &S;
   myusample = NbU;
   myvsample = NbV;
-  myumin = Umin;
-  myusup = Usup;
-  myvmin = Vmin;
-  myvsup = Vsup;
-  mytol2 = Tol2;
+  myumin    = Umin;
+  myusup    = Usup;
+  myvmin    = Vmin;
+  myvsup    = Vsup;
+  mytol2    = Tol2;
 
   Standard_Real umaxpar, vmaxpar;
   GetSurfMaxParamVals(*myS, umaxpar, vmaxpar);
 
-  if(Precision::IsInfinite (myusup))
+  if (Precision::IsInfinite(myusup))
   {
     myusup = umaxpar;
   }
-  if(Precision::IsInfinite (myumin))
+  if (Precision::IsInfinite(myumin))
   {
     myumin = -umaxpar;
   }
-  if(Precision::IsInfinite (myvsup))
+  if (Precision::IsInfinite(myvsup))
   {
-    myvsup =  vmaxpar;
+    myvsup = vmaxpar;
   }
-  if(Precision::IsInfinite (myvmin))
+  if (Precision::IsInfinite(myvmin))
   {
     myvmin = -vmaxpar;
   }
 
-  Standard_Real du = (myusup - myumin) / aBorderDivisor;
-  Standard_Real dv = (myvsup - myvmin) / aBorderDivisor;
+  Standard_Real       du    = (myusup - myumin) / aBorderDivisor;
+  Standard_Real       dv    = (myvsup - myvmin) / aBorderDivisor;
   const Standard_Real aMinU = myumin + du;
   const Standard_Real aMinV = myvmin + dv;
   const Standard_Real aMaxU = myusup - du;
   const Standard_Real aMaxV = myvsup - dv;
-  
+
   const Standard_Real aStepSU = (aMaxU - aMinU) / myusample;
   const Standard_Real aStepSV = (aMaxV - aMinV) / myvsample;
 
-  mySurfPnts = new TColgp_HArray2OfPnt (0, myusample, 0, myvsample);
+  mySurfPnts = new TColgp_HArray2OfPnt(0, myusample, 0, myvsample);
 
   Standard_Real aSU = aMinU;
   for (Standard_Integer aSUI = 0; aSUI <= myusample; aSUI++, aSU += aStepSU)
@@ -244,52 +242,50 @@ void Extrema_GenExtCS::Initialize (const Adaptor3d_Surface& S,
     Standard_Real aSV = aMinV;
     for (Standard_Integer aSVI = 0; aSVI <= myvsample; aSVI++, aSV += aStepSV)
     {
-      mySurfPnts->ChangeValue (aSUI, aSVI) = myS->Value (aSU, aSV);
+      mySurfPnts->ChangeValue(aSUI, aSVI) = myS->Value(aSU, aSV);
     }
   }
 }
 
-//=======================================================================
-//function : Perform
-//purpose  : 
-//=======================================================================
-void Extrema_GenExtCS::Perform(const Adaptor3d_Curve& C, 
-  const Standard_Integer NbT,
-  const Standard_Real Tol1)
+//=================================================================================================
+
+void Extrema_GenExtCS::Perform(const Adaptor3d_Curve& C,
+                               const Standard_Integer NbT,
+                               const Standard_Real    Tol1)
 {
   mytmin = C.FirstParameter();
   mytsup = C.LastParameter();
-  Perform(C, NbT, mytmin, mytsup,Tol1);
+  Perform(C, NbT, mytmin, mytsup, Tol1);
 }
 
-//=======================================================================
-//function : Perform
-//purpose  : 
-//=======================================================================
-void Extrema_GenExtCS::Perform (const Adaptor3d_Curve& C,
-                                const Standard_Integer NbT,
-                                const Standard_Real tmin,
-                                const Standard_Real tsup,
-                                const Standard_Real Tol1)
+//=================================================================================================
+
+void Extrema_GenExtCS::Perform(const Adaptor3d_Curve& C,
+                               const Standard_Integer NbT,
+                               const Standard_Real    tmin,
+                               const Standard_Real    tsup,
+                               const Standard_Real    Tol1)
 {
   myDone = Standard_False;
-  myF.Initialize(C,*myS);
-  mytmin = tmin;
-  mytsup = tsup;
-  mytol1 = Tol1;
+  myF.Initialize(C, *myS);
+  mytmin    = tmin;
+  mytsup    = tsup;
+  mytol1    = Tol1;
   mytsample = NbT;
   // Modif de lvt pour trimer la surface non pas aux infinis mais  a +/- 10000
 
-  Standard_Real trimusup = myusup, trimumin = myumin,trimvsup = myvsup,trimvmin = myvmin;
-  Standard_Real aCMaxVal = GetCurvMaxParamVal (C);
-  if (Precision::IsInfinite(mytsup)){
+  Standard_Real trimusup = myusup, trimumin = myumin, trimvsup = myvsup, trimvmin = myvmin;
+  Standard_Real aCMaxVal = GetCurvMaxParamVal(C);
+  if (Precision::IsInfinite(mytsup))
+  {
     mytsup = aCMaxVal;
   }
-  if (Precision::IsInfinite(mytmin)){
+  if (Precision::IsInfinite(mytmin))
+  {
     mytmin = -aCMaxVal;
   }
   //
-  Standard_Integer aNbVar = 3;
+  Standard_Integer    aNbVar = 3;
   GeomAbs_SurfaceType aSType = myS->GetType();
   if (IsQuadric(aSType))
   {
@@ -324,7 +320,7 @@ void Extrema_GenExtCS::Perform (const Adaptor3d_Curve& C,
   }
 
   Standard_Integer anInt;
-  Standard_Real dT = (mytsup - mytmin) / aNbIntC;
+  Standard_Real    dT = (mytsup - mytmin) / aNbIntC;
   for (anInt = 1; anInt <= aNbIntC; anInt++)
   {
     TUVinf(1) = mytmin + (anInt - 1) * dT;
@@ -354,15 +350,15 @@ void Extrema_GenExtCS::Perform (const Adaptor3d_Curve& C,
   }
   if (aNbIntC > 1 && myF.NbExt() > 1)
   {
-    //Try to remove "false" extrema caused by dividing curve interval
-    TColStd_SequenceOfReal& aSqDists = myF.SquareDistances();
-    Extrema_SequenceOfPOnCurv& aPntsOnCrv = myF.PointsOnCurve();
+    // Try to remove "false" extrema caused by dividing curve interval
+    TColStd_SequenceOfReal&    aSqDists    = myF.SquareDistances();
+    Extrema_SequenceOfPOnCurv& aPntsOnCrv  = myF.PointsOnCurve();
     Extrema_SequenceOfPOnSurf& aPntsOnSurf = myF.PointsOnSurf();
-    TColStd_SequenceOfReal aSqDists1(aSqDists);
-    Extrema_SequenceOfPOnCurv aPntsOnCrv1(aPntsOnCrv);
-    Extrema_SequenceOfPOnSurf aPntsOnSurf1(aPntsOnSurf);
+    TColStd_SequenceOfReal     aSqDists1(aSqDists);
+    Extrema_SequenceOfPOnCurv  aPntsOnCrv1(aPntsOnCrv);
+    Extrema_SequenceOfPOnSurf  aPntsOnSurf1(aPntsOnSurf);
 
-    Standard_Real aMinDist = aSqDists(1);
+    Standard_Real    aMinDist = aSqDists(1);
     Standard_Integer i;
     for (i = 2; i <= aSqDists.Length(); ++i)
     {
@@ -375,7 +371,7 @@ void Extrema_GenExtCS::Perform (const Adaptor3d_Curve& C,
     aSqDists.Clear();
     aPntsOnCrv.Clear();
     aPntsOnSurf.Clear();
-    Standard_Real aTol = Precision::SquareConfusion();
+    constexpr Standard_Real aTol = Precision::SquareConfusion();
     for (i = 1; i <= aSqDists1.Length(); ++i)
     {
       Standard_Real aDist = aSqDists1(i);
@@ -388,17 +384,15 @@ void Extrema_GenExtCS::Perform (const Adaptor3d_Curve& C,
     }
   }
   myDone = Standard_True;
-
 }
-//=======================================================================
-//function : GlobMinGenCS
-//purpose  : 
-//=======================================================================
+
+//=================================================================================================
+
 void Extrema_GenExtCS::GlobMinGenCS(const Adaptor3d_Curve& theC,
-                                    const Standard_Integer theNbParticles, 
-                                    const math_Vector& theTUVinf, 
-                                    const math_Vector& theTUVsup,
-                                    math_Vector& theTUV)
+                                    const Standard_Integer theNbParticles,
+                                    const math_Vector&     theTUVinf,
+                                    const math_Vector&     theTUVsup,
+                                    math_Vector&           theTUV)
 {
   math_PSOParticlesPool aParticles(theNbParticles, 3);
 
@@ -413,12 +407,13 @@ void Extrema_GenExtCS::GlobMinGenCS(const Adaptor3d_Curve& theC,
   Standard_Real aStepSV = (aMaxTUV(3) - aMinTUV(3)) / myvsample;
 
   // Correct number of curve samples in case of low resolution
-  Standard_Integer aNewCsample = mytsample;
-  Standard_Real aScaleFactor = 5.0;
-  Standard_Real aResolutionCU = aStepCU / theC.Resolution(1.0);
+  Standard_Integer aNewCsample   = mytsample;
+  Standard_Real    aScaleFactor  = 5.0;
+  Standard_Real    aResolutionCU = aStepCU / theC.Resolution(1.0);
 
-  Standard_Real aMinResolution = aScaleFactor * Min(aResolutionCU,
-    Min(aStepSU / myS->UResolution(1.0), aStepSV / myS->VResolution(1.0)));
+  Standard_Real aMinResolution =
+    aScaleFactor
+    * Min(aResolutionCU, Min(aStepSU / myS->UResolution(1.0), aStepSV / myS->VResolution(1.0)));
 
   if (aMinResolution > Epsilon(1.0))
   {
@@ -426,8 +421,7 @@ void Extrema_GenExtCS::GlobMinGenCS(const Adaptor3d_Curve& theC,
     {
       const Standard_Integer aMaxNbNodes = 50;
 
-      aNewCsample = Min(aMaxNbNodes,
-        RealToInt(mytsample * aResolutionCU / aMinResolution));
+      aNewCsample = Min(aMaxNbNodes, RealToInt(mytsample * aResolutionCU / aMinResolution));
 
       aStepCU = (aMaxTUV(1) - aMinTUV(1)) / aNewCsample;
     }
@@ -463,7 +457,7 @@ void Extrema_GenExtCS::GlobMinGenCS(const Adaptor3d_Curve& theC,
           aParticle->BestPosition[1] = aSU;
           aParticle->BestPosition[2] = aSV;
 
-          aParticle->Distance = aSqDist;
+          aParticle->Distance     = aSqDist;
           aParticle->BestDistance = aSqDist;
 
           aParticle = aParticles.GetWorstParticle();
@@ -478,24 +472,22 @@ void Extrema_GenExtCS::GlobMinGenCS(const Adaptor3d_Curve& theC,
   aStep(3) = aStepSV;
 
   // Find min approximation
-  Standard_Real aValue;
+  Standard_Real         aValue;
   Extrema_GlobOptFuncCS aFunc(&theC, myS);
-  math_PSO aPSO(&aFunc, theTUVinf, theTUVsup, aStep);
+  math_PSO              aPSO(&aFunc, theTUVinf, theTUVsup, aStep);
   aPSO.Perform(aParticles, theNbParticles, aValue, theTUV);
-
 }
-//=======================================================================
-//function : GlobMinConicS
-//purpose  : 
-//=======================================================================
+
+//=================================================================================================
+
 void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
-  const Standard_Integer theNbParticles,
-  const math_Vector& theTUVinf,
-  const math_Vector& theTUVsup,
-  math_Vector& theTUV)
+                                     const Standard_Integer theNbParticles,
+                                     const math_Vector&     theTUVinf,
+                                     const math_Vector&     theTUVsup,
+                                     math_Vector&           theTUV)
 {
   Standard_Integer aNbVar = 2;
-  math_Vector  anUVinf(1, aNbVar), anUVsup(1, aNbVar), anUV(1, aNbVar);
+  math_Vector      anUVinf(1, aNbVar), anUVsup(1, aNbVar), anUV(1, aNbVar);
   Standard_Integer i;
   for (i = 1; i <= aNbVar; ++i)
   {
@@ -512,10 +504,10 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
   math_Vector aMaxUV(1, aNbVar);
   aMaxUV = anUVsup - (anUVsup - anUVinf) / aBorderDivisor;
 
-  //Increase numbers of UV samples to improve searching global minimum
+  // Increase numbers of UV samples to improve searching global minimum
   Standard_Integer anAddsample = Max(mytsample / 2, 3);
-  Standard_Integer anUsample = myusample + anAddsample;
-  Standard_Integer aVsample = myvsample + anAddsample;
+  Standard_Integer anUsample   = myusample + anAddsample;
+  Standard_Integer aVsample    = myvsample + anAddsample;
   //
   Standard_Real aStepSU = (aMaxUV(1) - aMinUV(1)) / anUsample;
   Standard_Real aStepSV = (aMaxUV(2) - aMinUV(2)) / aVsample;
@@ -523,14 +515,13 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
   Extrema_GlobOptFuncConicS aFunc(myS, anUVinf(1), anUVsup(1), anUVinf(2), anUVsup(2));
   aFunc.LoadConic(&theC, theTUVinf(1), theTUVsup(1));
 
-
   PSO_Particle* aParticle = aParticles.GetWorstParticle();
   // Select specified number of particles from pre-computed set of samples
   Standard_Real aSU = aMinUV(1);
-  
+
   for (Standard_Integer aSUI = 0; aSUI <= anUsample; aSUI++, aSU += aStepSU)
   {
-    anUV(1) = aSU;
+    anUV(1)           = aSU;
     Standard_Real aSV = aMinUV(2);
     for (Standard_Integer aSVI = 0; aSVI <= aVsample; aSVI++, aSV += aStepSV)
     {
@@ -549,7 +540,7 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
         aParticle->BestPosition[0] = aSU;
         aParticle->BestPosition[1] = aSV;
 
-        aParticle->Distance = aSqDist;
+        aParticle->Distance     = aSqDist;
         aParticle->BestDistance = aSqDist;
 
         aParticle = aParticles.GetWorstParticle();
@@ -563,13 +554,14 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
 
   // Find min approximation
   Standard_Real aValue;
-  math_PSO aPSO(&aFunc, anUVinf, anUVsup, aStep);
+  math_PSO      aPSO(&aFunc, anUVinf, anUVsup, aStep);
   aPSO.Perform(aParticles, theNbParticles, aValue, anUV);
   //
   Standard_Real aCT = aFunc.ConicParameter(anUV);
   if (theC.IsPeriodic())
   {
-    if (aCT <  theTUVinf(1) - Precision::PConfusion() || aCT >  theTUVsup(1) + Precision::PConfusion())
+    if (aCT < theTUVinf(1) - Precision::PConfusion()
+        || aCT > theTUVsup(1) + Precision::PConfusion())
     {
       aCT = ElCLib::InPeriod(aCT, theTUVinf(1), theTUVinf(1) + 2. * M_PI);
     }
@@ -580,8 +572,8 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
   theTUV(3) = anUV(2);
 
   Standard_Boolean isBadSol = Standard_False;
-  gp_Vec aDU, aDV, aDT;
-  gp_Pnt aPOnS, aPOnC;
+  gp_Vec           aDU, aDV, aDT;
+  gp_Pnt           aPOnS, aPOnC;
   myS->D1(anUV(1), anUV(2), aPOnS, aDU, aDV);
   theC.D1(aCT, aPOnC, aDT);
   Standard_Real aSqDist = aPOnC.SquareDistance(aPOnS);
@@ -607,13 +599,13 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
     for (iu = -1; iu <= 1; ++iu)
     {
       Standard_Real u = anUV(1) + iu * aStepSU;
-      u = Max(anUVinf(1), u);
-      u = Min(anUVsup(1), u);
+      u               = Max(anUVinf(1), u);
+      u               = Min(anUVsup(1), u);
       for (iv = -1; iv <= 1; ++iv)
       {
         Standard_Real v = anUV(2) + iv * aStepSV;
-        v = Max(anUVinf(2), v);
-        v = Min(anUVsup(2), v);
+        v               = Max(anUVinf(2), v);
+        v               = Min(anUVsup(2), v);
         myS->D1(u, v, aPOnS, aDU, aDV);
         if (aPOnC.SquareDistance(aPOnS) < Precision::SquareConfusion())
         {
@@ -643,12 +635,12 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
 
   if (isBadSol)
   {
-    //Try to precise solution with help of Extrema PS
+    // Try to precise solution with help of Extrema PS
 
     math_Vector aF(1, 3);
-    aF(1) = PcPs.Dot(aDT);
-    aF(2) = PcPs.Dot(aDU);
-    aF(3) = PcPs.Dot(aDV);
+    aF(1)             = PcPs.Dot(aDT);
+    aF(2)             = PcPs.Dot(aDU);
+    aF(3)             = PcPs.Dot(aDV);
     Standard_Real aFF = aF.Norm2();
 
     Extrema_GenLocateExtPS anExtPS(*myS, mytol2, mytol2);
@@ -658,8 +650,8 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
       const Extrema_POnSurf& aPmin = anExtPS.Point();
       aPmin.Parameter(anUV(1), anUV(2));
       math_Vector aTUV = theTUV;
-      aTUV(2) = anUV(1);
-      aTUV(3) = anUV(2);
+      aTUV(2)          = anUV(1);
+      aTUV(3)          = anUV(2);
       myF.Value(aTUV, aF);
       Standard_Real aFF1 = aF.Norm2();
 
@@ -670,20 +662,18 @@ void Extrema_GenExtCS::GlobMinConicS(const Adaptor3d_Curve& theC,
       }
     }
   }
- 
 }
-//=======================================================================
-//function : GlobMinCQuadric
-//purpose  : 
-//=======================================================================
+
+//=================================================================================================
+
 void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
-  const Standard_Integer theNbParticles,
-  const math_Vector& theTUVinf,
-  const math_Vector& theTUVsup,
-  math_Vector& theTUV)
+                                       const Standard_Integer theNbParticles,
+                                       const math_Vector&     theTUVinf,
+                                       const math_Vector&     theTUVsup,
+                                       math_Vector&           theTUV)
 {
   Standard_Integer aNbVar = 1;
-  math_Vector aTinf(1, aNbVar), aTsup(1, aNbVar), aT(1, aNbVar);
+  math_Vector      aTinf(1, aNbVar), aTsup(1, aNbVar), aT(1, aNbVar);
   aTinf(1) = theTUVinf(1);
   aTsup(1) = theTUVsup(1);
   //
@@ -696,31 +686,31 @@ void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
   aMaxT = aTsup - (aTsup - aTinf) / aBorderDivisor;
   //
 
-  //Increase numbers of curve samples to improve searching global minimum
-  //because dimension of optimisation task is redused
+  // Increase numbers of curve samples to improve searching global minimum
+  // because dimension of optimisation task is reduced
   const Standard_Integer aMaxNbNodes = 50;
-  Standard_Integer aNewCsample = mytsample;
-  Standard_Integer anAddsample = Max(myusample / 2, 3);
+  Standard_Integer       aNewCsample = mytsample;
+  Standard_Integer       anAddsample = Max(myusample / 2, 3);
   aNewCsample += anAddsample;
   aNewCsample = Min(aNewCsample, aMaxNbNodes);
   //
   // Correct number of curve samples in case of low resolution
-  Standard_Real aStepCT = (aMaxT(1) - aMinT(1)) / aNewCsample;
-  Standard_Real aStepSU = (theTUVsup(2) - theTUVinf(2)) / myusample;
-  Standard_Real aStepSV = (theTUVsup(3) - theTUVinf(3)) / myvsample;
-  Standard_Real aScaleFactor = 5.0;
+  Standard_Real aStepCT       = (aMaxT(1) - aMinT(1)) / aNewCsample;
+  Standard_Real aStepSU       = (theTUVsup(2) - theTUVinf(2)) / myusample;
+  Standard_Real aStepSV       = (theTUVsup(3) - theTUVinf(3)) / myvsample;
+  Standard_Real aScaleFactor  = 5.0;
   Standard_Real aResolutionCU = aStepCT / theC.Resolution(1.0);
 
-  Standard_Real aMinResolution = aScaleFactor * Min(aResolutionCU,
-    Min(aStepSU / myS->UResolution(1.0), aStepSV / myS->VResolution(1.0)));
+  Standard_Real aMinResolution =
+    aScaleFactor
+    * Min(aResolutionCU, Min(aStepSU / myS->UResolution(1.0), aStepSV / myS->VResolution(1.0)));
 
   if (aMinResolution > Epsilon(1.0))
   {
     if (aResolutionCU > aMinResolution)
     {
 
-      aNewCsample = Min(aMaxNbNodes,
-        RealToInt(aNewCsample * aResolutionCU / aMinResolution));
+      aNewCsample = Min(aMaxNbNodes, RealToInt(aNewCsample * aResolutionCU / aMinResolution));
 
       aStepCT = (aMaxT(1) - aMinT(1)) / aNewCsample;
     }
@@ -736,7 +726,7 @@ void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
   for (Standard_Integer aCUI = 0; aCUI <= aNewCsample; aCUI++, aCT += aStepCT)
   {
     aT(1) = aCT;
-    Standard_Real aSqDist; 
+    Standard_Real aSqDist;
     if (!aFunc.Value(aT, aSqDist))
     {
       aSqDist = Precision::Infinite();
@@ -748,7 +738,7 @@ void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
 
       aParticle->BestPosition[0] = aCT;
 
-      aParticle->Distance = aSqDist;
+      aParticle->Distance     = aSqDist;
       aParticle->BestDistance = aSqDist;
 
       aParticle = aParticles.GetWorstParticle();
@@ -760,14 +750,15 @@ void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
 
   // Find min approximation
   Standard_Real aValue;
-  math_PSO aPSO(&aFunc, aTinf, aTsup, aStep);
+  math_PSO      aPSO(&aFunc, aTinf, aTsup, aStep);
   aPSO.Perform(aParticles, theNbParticles, aValue, aT);
   //
   math_Vector anUV(1, 2);
   aFunc.QuadricParameters(aT, anUV);
   if (myS->IsUPeriodic())
   {
-    if (anUV(1) <  theTUVinf(2) - Precision::PConfusion() || anUV(1)>  theTUVsup(2) + Precision::PConfusion())
+    if (anUV(1) < theTUVinf(2) - Precision::PConfusion()
+        || anUV(1) > theTUVsup(2) + Precision::PConfusion())
     {
       anUV(1) = ElCLib::InPeriod(anUV(1), theTUVinf(2), theTUVinf(2) + 2. * M_PI);
     }
@@ -775,7 +766,8 @@ void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
   //
   if (myS->IsVPeriodic())
   {
-    if (anUV(2) <  theTUVinf(3) - Precision::PConfusion() || anUV(2)>  theTUVsup(3) + Precision::PConfusion())
+    if (anUV(2) < theTUVinf(3) - Precision::PConfusion()
+        || anUV(2) > theTUVsup(3) + Precision::PConfusion())
     {
       anUV(2) = ElCLib::InPeriod(anUV(2), theTUVinf(3), theTUVinf(3) + 2. * M_PI);
     }
@@ -784,33 +776,29 @@ void Extrema_GenExtCS::GlobMinCQuadric(const Adaptor3d_Curve& theC,
   theTUV(1) = aT(1);
   theTUV(2) = anUV(1);
   theTUV(3) = anUV(2);
-
 }
 
-//=======================================================================
-//function : IsDone
-//purpose  : 
-//=======================================================================
-Standard_Boolean Extrema_GenExtCS::IsDone() const 
+//=================================================================================================
+
+Standard_Boolean Extrema_GenExtCS::IsDone() const
 {
   return myDone;
 }
 
-//=======================================================================
-//function : NbExt
-//purpose  : 
-//=======================================================================
-Standard_Integer Extrema_GenExtCS::NbExt() const 
+//=================================================================================================
+
+Standard_Integer Extrema_GenExtCS::NbExt() const
 {
-  if (!IsDone()) { throw StdFail_NotDone(); }
+  if (!IsDone())
+  {
+    throw StdFail_NotDone();
+  }
   return myF.NbExt();
 }
 
-//=======================================================================
-//function : Value
-//purpose  : 
-//=======================================================================
-Standard_Real Extrema_GenExtCS::SquareDistance(const Standard_Integer N) const 
+//=================================================================================================
+
+Standard_Real Extrema_GenExtCS::SquareDistance(const Standard_Integer N) const
 {
   if (N < 1 || N > NbExt())
   {
@@ -820,11 +808,9 @@ Standard_Real Extrema_GenExtCS::SquareDistance(const Standard_Integer N) const
   return myF.SquareDistance(N);
 }
 
-//=======================================================================
-//function : PointOnCurve
-//purpose  : 
-//=======================================================================
-const Extrema_POnCurv& Extrema_GenExtCS::PointOnCurve(const Standard_Integer N) const 
+//=================================================================================================
+
+const Extrema_POnCurv& Extrema_GenExtCS::PointOnCurve(const Standard_Integer N) const
 {
   if (N < 1 || N > NbExt())
   {
@@ -834,11 +820,9 @@ const Extrema_POnCurv& Extrema_GenExtCS::PointOnCurve(const Standard_Integer N)
   return myF.PointOnCurve(N);
 }
 
-//=======================================================================
-//function : PointOnSurface
-//purpose  : 
-//=======================================================================
-const Extrema_POnSurf& Extrema_GenExtCS::PointOnSurface(const Standard_Integer N) const 
+//=================================================================================================
+
+const Extrema_POnSurf& Extrema_GenExtCS::PointOnSurface(const Standard_Integer N) const
 {
   if (N < 1 || N > NbExt())
   {
