@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <GC_MakeScale.hxx>
 #include <Geom_Transformation.hxx>
 #include <gp_Pnt.hxx>
@@ -23,13 +22,13 @@
 //=========================================================================
 //   Creation d un homothetie de gp de centre Point et de rapport Scale.  +
 //=========================================================================
-GC_MakeScale::GC_MakeScale(const gp_Pnt&  Point ,
-			     const Standard_Real     Scale ) {
+GC_MakeScale::GC_MakeScale(const gp_Pnt& Point, const Standard_Real Scale)
+{
   TheScale = new Geom_Transformation();
-  TheScale->SetScale(Point,Scale);
+  TheScale->SetScale(Point, Scale);
 }
 
 const Handle(Geom_Transformation)& GC_MakeScale::Value() const
-{ 
+{
   return TheScale;
 }
