@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <GCE2d_MakeTranslation.hxx>
 #include <Geom2d_Transformation.hxx>
 #include <gp_Pnt2d.hxx>
@@ -23,7 +22,8 @@
 //=========================================================================
 //   Creation d une translation 3d de Geom2d de vecteur de translation Vec
 //=========================================================================
-GCE2d_MakeTranslation::GCE2d_MakeTranslation(const gp_Vec2d&  Vec ) {
+GCE2d_MakeTranslation::GCE2d_MakeTranslation(const gp_Vec2d& Vec)
+{
   TheTranslation = new Geom2d_Transformation();
   TheTranslation->SetTranslation(Vec);
 }
@@ -33,10 +33,10 @@ GCE2d_MakeTranslation::GCE2d_MakeTranslation(const gp_Vec2d&  Vec ) {
 //   vecteur reliant Point1 a Point2.                                     +
 //=========================================================================
 
-GCE2d_MakeTranslation::GCE2d_MakeTranslation(const gp_Pnt2d&  Point1 ,
-					     const gp_Pnt2d&  Point2 ) {
+GCE2d_MakeTranslation::GCE2d_MakeTranslation(const gp_Pnt2d& Point1, const gp_Pnt2d& Point2)
+{
   TheTranslation = new Geom2d_Transformation();
-  TheTranslation->SetTranslation(Point1,Point2);
+  TheTranslation->SetTranslation(Point1, Point2);
 }
 
 const Handle(Geom2d_Transformation)& GCE2d_MakeTranslation::Value() const
