@@ -14,22 +14,23 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <GccInt_BElips.hxx>
 #include <gp_Elips2d.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(GccInt_BElips,GccInt_Bisec)
+IMPLEMENT_STANDARD_RTTIEXT(GccInt_BElips, GccInt_Bisec)
 
-GccInt_BElips::
-   GccInt_BElips(const gp_Elips2d& Ellipse) {
-   eli = gp_Elips2d(Ellipse);
- }
+GccInt_BElips::GccInt_BElips(const gp_Elips2d& Ellipse)
+{
+  eli = gp_Elips2d(Ellipse);
+}
 
-GccInt_IType GccInt_BElips::
-   ArcType() const {
-   return GccInt_Ell;
- }
+GccInt_IType GccInt_BElips::ArcType() const
+{
+  return GccInt_Ell;
+}
 
-gp_Elips2d GccInt_BElips::
-  Ellipse() const { return eli; }
+gp_Elips2d GccInt_BElips::Ellipse() const
+{
+  return eli;
+}
