@@ -14,30 +14,20 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <GeomFill_TgtField.hxx>
 #include <gp_Vec.hxx>
 #include <Law_BSpline.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(GeomFill_TgtField,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(GeomFill_TgtField, Standard_Transient)
 
-//=======================================================================
-//function : IsScalable
-//purpose  : 
-//=======================================================================
-Standard_Boolean GeomFill_TgtField::IsScalable() const 
+//=================================================================================================
+
+Standard_Boolean GeomFill_TgtField::IsScalable() const
 {
   return 0;
 }
 
-//=======================================================================
-//function : Scale
-//purpose  : 
-//=======================================================================
-
-void GeomFill_TgtField::Scale(const Handle(Law_BSpline)& )
-{
-}
-
+//=================================================================================================
 
+void GeomFill_TgtField::Scale(const Handle(Law_BSpline)&) {}
