@@ -18,7 +18,6 @@
 
 #include <IntPatch_WLine.hxx>
 #include <ApproxInt_SvSurfaces.hxx>
- 
 
 #define Handle_TheLine Handle(IntPatch_WLine)
 #define TheLine IntPatch_WLine
@@ -27,5 +26,4 @@
 #define TheSvSurfaces_hxx <ApproxInt_SvSurfaces.hxx>
 #define ApproxInt_MultiLine GeomInt_TheMultiLineOfWLApprox
 #define ApproxInt_MultiLine_hxx <GeomInt_TheMultiLineOfWLApprox.hxx>
-#include <ApproxInt_MultiLine.gxx>
-
+#include "../ApproxInt/ApproxInt_MultiLine.gxx"
