@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Geom2d_BezierCurve.hxx>
 #include <Geom2d_BoundedCurve.hxx>
 #include <Geom2d_BSplineCurve.hxx>
@@ -35,97 +34,107 @@
 //=============================================================================
 // Creation d' une BoundedCurve de prostep a partir d' une BoundedCurve de Geom
 //=============================================================================
-GeomToStep_MakeBoundedCurve::GeomToStep_MakeBoundedCurve ( const Handle(Geom_BoundedCurve)& C,
-                                                           const StepData_Factors& theLocalFactors)
+GeomToStep_MakeBoundedCurve::GeomToStep_MakeBoundedCurve(const Handle(Geom_BoundedCurve)& C,
+                                                         const StepData_Factors& theLocalFactors)
 {
   done = Standard_True;
 
-  if (C->IsKind(STANDARD_TYPE(Geom_BSplineCurve))) {
+  if (C->IsKind(STANDARD_TYPE(Geom_BSplineCurve)))
+  {
     Handle(Geom_BSplineCurve) Bspli = Handle(Geom_BSplineCurve)::DownCast(C);
     // UPDATE FMA 1-04-96
-    if (C->IsPeriodic()) {
-      Handle(Geom_BSplineCurve) newBspli = 
-	Handle(Geom_BSplineCurve)::DownCast(Bspli->Copy());
+    if (C->IsPeriodic())
+    {
+      Handle(Geom_BSplineCurve) newBspli = Handle(Geom_BSplineCurve)::DownCast(Bspli->Copy());
       newBspli->SetNotPeriodic();
       Bspli = newBspli;
     }
-    if ( Bspli->IsRational() ) {
-      GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve MkRatBSplineC(Bspli, theLocalFactors);
+    if (Bspli->IsRational())
+    {
+      GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve MkRatBSplineC(Bspli,
+                                                                                theLocalFactors);
       theBoundedCurve = MkRatBSplineC.Value();
     }
-    else {
+    else
+    {
       GeomToStep_MakeBSplineCurveWithKnots MkBSplineC(Bspli, theLocalFactors);
       theBoundedCurve = MkBSplineC.Value();
     }
   }
-  else if (C->IsKind(STANDARD_TYPE(Geom_BezierCurve))) {
-    Handle(Geom_BezierCurve) Cur = Handle(Geom_BezierCurve)::DownCast(C);
+  else if (C->IsKind(STANDARD_TYPE(Geom_BezierCurve)))
+  {
+    Handle(Geom_BezierCurve)  Cur   = Handle(Geom_BezierCurve)::DownCast(C);
     Handle(Geom_BSplineCurve) Bspli = GeomConvert::CurveToBSplineCurve(Cur);
-    if ( Bspli->IsRational() ) {
-      GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve MkRatBSplineC(Bspli, theLocalFactors);
+    if (Bspli->IsRational())
+    {
+      GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve MkRatBSplineC(Bspli,
+                                                                                theLocalFactors);
       theBoundedCurve = MkRatBSplineC.Value();
     }
-    else {
+    else
+    {
       GeomToStep_MakeBSplineCurveWithKnots MkBSplineC(Bspli, theLocalFactors);
       theBoundedCurve = MkBSplineC.Value();
     }
   }
-  else {
+  else
+  {
 #ifdef OCCT_DEBUG
-    std::cout<<"MakeBoundedCurve, type : "<<C->DynamicType()->Name()<<" not processed"<<std::endl;
+    std::cout << "MakeBoundedCurve, type : " << C->DynamicType()->Name() << " not processed"
+              << std::endl;
 #endif
     done = Standard_False;
   }
 }
-	 
+
 //=============================================================================
 // Creation d' une BoundedCurve de prostep a partir d' une BoundedCurve de
 // Geom2d
 //=============================================================================
 
-GeomToStep_MakeBoundedCurve::GeomToStep_MakeBoundedCurve ( const Handle(Geom2d_BoundedCurve)& C,
-                                                           const StepData_Factors& theLocalFactors)
+GeomToStep_MakeBoundedCurve::GeomToStep_MakeBoundedCurve(const Handle(Geom2d_BoundedCurve)& C,
+                                                         const StepData_Factors& theLocalFactors)
 {
   done = Standard_True;
   if (C->IsKind(STANDARD_TYPE(Geom2d_BSplineCurve)))
+  {
+    Handle(Geom2d_BSplineCurve) Bspli = Handle(Geom2d_BSplineCurve)::DownCast(C);
+    // UPDATE FMA 1-04-96
+    if (C->IsPeriodic())
     {
-      Handle(Geom2d_BSplineCurve) Bspli = 
-	Handle(Geom2d_BSplineCurve)::DownCast(C);
-      // UPDATE FMA 1-04-96
-      if (C->IsPeriodic()) {
-	Handle(Geom2d_BSplineCurve) newBspli = 
-	  Handle(Geom2d_BSplineCurve)::DownCast(Bspli->Copy());
-	newBspli->SetNotPeriodic();
-	Bspli = newBspli;
-      }
-      if ( Bspli->IsRational() ) {
-	GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve MkRatBSplineC(Bspli, theLocalFactors);
-	theBoundedCurve = MkRatBSplineC.Value();
-      }
-      else {
-	GeomToStep_MakeBSplineCurveWithKnots MkBSplineC(Bspli, theLocalFactors);
-	theBoundedCurve = MkBSplineC.Value();
-      }
+      Handle(Geom2d_BSplineCurve) newBspli = Handle(Geom2d_BSplineCurve)::DownCast(Bspli->Copy());
+      newBspli->SetNotPeriodic();
+      Bspli = newBspli;
     }
-  else if (C->IsKind(STANDARD_TYPE(Geom2d_BezierCurve))) {
-    Handle(Geom2d_BezierCurve) Cur = Handle(Geom2d_BezierCurve)::DownCast(C);
-    Handle(Geom2d_BSplineCurve) Bspli = 
-      Geom2dConvert::CurveToBSplineCurve(Cur);
+    if (Bspli->IsRational())
+    {
+      GeomToStep_MakeBSplineCurveWithKnotsAndRationalBSplineCurve MkRatBSplineC(Bspli,
+                                                                                theLocalFactors);
+      theBoundedCurve = MkRatBSplineC.Value();
+    }
+    else
+    {
+      GeomToStep_MakeBSplineCurveWithKnots MkBSplineC(Bspli, theLocalFactors);
+      theBoundedCurve = MkBSplineC.Value();
+    }
+  }
+  else if (C->IsKind(STANDARD_TYPE(Geom2d_BezierCurve)))
+  {
+    Handle(Geom2d_BezierCurve)           Cur   = Handle(Geom2d_BezierCurve)::DownCast(C);
+    Handle(Geom2d_BSplineCurve)          Bspli = Geom2dConvert::CurveToBSplineCurve(Cur);
     GeomToStep_MakeBSplineCurveWithKnots MkBSplineC(Bspli, theLocalFactors);
     theBoundedCurve = MkBSplineC.Value();
-    }
+  }
   else
     done = Standard_False;
-  
 }
 
 //=============================================================================
 // renvoi des valeurs
 //=============================================================================
 
-const Handle(StepGeom_BoundedCurve) &
-      GeomToStep_MakeBoundedCurve::Value() const
+const Handle(StepGeom_BoundedCurve)& GeomToStep_MakeBoundedCurve::Value() const
 {
-  StdFail_NotDone_Raise_if (!done, "GeomToStep_MakeBoundedCurve::Value() - no result");
+  StdFail_NotDone_Raise_if(!done, "GeomToStep_MakeBoundedCurve::Value() - no result");
   return theBoundedCurve;
 }
