@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Geom_ConicalSurface.hxx>
 #include <GeomToStep_MakeAxis2Placement3d.hxx>
 #include <GeomToStep_MakeConicalSurface.hxx>
@@ -29,35 +28,36 @@
 // Creation d' une conical_surface de prostep a partir d' une ConicalSurface
 // de Geom
 //=============================================================================
-GeomToStep_MakeConicalSurface::GeomToStep_MakeConicalSurface
-  ( const Handle(Geom_ConicalSurface)& CS, const StepData_Factors& theLocalFactors)
-	
+GeomToStep_MakeConicalSurface::GeomToStep_MakeConicalSurface(
+  const Handle(Geom_ConicalSurface)& CS,
+  const StepData_Factors&            theLocalFactors)
+
 {
-  Handle(StepGeom_ConicalSurface) CSstep = new StepGeom_ConicalSurface;
+  Handle(StepGeom_ConicalSurface)   CSstep = new StepGeom_ConicalSurface;
   Handle(StepGeom_Axis2Placement3d) aPosition;
-  Standard_Real aRadius, aSemiAngle;
-  
+  Standard_Real                     aRadius, aSemiAngle;
+
   GeomToStep_MakeAxis2Placement3d MkAxis(CS->Position(), theLocalFactors);
-  aPosition = MkAxis.Value();
-  aRadius = CS->RefRadius();
+  aPosition  = MkAxis.Value();
+  aRadius    = CS->RefRadius();
   aSemiAngle = CS->SemiAngle();
-  if (aSemiAngle < 0. || aSemiAngle > M_PI/2.) {
+  if (aSemiAngle < 0. || aSemiAngle > M_PI / 2.)
+  {
     throw Standard_DomainError("Conicalsurface not STEP conformant");
   }
-  
+
   Handle(TCollection_HAsciiString) name = new TCollection_HAsciiString("");
   CSstep->Init(name, aPosition, aRadius / theLocalFactors.LengthFactor(), aSemiAngle);
   theConicalSurface = CSstep;
-  done = Standard_True;
+  done              = Standard_True;
 }
 
 //=============================================================================
 // renvoi des valeurs
 //=============================================================================
 
-const Handle(StepGeom_ConicalSurface) &
-      GeomToStep_MakeConicalSurface::Value() const
+const Handle(StepGeom_ConicalSurface)& GeomToStep_MakeConicalSurface::Value() const
 {
-  StdFail_NotDone_Raise_if (!done, "GeomToStep_MakeConicalSurface::Value() - no result");
+  StdFail_NotDone_Raise_if(!done, "GeomToStep_MakeConicalSurface::Value() - no result");
   return theConicalSurface;
 }
