@@ -15,19 +15,18 @@
 // commercial license or contractual agreement.
 
 #ifndef No_Exception
-#define No_Exception
+  #define No_Exception
 #endif
 
-
 #include <HLRAlgo_EdgesBlock.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(HLRAlgo_EdgesBlock,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(HLRAlgo_EdgesBlock, Standard_Transient)
 
-//=======================================================================
-//function : HLRAlgo_EdgesBlock
-//purpose  : 
-//=======================================================================
-HLRAlgo_EdgesBlock::HLRAlgo_EdgesBlock (const Standard_Integer NbEdges) :
-  myEdges(1,NbEdges), myFlags(1,NbEdges)
-{}
+//=================================================================================================
+
+HLRAlgo_EdgesBlock::HLRAlgo_EdgesBlock(const Standard_Integer NbEdges)
+    : myEdges(1, NbEdges),
+      myFlags(1, NbEdges)
+{
+}
