@@ -21,7 +21,6 @@
 #include <IntRes2d_Domain.hxx>
 #include <Bnd_Box2d.hxx>
 #include <gp_Pnt2d.hxx>
- 
 
 #define TheCurve Standard_Address
 #define TheCurve_hxx <Standard_Address.hxx>
@@ -29,5 +28,4 @@
 #define TheCurveTool_hxx <HLRBRep_CurveTool.hxx>
 #define IntCurve_Polygon2dGen HLRBRep_ThePolygon2dOfTheIntPCurvePCurveOfCInter
 #define IntCurve_Polygon2dGen_hxx <HLRBRep_ThePolygon2dOfTheIntPCurvePCurveOfCInter.hxx>
-#include <IntCurve_Polygon2dGen.gxx>
-
+#include "../IntCurve/IntCurve_Polygon2dGen.gxx"
