@@ -21,7 +21,6 @@
 #include <gp_Pnt.hxx>
 #include <Bnd_Box.hxx>
 #include <gp_XYZ.hxx>
- 
 
 #define ThePSurface Standard_Address
 #define ThePSurface_hxx <Standard_Address.hxx>
@@ -29,5 +28,4 @@
 #define ThePSurfaceTool_hxx <HLRBRep_SurfaceTool.hxx>
 #define IntCurveSurface_Polyhedron HLRBRep_ThePolyhedronOfInterCSurf
 #define IntCurveSurface_Polyhedron_hxx <HLRBRep_ThePolyhedronOfInterCSurf.hxx>
-#include <IntCurveSurface_Polyhedron.gxx>
-
+#include "../IntCurveSurface/IntCurveSurface_Polyhedron.gxx"
