@@ -14,11 +14,12 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <IFSelect_SelectIncorrectEntities.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(IFSelect_SelectIncorrectEntities,IFSelect_SelectFlag)
+IMPLEMENT_STANDARD_RTTIEXT(IFSelect_SelectIncorrectEntities, IFSelect_SelectFlag)
 
-IFSelect_SelectIncorrectEntities::IFSelect_SelectIncorrectEntities ()
-    : IFSelect_SelectFlag ("Incorrect")    {  }
+IFSelect_SelectIncorrectEntities::IFSelect_SelectIncorrectEntities()
+    : IFSelect_SelectFlag("Incorrect")
+{
+}
