@@ -21,62 +21,61 @@
 #include <Standard_Type.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(IGESAppli_LevelToPWBLayerMap,IGESData_IGESEntity)
+IMPLEMENT_STANDARD_RTTIEXT(IGESAppli_LevelToPWBLayerMap, IGESData_IGESEntity)
 
-IGESAppli_LevelToPWBLayerMap::IGESAppli_LevelToPWBLayerMap ()    {  }
+IGESAppli_LevelToPWBLayerMap::IGESAppli_LevelToPWBLayerMap() {}
 
-
-    void  IGESAppli_LevelToPWBLayerMap::Init
-  (const Standard_Integer nbPropVal,
-   const Handle(TColStd_HArray1OfInteger)& allExchLevels,
-   const Handle(Interface_HArray1OfHAsciiString)& allNativeLevels,
-   const Handle(TColStd_HArray1OfInteger)& allPhysLevels,
-   const Handle(Interface_HArray1OfHAsciiString)& allExchIdents)
+void IGESAppli_LevelToPWBLayerMap::Init(
+  const Standard_Integer                         nbPropVal,
+  const Handle(TColStd_HArray1OfInteger)&        allExchLevels,
+  const Handle(Interface_HArray1OfHAsciiString)& allNativeLevels,
+  const Handle(TColStd_HArray1OfInteger)&        allPhysLevels,
+  const Handle(Interface_HArray1OfHAsciiString)& allExchIdents)
 {
   Standard_Integer num = allExchLevels->Length();
-  if ( allExchLevels->Lower()   != 1 ||
-      (allNativeLevels->Lower() != 1 || allNativeLevels->Length() != num) ||
-      (allPhysLevels->Lower()   != 1 || allPhysLevels->Length()   != num) ||
-      (allExchIdents->Lower()   != 1 || allExchIdents->Length()   != num) )
+  if (allExchLevels->Lower() != 1
+      || (allNativeLevels->Lower() != 1 || allNativeLevels->Length() != num)
+      || (allPhysLevels->Lower() != 1 || allPhysLevels->Length() != num)
+      || (allExchIdents->Lower() != 1 || allExchIdents->Length() != num))
     throw Standard_DimensionMismatch("IGESAppli_LevelToPWBLayerMap: Init");
   theNbPropertyValues        = nbPropVal;
   theExchangeFileLevelNumber = allExchLevels;
   theNativeLevel             = allNativeLevels;
   thePhysicalLayerNumber     = allPhysLevels;
   theExchangeFileLevelIdent  = allExchIdents;
-  InitTypeAndForm(406,24);
+  InitTypeAndForm(406, 24);
 }
 
-    Standard_Integer  IGESAppli_LevelToPWBLayerMap::NbPropertyValues () const
+Standard_Integer IGESAppli_LevelToPWBLayerMap::NbPropertyValues() const
 {
   return theNbPropertyValues;
 }
 
-    Standard_Integer  IGESAppli_LevelToPWBLayerMap::NbLevelToLayerDefs () const
+Standard_Integer IGESAppli_LevelToPWBLayerMap::NbLevelToLayerDefs() const
 {
   return theExchangeFileLevelNumber->Length();
 }
 
-    Standard_Integer  IGESAppli_LevelToPWBLayerMap::ExchangeFileLevelNumber
-  (const Standard_Integer Index) const
+Standard_Integer IGESAppli_LevelToPWBLayerMap::ExchangeFileLevelNumber(
+  const Standard_Integer Index) const
 {
   return theExchangeFileLevelNumber->Value(Index);
 }
 
-    Handle(TCollection_HAsciiString)  IGESAppli_LevelToPWBLayerMap::NativeLevel
-  (const Standard_Integer Index) const
+Handle(TCollection_HAsciiString) IGESAppli_LevelToPWBLayerMap::NativeLevel(
+  const Standard_Integer Index) const
 {
   return theNativeLevel->Value(Index);
 }
 
-    Standard_Integer  IGESAppli_LevelToPWBLayerMap::PhysicalLayerNumber
-  (const Standard_Integer Index) const
+Standard_Integer IGESAppli_LevelToPWBLayerMap::PhysicalLayerNumber(
+  const Standard_Integer Index) const
 {
   return thePhysicalLayerNumber->Value(Index);
 }
 
-    Handle(TCollection_HAsciiString)  IGESAppli_LevelToPWBLayerMap::ExchangeFileLevelIdent
-  (const Standard_Integer Index) const
+Handle(TCollection_HAsciiString) IGESAppli_LevelToPWBLayerMap::ExchangeFileLevelIdent(
+  const Standard_Integer Index) const
 {
   return theExchangeFileLevelIdent->Value(Index);
 }
