@@ -18,21 +18,10 @@
 
 #include <Standard_Type.hxx>
 
-
- 
-
-
-
-
-
-
-
-
 #define Handle_TheKey Handle(TColStd_HArray1OfInteger)
 #define TheKey TColStd_HArray1OfInteger
 #define TheKey_hxx <TColStd_HArray1OfInteger.hxx>
 #define Interface_JaggedArray IGESBasic_HArray1OfHArray1OfInteger
 #define Interface_JaggedArray_hxx <IGESBasic_HArray1OfHArray1OfInteger.hxx>
 #define Handle_Interface_JaggedArray Handle(IGESBasic_HArray1OfHArray1OfInteger)
-#include <Interface_JaggedArray.gxx>
-
+#include "../Interface/Interface_JaggedArray.gxx"
