@@ -13,19 +13,16 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <IGESControl_AlgoContainer.hxx>
 #include <IGESControl_ToolContainer.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(IGESControl_AlgoContainer,IGESToBRep_AlgoContainer)
+IMPLEMENT_STANDARD_RTTIEXT(IGESControl_AlgoContainer, IGESToBRep_AlgoContainer)
 
-//=======================================================================
-//function : IGESControl_AlgoContainer
-//purpose  : 
-//=======================================================================
-IGESControl_AlgoContainer::IGESControl_AlgoContainer():IGESToBRep_AlgoContainer()
+//=================================================================================================
+
+IGESControl_AlgoContainer::IGESControl_AlgoContainer()
+    : IGESToBRep_AlgoContainer()
 {
-  SetToolContainer (new IGESControl_ToolContainer);
+  SetToolContainer(new IGESControl_ToolContainer);
 }
-
