@@ -23,51 +23,49 @@
 #include <Standard_DimensionMismatch.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(IGESDimen_WitnessLine,IGESData_IGESEntity)
+IMPLEMENT_STANDARD_RTTIEXT(IGESDimen_WitnessLine, IGESData_IGESEntity)
 
-IGESDimen_WitnessLine::IGESDimen_WitnessLine ()    {  }
+IGESDimen_WitnessLine::IGESDimen_WitnessLine() {}
 
-
-    void  IGESDimen_WitnessLine::Init
-  (const Standard_Integer dataType, const Standard_Real aDisp,
-   const Handle(TColgp_HArray1OfXY)& dataPoints)
+void IGESDimen_WitnessLine::Init(const Standard_Integer            dataType,
+                                 const Standard_Real               aDisp,
+                                 const Handle(TColgp_HArray1OfXY)& dataPoints)
 {
   if (dataPoints->Lower() != 1)
     throw Standard_DimensionMismatch("IGESDimen_WitnessLine : Init");
   theDatatype      = dataType;
   theZDisplacement = aDisp;
   theDataPoints    = dataPoints;
-  InitTypeAndForm(106,40);
+  InitTypeAndForm(106, 40);
 }
 
-
-    Standard_Integer  IGESDimen_WitnessLine::Datatype () const 
+Standard_Integer IGESDimen_WitnessLine::Datatype() const
 {
   return theDatatype;
 }
 
-    Standard_Integer  IGESDimen_WitnessLine::NbPoints () const 
+Standard_Integer IGESDimen_WitnessLine::NbPoints() const
 {
   return theDataPoints->Length();
 }
 
-    Standard_Real  IGESDimen_WitnessLine::ZDisplacement () const 
+Standard_Real IGESDimen_WitnessLine::ZDisplacement() const
 {
   return theZDisplacement;
 }
 
-    gp_Pnt IGESDimen_WitnessLine::Point (const Standard_Integer Index) const 
+gp_Pnt IGESDimen_WitnessLine::Point(const Standard_Integer Index) const
 {
-  gp_XY tempXY = theDataPoints->Value(Index);
+  gp_XY  tempXY = theDataPoints->Value(Index);
   gp_Pnt point(tempXY.X(), tempXY.Y(), theZDisplacement);
   return point;
 }
 
-    gp_Pnt  IGESDimen_WitnessLine::TransformedPoint
-  (const Standard_Integer Index) const 
+gp_Pnt IGESDimen_WitnessLine::TransformedPoint(const Standard_Integer Index) const
 {
-  gp_XY point2d = theDataPoints->Value(Index);
+  gp_XY  point2d = theDataPoints->Value(Index);
   gp_XYZ point(point2d.X(), point2d.Y(), theZDisplacement);
-  if (HasTransf()) Location().Transforms(point);
+  if (HasTransf())
+    Location().Transforms(point);
   return gp_Pnt(point);
 }
