@@ -28,13 +28,12 @@
 #include <Interface_EntityIterator.hxx>
 #include <Interface_ShareTool.hxx>
 
-IGESGraph_ToolHighLight::IGESGraph_ToolHighLight ()    {  }
+IGESGraph_ToolHighLight::IGESGraph_ToolHighLight() {}
 
-
-void IGESGraph_ToolHighLight::ReadOwnParams
-  (const Handle(IGESGraph_HighLight)& ent,
-   const Handle(IGESData_IGESReaderData)& /*IR*/, IGESData_ParamReader& PR) const
-{ 
+void IGESGraph_ToolHighLight::ReadOwnParams(const Handle(IGESGraph_HighLight)& ent,
+                                            const Handle(IGESData_IGESReaderData)& /*IR*/,
+                                            IGESData_ParamReader& PR) const
+{
   Standard_Integer nbPropertyValues;
   Standard_Integer highLightStatus;
 
@@ -45,45 +44,45 @@ void IGESGraph_ToolHighLight::ReadOwnParams
 
   if (PR.DefinedElseSkip())
     // Reading highLightStatus(Integer)
-    PR.ReadInteger (PR.Current(), "Highlight flag", highLightStatus);
+    PR.ReadInteger(PR.Current(), "Highlight flag", highLightStatus);
   else
     highLightStatus = 0; // Default Value
 
-  DirChecker(ent).CheckTypeAndForm(PR.CCheck(),ent);
+  DirChecker(ent).CheckTypeAndForm(PR.CCheck(), ent);
   ent->Init(nbPropertyValues, highLightStatus);
 }
 
-void IGESGraph_ToolHighLight::WriteOwnParams
-  (const Handle(IGESGraph_HighLight)& ent, IGESData_IGESWriter& IW)  const
-{ 
-  IW.Send( ent->NbPropertyValues() );
-  IW.Send( ent->HighLightStatus() );
+void IGESGraph_ToolHighLight::WriteOwnParams(const Handle(IGESGraph_HighLight)& ent,
+                                             IGESData_IGESWriter&               IW) const
+{
+  IW.Send(ent->NbPropertyValues());
+  IW.Send(ent->HighLightStatus());
 }
 
-void  IGESGraph_ToolHighLight::OwnShared
-  (const Handle(IGESGraph_HighLight)& /*ent*/, Interface_EntityIterator& /*iter*/) const
+void IGESGraph_ToolHighLight::OwnShared(const Handle(IGESGraph_HighLight)& /*ent*/,
+                                        Interface_EntityIterator& /*iter*/) const
 {
 }
 
-void IGESGraph_ToolHighLight::OwnCopy
-  (const Handle(IGESGraph_HighLight)& another,
-   const Handle(IGESGraph_HighLight)& ent, Interface_CopyTool& /*TC*/) const
+void IGESGraph_ToolHighLight::OwnCopy(const Handle(IGESGraph_HighLight)& another,
+                                      const Handle(IGESGraph_HighLight)& ent,
+                                      Interface_CopyTool& /*TC*/) const
 {
-  ent->Init(1,another->HighLightStatus());
+  ent->Init(1, another->HighLightStatus());
 }
 
-Standard_Boolean  IGESGraph_ToolHighLight::OwnCorrect
-  (const Handle(IGESGraph_HighLight)& ent) const
+Standard_Boolean IGESGraph_ToolHighLight::OwnCorrect(const Handle(IGESGraph_HighLight)& ent) const
 {
   Standard_Boolean res = (ent->NbPropertyValues() != 1);
-  if (res) ent->Init(1,ent->HighLightStatus());    // nbpropertyvalues=1
+  if (res)
+    ent->Init(1, ent->HighLightStatus()); // nbpropertyvalues=1
   return res;
 }
 
-IGESData_DirChecker IGESGraph_ToolHighLight::DirChecker
-  (const Handle(IGESGraph_HighLight)& /*ent*/)  const
-{ 
-  IGESData_DirChecker DC (406, 20);
+IGESData_DirChecker IGESGraph_ToolHighLight::DirChecker(
+  const Handle(IGESGraph_HighLight)& /*ent*/) const
+{
+  IGESData_DirChecker DC(406, 20);
   DC.Structure(IGESData_DefVoid);
   DC.LineFont(IGESData_DefVoid);
   DC.LineWeight(IGESData_DefVoid);
@@ -94,17 +93,18 @@ IGESData_DirChecker IGESGraph_ToolHighLight::DirChecker
   return DC;
 }
 
-void IGESGraph_ToolHighLight::OwnCheck
-  (const Handle(IGESGraph_HighLight)& ent,
-   const Interface_ShareTool& , Handle(Interface_Check)& ach)  const
+void IGESGraph_ToolHighLight::OwnCheck(const Handle(IGESGraph_HighLight)& ent,
+                                       const Interface_ShareTool&,
+                                       Handle(Interface_Check)& ach) const
 {
   if (ent->NbPropertyValues() != 1)
     ach->AddFail("No. of Property values : Value != 1");
 }
 
-void IGESGraph_ToolHighLight::OwnDump
-  (const Handle(IGESGraph_HighLight)& ent, const IGESData_IGESDumper& /*dumper*/,
-   Standard_OStream& S, const Standard_Integer /*level*/)  const
+void IGESGraph_ToolHighLight::OwnDump(const Handle(IGESGraph_HighLight)& ent,
+                                      const IGESData_IGESDumper& /*dumper*/,
+                                      Standard_OStream& S,
+                                      const Standard_Integer /*level*/) const
 {
   S << "IGESGraph_HighLight\n"
     << "No. of property values : " << ent->NbPropertyValues() << "\n"
