@@ -35,19 +35,11 @@
 #include <TColgp_HArray1OfXYZ.hxx>
 
 // MGE 03/08/98
-//=======================================================================
-//function : IGESSolid_ToolVertexList
-//purpose  : 
-//=======================================================================
-IGESSolid_ToolVertexList::IGESSolid_ToolVertexList ()
-{
-}
+//=================================================================================================
 
+IGESSolid_ToolVertexList::IGESSolid_ToolVertexList() {}
 
-//=======================================================================
-//function : ReadOwnParams
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void IGESSolid_ToolVertexList::ReadOwnParams(const Handle(IGESSolid_VertexList)& ent,
                                              const Handle(IGESData_IGESReaderData)& /* IR */,
@@ -56,79 +48,70 @@ void IGESSolid_ToolVertexList::ReadOwnParams(const Handle(IGESSolid_VertexList)&
   // MGE 03/08/98
   // Building of messages
   //========================================
-//  Message_Msg Msg182("XSTEP_182");
-//  Message_Msg Msg183("XSTEP_183");
+  //  Message_Msg Msg182("XSTEP_182");
+  //  Message_Msg Msg183("XSTEP_183");
   //========================================
 
-  //Standard_Boolean st; //szv#4:S4163:12Mar99 not needed
-  Standard_Integer nbitems = 0; //szv#4:S4163:12Mar99 `i` moved in for
-  //gp_XYZ anXYZ; //szv#4:S4163:12Mar99 moved down
+  // Standard_Boolean st; //szv#4:S4163:12Mar99 not needed
+  Standard_Integer nbitems = 0; // szv#4:S4163:12Mar99 `i` moved in for
+  // gp_XYZ anXYZ; //szv#4:S4163:12Mar99 moved down
   Handle(TColgp_HArray1OfXYZ) tempVertices;
 
-  //st = PR.ReadInteger(PR.Current(), Msg182, nbitems); //szv#4:S4163:12Mar99 moved in if
-  //st = PR.ReadInteger(PR.Current(), "Number of Vertices", nbitems);
+  // st = PR.ReadInteger(PR.Current(), Msg182, nbitems); //szv#4:S4163:12Mar99 moved in if
+  // st = PR.ReadInteger(PR.Current(), "Number of Vertices", nbitems);
   Standard_Boolean sb = PR.ReadInteger(PR.Current(), nbitems);
-  if (sb && (nbitems > 0)) {
-    
+  if (sb && (nbitems > 0))
+  {
+
     Message_Msg Msg183("XSTEP_183");
-    
+
     tempVertices = new TColgp_HArray1OfXYZ(1, nbitems);
-    
+
     gp_XYZ anXYZ;
     for (Standard_Integer i = 1; i <= nbitems; i++)
-      {
-	//st = PR.ReadXYZ(PR.CurrentList(1, 3), Msg183, anXYZ); //szv#4:S4163:12Mar99 moved in if
-	//st = PR.ReadXYZ(PR.CurrentList(1, 3), "Vertices", anXYZ);
-	if (PR.ReadXYZ(PR.CurrentList(1, 3), Msg183, anXYZ))
-	  tempVertices->SetValue(i, anXYZ);
-      }
+    {
+      // st = PR.ReadXYZ(PR.CurrentList(1, 3), Msg183, anXYZ); //szv#4:S4163:12Mar99 moved in if
+      // st = PR.ReadXYZ(PR.CurrentList(1, 3), "Vertices", anXYZ);
+      if (PR.ReadXYZ(PR.CurrentList(1, 3), Msg183, anXYZ))
+        tempVertices->SetValue(i, anXYZ);
+    }
   }
-  else {
+  else
+  {
     Message_Msg Msg182("XSTEP_182");
     PR.SendFail(Msg182);
   }
 
-  DirChecker(ent).CheckTypeAndForm(PR.CCheck(),ent);
-  if (nbitems > 0) ent->Init (tempVertices);
+  DirChecker(ent).CheckTypeAndForm(PR.CCheck(), ent);
+  if (nbitems > 0)
+    ent->Init(tempVertices);
 }
 
-
-//=======================================================================
-//function : WriteOwnParams
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void IGESSolid_ToolVertexList::WriteOwnParams(const Handle(IGESSolid_VertexList)& ent,
-                                              IGESData_IGESWriter& IW) const
+                                              IGESData_IGESWriter&                IW) const
 {
   Standard_Integer nbitems = ent->NbVertices();
   Standard_Integer i;
 
   IW.Send(nbitems);
-  for (i = 1; i <= nbitems; i ++)
-    {
-      IW.Send(ent->Vertex(i).X());
-      IW.Send(ent->Vertex(i).Y());
-      IW.Send(ent->Vertex(i).Z());
-    }
+  for (i = 1; i <= nbitems; i++)
+  {
+    IW.Send(ent->Vertex(i).X());
+    IW.Send(ent->Vertex(i).Y());
+    IW.Send(ent->Vertex(i).Z());
+  }
 }
 
-
-//=======================================================================
-//function : OwnShared
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void IGESSolid_ToolVertexList::OwnShared(const Handle(IGESSolid_VertexList)& /* ent */,
                                          Interface_EntityIterator& /* iter */) const
 {
 }
 
-
-//=======================================================================
-//function : OwnCopy
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void IGESSolid_ToolVertexList::OwnCopy(const Handle(IGESSolid_VertexList)& another,
                                        const Handle(IGESSolid_VertexList)& ent,
@@ -136,43 +119,34 @@ void IGESSolid_ToolVertexList::OwnCopy(const Handle(IGESSolid_VertexList)& anoth
 {
   Standard_Integer nbitems, i;
 
-  nbitems = another->NbVertices();
-  Handle(TColgp_HArray1OfXYZ) tempVertices = new
-    TColgp_HArray1OfXYZ(1, nbitems);
+  nbitems                                  = another->NbVertices();
+  Handle(TColgp_HArray1OfXYZ) tempVertices = new TColgp_HArray1OfXYZ(1, nbitems);
 
-  for (i=1; i<=nbitems; i++)
-    {
-      tempVertices->SetValue(i, another->Vertex(i).XYZ());
-    }
+  for (i = 1; i <= nbitems; i++)
+  {
+    tempVertices->SetValue(i, another->Vertex(i).XYZ());
+  }
   ent->Init(tempVertices);
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : DirChecker
-//purpose  : 
-//=======================================================================
-
-IGESData_DirChecker IGESSolid_ToolVertexList::DirChecker
-  (const Handle(IGESSolid_VertexList)& /* ent */ ) const
+IGESData_DirChecker IGESSolid_ToolVertexList::DirChecker(
+  const Handle(IGESSolid_VertexList)& /* ent */) const
 {
   IGESData_DirChecker DC(502, 1);
 
-  DC.Structure  (IGESData_DefVoid);
-  DC.LineFont   (IGESData_DefVoid);
-  DC.LineWeight (IGESData_DefVoid);
-  DC.Color      (IGESData_DefAny);
+  DC.Structure(IGESData_DefVoid);
+  DC.LineFont(IGESData_DefVoid);
+  DC.LineWeight(IGESData_DefVoid);
+  DC.Color(IGESData_DefAny);
 
-  DC.SubordinateStatusRequired (1);
-  DC.HierarchyStatusIgnored ();
+  DC.SubordinateStatusRequired(1);
+  DC.HierarchyStatusIgnored();
   return DC;
 }
 
-
-//=======================================================================
-//function : OwnCheck
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void IGESSolid_ToolVertexList::OwnCheck(const Handle(IGESSolid_VertexList)& ent,
                                         const Interface_ShareTool&,
@@ -181,28 +155,25 @@ void IGESSolid_ToolVertexList::OwnCheck(const Handle(IGESSolid_VertexList)& ent,
   // MGE 03/08/98
   // Building of messages
   //========================================
-  //Message_Msg Msg182("XSTEP_182");
+  // Message_Msg Msg182("XSTEP_182");
   //========================================
 
-  if (ent->NbVertices() <= 0) {
+  if (ent->NbVertices() <= 0)
+  {
     Message_Msg Msg182("XSTEP_182");
     ach->SendFail(Msg182);
   }
 }
 
-
-//=======================================================================
-//function : OwnDump
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
 void IGESSolid_ToolVertexList::OwnDump(const Handle(IGESSolid_VertexList)& ent,
                                        const IGESData_IGESDumper& /* dumper */,
-                                       Standard_OStream& S,
+                                       Standard_OStream&      S,
                                        const Standard_Integer level) const
 {
   S << "IGESSolid_VertexList\n"
     << "Vertices : ";
-  IGESData_DumpListXYZL(S,level,1, ent->NbVertices(),ent->Vertex,ent->Location());
+  IGESData_DumpListXYZL(S, level, 1, ent->NbVertices(), ent->Vertex, ent->Location());
   S << std::endl;
 }
