@@ -1,8 +1,8 @@
-// Created on: 2011-11-15 
+// Created on: 2011-11-15
 // Created by: Roman KOZLOV
-// Copyright (c) 2001-2012 OPEN CASCADE SAS 
-// 
-//This file is part of Open CASCADE Technology software library.
+// Copyright (c) 2001-2012 OPEN CASCADE SAS
+//
+// This file is part of Open CASCADE Technology software library.
 //
 // This library is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License version 2.1 as published
@@ -16,47 +16,47 @@
 #include <IVtkTools_DisplayModeFilter.hxx>
 #include <IVtkVTK_ShapeData.hxx>
 
-// prevent disabling some MSVC warning messages by VTK headers 
+// prevent disabling some MSVC warning messages by VTK headers
 #ifdef _MSC_VER
-#pragma warning(push)
+  #pragma warning(push)
 #endif
 #include <vtkInformation.h>
 #include <vtkInformationVector.h>
 #include <vtkObjectFactory.h>
 #ifdef _MSC_VER
-#pragma warning(pop)
+  #pragma warning(pop)
 #endif
 
 vtkStandardNewMacro(IVtkTools_DisplayModeFilter)
 
-//============================================================================
-// Method: Constructor
-// Purpose:
-//============================================================================
-IVtkTools_DisplayModeFilter::IVtkTools_DisplayModeFilter()
-: myDisplayMode (DM_Wireframe),
-  myDoDisplaySharedVertices (false),
-  myDrawFaceBoundaries (false),
-  myIsSmoothShading (true)
+  //============================================================================
+  // Method: Constructor
+  // Purpose:
+  //============================================================================
+  IVtkTools_DisplayModeFilter::IVtkTools_DisplayModeFilter()
+    : myDisplayMode(DM_Wireframe),
+      myDoDisplaySharedVertices(false),
+      myDrawFaceBoundaries(false),
+      myIsSmoothShading(true)
 {
   // Filter according to values in subshapes types array.
   myIdsArrayName = IVtkVTK_ShapeData::ARRNAME_MESH_TYPES();
 
   IVtk_IdTypeMap aTypes;
 
-  aTypes.Add (MT_IsoLine);
-  aTypes.Add (MT_FreeVertex);
-  aTypes.Add (MT_FreeEdge);
-  aTypes.Add (MT_BoundaryEdge);
-  aTypes.Add (MT_SharedEdge);
-  aTypes.Add (MT_SeamEdge);
-  aTypes.Add (MT_WireFrameFace);
+  aTypes.Add(MT_IsoLine);
+  aTypes.Add(MT_FreeVertex);
+  aTypes.Add(MT_FreeEdge);
+  aTypes.Add(MT_BoundaryEdge);
+  aTypes.Add(MT_SharedEdge);
+  aTypes.Add(MT_SeamEdge);
+  aTypes.Add(MT_WireFrameFace);
 
   myModesDefinition[DM_Wireframe] = aTypes;
 
   aTypes.Clear();
-  aTypes.Add (MT_FreeVertex);
-  aTypes.Add (MT_ShadedFace);
+  aTypes.Add(MT_FreeVertex);
+  aTypes.Add(MT_ShadedFace);
 
   myModesDefinition[DM_Shading] = aTypes;
 }
@@ -65,31 +65,29 @@ IVtkTools_DisplayModeFilter::IVtkTools_DisplayModeFilter()
 // Method: Destructor
 // Purpose:
 //============================================================================
-IVtkTools_DisplayModeFilter::~IVtkTools_DisplayModeFilter()
-{
-}
+IVtkTools_DisplayModeFilter::~IVtkTools_DisplayModeFilter() {}
 
 //============================================================================
 // Method: RequestData
 // Purpose: Filters cells according to the selected display mode by mesh
 //          parts types.
 //============================================================================
-int IVtkTools_DisplayModeFilter::RequestData (vtkInformation        *theRequest,
-                                              vtkInformationVector **theInputVector,
-                                              vtkInformationVector  *theOutputVector)
+int IVtkTools_DisplayModeFilter::RequestData(vtkInformation*        theRequest,
+                                             vtkInformationVector** theInputVector,
+                                             vtkInformationVector*  theOutputVector)
 {
-  SetData (myModesDefinition[myDisplayMode]);
+  SetData(myModesDefinition[myDisplayMode]);
   myToCopyNormals = myIsSmoothShading && (myDisplayMode == DM_Shading);
-  return Superclass::RequestData (theRequest, theInputVector, theOutputVector);
+  return Superclass::RequestData(theRequest, theInputVector, theOutputVector);
 }
 
 //============================================================================
 // Method: PrintSelf
 // Purpose:
 //============================================================================
-void IVtkTools_DisplayModeFilter::PrintSelf (std::ostream& theOs, vtkIndent theIndent)
+void IVtkTools_DisplayModeFilter::PrintSelf(std::ostream& theOs, vtkIndent theIndent)
 {
-  this->Superclass::PrintSelf (theOs, theIndent);
+  this->Superclass::PrintSelf(theOs, theIndent);
   theOs << theIndent << "IVtkTools_DisplayModeFilter: display mode = ";
   if (myDisplayMode == DM_Wireframe)
   {
@@ -105,7 +103,7 @@ void IVtkTools_DisplayModeFilter::PrintSelf (std::ostream& theOs, vtkIndent theI
 // Method: SetDisplaySharedVertices
 // Purpose:
 //============================================================================
-void IVtkTools_DisplayModeFilter::SetDisplaySharedVertices (const bool theDoDisplay)
+void IVtkTools_DisplayModeFilter::SetDisplaySharedVertices(const bool theDoDisplay)
 {
   if (myDoDisplaySharedVertices != theDoDisplay)
   {
@@ -116,11 +114,11 @@ void IVtkTools_DisplayModeFilter::SetDisplaySharedVertices (const bool theDoDisp
       aModeTypes = myModesDefinition[i];
       if (theDoDisplay && !aModeTypes.Contains(MT_SharedVertex))
       {
-        aModeTypes.Add (MT_SharedVertex);
+        aModeTypes.Add(MT_SharedVertex);
       }
-      else if (!theDoDisplay && aModeTypes.Contains (MT_SharedVertex))
+      else if (!theDoDisplay && aModeTypes.Contains(MT_SharedVertex))
       {
-        aModeTypes.Remove (MT_SharedVertex);
+        aModeTypes.Remove(MT_SharedVertex);
       }
       myModesDefinition[i] = aModeTypes;
     }
@@ -145,7 +143,7 @@ void IVtkTools_DisplayModeFilter::SetDisplayMode(const IVtk_DisplayMode theMode)
 // Method: GetDisplayMode
 // Purpose:
 //============================================================================
-IVtk_DisplayMode IVtkTools_DisplayModeFilter::GetDisplayMode () const
+IVtk_DisplayMode IVtkTools_DisplayModeFilter::GetDisplayMode() const
 {
   return myDisplayMode;
 }
@@ -163,7 +161,8 @@ const IVtk_IdTypeMap& IVtkTools_DisplayModeFilter::MeshTypesForMode(IVtk_Display
 // Method: setMeshTypesForMode
 // Purpose:
 //============================================================================
-void IVtkTools_DisplayModeFilter::SetMeshTypesForMode(IVtk_DisplayMode theMode, const IVtk_IdTypeMap& theMeshTypes)
+void IVtkTools_DisplayModeFilter::SetMeshTypesForMode(IVtk_DisplayMode      theMode,
+                                                      const IVtk_IdTypeMap& theMeshTypes)
 {
   myModesDefinition[theMode] = theMeshTypes;
   Modified();
@@ -176,11 +175,13 @@ void IVtkTools_DisplayModeFilter::SetMeshTypesForMode(IVtk_DisplayMode theMode,
 void IVtkTools_DisplayModeFilter::SetFaceBoundaryDraw(bool theToDraw)
 {
   myDrawFaceBoundaries = theToDraw;
-  if (theToDraw) {
+  if (theToDraw)
+  {
     myModesDefinition[DM_Shading].Add(MT_BoundaryEdge);
     myModesDefinition[DM_Shading].Add(MT_SharedEdge);
   }
-  else {
+  else
+  {
     myModesDefinition[DM_Shading].Remove(MT_BoundaryEdge);
     myModesDefinition[DM_Shading].Remove(MT_SharedEdge);
   }
@@ -191,7 +192,7 @@ void IVtkTools_DisplayModeFilter::SetFaceBoundaryDraw(bool theToDraw)
 // Method: SetSmoothShading
 // Purpose:
 //============================================================================
-void IVtkTools_DisplayModeFilter::SetSmoothShading (bool theIsSmooth)
+void IVtkTools_DisplayModeFilter::SetSmoothShading(bool theIsSmooth)
 {
   if (myIsSmoothShading != theIsSmooth)
   {
