@@ -19,7 +19,6 @@
 #include <IntCurve_IConicTool.hxx>
 #include <IntCurve_PConic.hxx>
 #include <IntCurve_PConicTool.hxx>
- 
 
 #define ImpTool IntCurve_IConicTool
 #define ImpTool_hxx <IntCurve_IConicTool.hxx>
@@ -29,5 +28,4 @@
 #define ParTool_hxx <IntCurve_PConicTool.hxx>
 #define IntImpParGen_ImpParTool IntCurve_MyImpParToolOfIntImpConicParConic
 #define IntImpParGen_ImpParTool_hxx <IntCurve_MyImpParToolOfIntImpConicParConic.hxx>
-#include <IntImpParGen_ImpParTool.gxx>
-
+#include "../IntImpParGen/IntImpParGen_ImpParTool.gxx"
