@@ -14,53 +14,64 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <IntCurveSurface_IntersectionSegment.hxx>
 
-IntCurveSurface_IntersectionSegment::IntCurveSurface_IntersectionSegment() 
-{ }
+IntCurveSurface_IntersectionSegment::IntCurveSurface_IntersectionSegment() {}
+
 //================================================================================
-IntCurveSurface_IntersectionSegment::IntCurveSurface_IntersectionSegment(const IntCurveSurface_IntersectionPoint& P1,
-									 const IntCurveSurface_IntersectionPoint& P2):
-       myP1(P1),myP2(P2)
-{ 
-} 
-//================================================================================
-void IntCurveSurface_IntersectionSegment::SetValues(const IntCurveSurface_IntersectionPoint& P1,
-						    const IntCurveSurface_IntersectionPoint& P2) { 
-  myP1 = P1; 
-  myP2 = P2;
-} 
-//================================================================================
-void IntCurveSurface_IntersectionSegment::Values(IntCurveSurface_IntersectionPoint& P1,
-						 IntCurveSurface_IntersectionPoint& P2) const
-{ 
-  P1 = myP1; 
-  P2 = myP2;
-} 
-//================================================================================
-void IntCurveSurface_IntersectionSegment::FirstPoint(IntCurveSurface_IntersectionPoint& P1) const { 
-  P1 = myP1;
-}
-//================================================================================
-void IntCurveSurface_IntersectionSegment::SecondPoint(IntCurveSurface_IntersectionPoint& P2) const { 
-  P2 = myP2;
-}
-//================================================================================
-const IntCurveSurface_IntersectionPoint &
-  IntCurveSurface_IntersectionSegment::FirstPoint() const { 
-  return(myP1);
-}
-//================================================================================
-const IntCurveSurface_IntersectionPoint &
-  IntCurveSurface_IntersectionSegment::SecondPoint() const { 
-  return(myP2);
-}
-//================================================================================
-void IntCurveSurface_IntersectionSegment::Dump() const { 
-  std::cout<<"\nIntersectionSegment : "<<std::endl;
-  myP1.Dump();
-  myP2.Dump();
-  std::cout<<std::endl;
+IntCurveSurface_IntersectionSegment::IntCurveSurface_IntersectionSegment(
+  const IntCurveSurface_IntersectionPoint& P1,
+  const IntCurveSurface_IntersectionPoint& P2)
+    : myP1(P1),
+      myP2(P2)
+{
 }
 
+//================================================================================
+void IntCurveSurface_IntersectionSegment::SetValues(const IntCurveSurface_IntersectionPoint& P1,
+                                                    const IntCurveSurface_IntersectionPoint& P2)
+{
+  myP1 = P1;
+  myP2 = P2;
+}
+
+//================================================================================
+void IntCurveSurface_IntersectionSegment::Values(IntCurveSurface_IntersectionPoint& P1,
+                                                 IntCurveSurface_IntersectionPoint& P2) const
+{
+  P1 = myP1;
+  P2 = myP2;
+}
+
+//================================================================================
+void IntCurveSurface_IntersectionSegment::FirstPoint(IntCurveSurface_IntersectionPoint& P1) const
+{
+  P1 = myP1;
+}
+
+//================================================================================
+void IntCurveSurface_IntersectionSegment::SecondPoint(IntCurveSurface_IntersectionPoint& P2) const
+{
+  P2 = myP2;
+}
+
+//================================================================================
+const IntCurveSurface_IntersectionPoint& IntCurveSurface_IntersectionSegment::FirstPoint() const
+{
+  return (myP1);
+}
+
+//================================================================================
+const IntCurveSurface_IntersectionPoint& IntCurveSurface_IntersectionSegment::SecondPoint() const
+{
+  return (myP2);
+}
+
+//================================================================================
+void IntCurveSurface_IntersectionSegment::Dump() const
+{
+  std::cout << "\nIntersectionSegment : " << std::endl;
+  myP1.Dump();
+  myP2.Dump();
+  std::cout << std::endl;
+}
