@@ -11,22 +11,23 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <MoniTool_SignText.hxx>
 #include <Standard_Transient.hxx>
 #include <Standard_Type.hxx>
 #include <TCollection_AsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(MoniTool_SignText,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(MoniTool_SignText, Standard_Transient)
 
-TCollection_AsciiString  MoniTool_SignText::TextAlone
-  (const Handle(Standard_Transient)& ent) const
+TCollection_AsciiString MoniTool_SignText::TextAlone(const Handle(Standard_Transient)& ent) const
 {
-  Handle(Standard_Transient) nulctx;  // no context
-  TCollection_AsciiString atext = Text (ent,nulctx);
-  if (atext.Length() == 0) {
-    if (ent.IsNull()) atext.AssignCat ("(NULL)");
-    else              atext.AssignCat (ent->DynamicType()->Name());
+  Handle(Standard_Transient) nulctx; // no context
+  TCollection_AsciiString    atext = Text(ent, nulctx);
+  if (atext.Length() == 0)
+  {
+    if (ent.IsNull())
+      atext.AssignCat("(NULL)");
+    else
+      atext.AssignCat(ent->DynamicType()->Name());
   }
   return atext;
 }
