@@ -11,36 +11,44 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <MoniTool_DataInfo.hxx>
 #include <MoniTool_TransientElem.hxx>
 #include <Standard_Integer.hxx>
 #include <Standard_Transient.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(MoniTool_TransientElem,MoniTool_Element)
+IMPLEMENT_STANDARD_RTTIEXT(MoniTool_TransientElem, MoniTool_Element)
 
-MoniTool_TransientElem::MoniTool_TransientElem (const Handle(Standard_Transient)& akey)
-    : theval (akey)
-{  SetHashCode ( std::hash<Handle(Standard_Transient)>{}(akey));  }
-
-
-    const Handle(Standard_Transient)&  MoniTool_TransientElem::Value () const
-      {  return theval;  }
-
-    Standard_Boolean  MoniTool_TransientElem::Equates
-  (const Handle(MoniTool_Element)& other) const
+MoniTool_TransientElem::MoniTool_TransientElem(const Handle(Standard_Transient)& akey)
+    : theval(akey)
 {
-  if (other.IsNull()) return Standard_False;
-  if (GetHashCode() != other->GetHashCode()) return Standard_False;
-  if (other->DynamicType() != DynamicType()) return Standard_False;
+  SetHashCode(std::hash<Handle(Standard_Transient)>{}(akey));
+}
+
+const Handle(Standard_Transient)& MoniTool_TransientElem::Value() const
+{
+  return theval;
+}
+
+Standard_Boolean MoniTool_TransientElem::Equates(const Handle(MoniTool_Element)& other) const
+{
+  if (other.IsNull())
+    return Standard_False;
+  if (GetHashCode() != other->GetHashCode())
+    return Standard_False;
+  if (other->DynamicType() != DynamicType())
+    return Standard_False;
   Handle(MoniTool_TransientElem) another = Handle(MoniTool_TransientElem)::DownCast(other);
-//  return (theval == another->Value());
+  //  return (theval == another->Value());
   return theval == another->Value();
 }
 
-    Handle(Standard_Type)  MoniTool_TransientElem::ValueType () const
-      {  return MoniTool_DataInfo::Type(theval);  }
+Handle(Standard_Type) MoniTool_TransientElem::ValueType() const
+{
+  return MoniTool_DataInfo::Type(theval);
+}
 
-    Standard_CString  MoniTool_TransientElem::ValueTypeName () const
-      {  return MoniTool_DataInfo::TypeName(theval);  }
+Standard_CString MoniTool_TransientElem::ValueTypeName() const
+{
+  return MoniTool_DataInfo::TypeName(theval);
+}
