@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <CDM_Application.hxx>
 #include <CDM_Document.hxx>
 #include <FSD_BinaryFile.hxx>
@@ -26,47 +25,47 @@
 #include <Resource_Manager.hxx>
 #include <TCollection_AsciiString.hxx>
 
-//=======================================================================
-//function : FileDriverType
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
-PCDM_TypeOfFileDriver PCDM::FileDriverType(const TCollection_AsciiString& aFileName, Handle(Storage_BaseDriver)& aBaseDriver)
+PCDM_TypeOfFileDriver PCDM::FileDriverType(const TCollection_AsciiString& aFileName,
+                                           Handle(Storage_BaseDriver)&    aBaseDriver)
 {
-  if(FSD_CmpFile::IsGoodFileType(aFileName) == Storage_VSOk) {
-    aBaseDriver=new FSD_CmpFile;
+  if (FSD_CmpFile::IsGoodFileType(aFileName) == Storage_VSOk)
+  {
+    aBaseDriver = new FSD_CmpFile;
     return PCDM_TOFD_CmpFile;
   }
-  else if(FSD_File::IsGoodFileType(aFileName) == Storage_VSOk) {
-    aBaseDriver=new FSD_File;
+  else if (FSD_File::IsGoodFileType(aFileName) == Storage_VSOk)
+  {
+    aBaseDriver = new FSD_File;
     return PCDM_TOFD_File;
   }
-  else if(FSD_BinaryFile::IsGoodFileType(aFileName) == Storage_VSOk) {
-    aBaseDriver=new FSD_BinaryFile;
+  else if (FSD_BinaryFile::IsGoodFileType(aFileName) == Storage_VSOk)
+  {
+    aBaseDriver = new FSD_BinaryFile;
     return PCDM_TOFD_File;
   }
-  else {
-    aBaseDriver=NULL;
+  else
+  {
+    aBaseDriver = NULL;
     return PCDM_TOFD_Unknown;
   }
 }
 
-//=======================================================================
-//function : FileDriverType
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
-PCDM_TypeOfFileDriver PCDM::FileDriverType (Standard_IStream& theIStream, Handle(Storage_BaseDriver)& theBaseDriver)
+PCDM_TypeOfFileDriver PCDM::FileDriverType(Standard_IStream&           theIStream,
+                                           Handle(Storage_BaseDriver)& theBaseDriver)
 {
   TCollection_AsciiString aReadMagicNumber;
 
   // read magic number from the file
   if (theIStream.good())
   {
-    aReadMagicNumber = Storage_BaseDriver::ReadMagicNumber (theIStream);
+    aReadMagicNumber = Storage_BaseDriver::ReadMagicNumber(theIStream);
   }
 
-  if(aReadMagicNumber == FSD_CmpFile::MagicNumber())
+  if (aReadMagicNumber == FSD_CmpFile::MagicNumber())
   {
     theBaseDriver = new FSD_CmpFile;
     return PCDM_TOFD_CmpFile;
@@ -81,7 +80,7 @@ PCDM_TypeOfFileDriver PCDM::FileDriverType (Standard_IStream& theIStream, Handle
     theBaseDriver = new FSD_BinaryFile;
     return PCDM_TOFD_File;
   }
-  else if (aReadMagicNumber.Search ("<?xml") != -1)
+  else if (aReadMagicNumber.Search("<?xml") != -1)
   {
     // skip xml declaration
     char aChar = ' ';
@@ -96,4 +95,3 @@ PCDM_TypeOfFileDriver PCDM::FileDriverType (Standard_IStream& theIStream, Handle
   theBaseDriver = NULL;
   return PCDM_TOFD_Unknown;
 }
-
