@@ -14,18 +14,20 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
-#include <gp_XYZ.hxx>
 #include <Plate_D3.hxx>
-#include <Plate_FreeGtoCConstraint.hxx>
-#include <Plate_GtoCConstraint.hxx>
 
 Plate_D3::Plate_D3(const gp_XYZ& duuu, const gp_XYZ& duuv, const gp_XYZ& duvv, const gp_XYZ& dvvv)
-:Duuu(duuu),Duuv(duuv),Duvv(duvv),Dvvv(dvvv)
+    : Duuu(duuu),
+      Duuv(duuv),
+      Duvv(duvv),
+      Dvvv(dvvv)
 {
 }
 
 Plate_D3::Plate_D3(const Plate_D3& ref)
-:Duuu(ref.Duuu),Duuv(ref.Duuv),Duvv(ref.Duvv),Dvvv(ref.Dvvv)
+    : Duuu(ref.Duuu),
+      Duuv(ref.Duuv),
+      Duvv(ref.Duvv),
+      Dvvv(ref.Dvvv)
 {
 }
