@@ -22,36 +22,43 @@
 
 #include <QABugs_PresentableObject.hxx>
 
-Handle(QABugs_PresentableObject) theObject1=NULL;
-Handle(QABugs_PresentableObject) theObject2=NULL;
+Handle(QABugs_PresentableObject) theObject1 = NULL;
+Handle(QABugs_PresentableObject) theObject2 = NULL;
 
-static Standard_Integer BUC60720 (Draw_Interpretor& di,Standard_Integer argc,const char ** argv )
+static Standard_Integer BUC60720(Draw_Interpretor& di, Standard_Integer argc, const char** argv)
 {
   Handle(AIS_InteractiveContext) myAISContext = ViewerTest::GetAISContext();
-  if(myAISContext.IsNull()) { 
+  if (myAISContext.IsNull())
+  {
     di << "use 'vinit' command before " << argv[0] << "\n";
     return -1;
   }
 
-  if(argc != 2) {
+  if (argc != 2)
+  {
     di << "Usage : " << argv[0] << " 0/1\n";
   }
 
-  if(Draw::Atoi(argv[1]) == 0) {
-    if ( theObject1.IsNull() )
-      {
-	theObject1 = new QABugs_PresentableObject();
-	theObject1->SetDisplayMode(0);
-	myAISContext->Display (theObject1, Standard_True);
-      }
-  } else if(Draw::Atoi(argv[1]) == 1) {
-    if ( theObject2.IsNull() )
-      {
-	theObject2 = new QABugs_PresentableObject();
-	theObject2->SetDisplayMode(1);
-	myAISContext->Display (theObject2, Standard_True);
-      }
-  } else {
+  if (Draw::Atoi(argv[1]) == 0)
+  {
+    if (theObject1.IsNull())
+    {
+      theObject1 = new QABugs_PresentableObject();
+      theObject1->SetDisplayMode(0);
+      myAISContext->Display(theObject1, Standard_True);
+    }
+  }
+  else if (Draw::Atoi(argv[1]) == 1)
+  {
+    if (theObject2.IsNull())
+    {
+      theObject2 = new QABugs_PresentableObject();
+      theObject2->SetDisplayMode(1);
+      myAISContext->Display(theObject2, Standard_True);
+    }
+  }
+  else
+  {
     di << "Usage : " << argv[0] << " 0/1\n";
     return -1;
   }
@@ -60,6 +67,6 @@ static Standard_Integer BUC60720 (Draw_Interpretor& di,Standard_Integer argc,con
 
 void QABugs::Commands_15(Draw_Interpretor& theCommands)
 {
-  const char *group = "QABugs";
-  theCommands.Add("BUC60720","BUC60720 0/1",__FILE__,BUC60720,group);
+  const char* group = "QABugs";
+  theCommands.Add("BUC60720", "BUC60720 0/1", __FILE__, BUC60720, group);
 }
