@@ -14,7 +14,7 @@
 // commercial license or contractual agreement.
 
 #include <Interface_EntityIterator.hxx>
-#include <RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation.hxx>
+#include "RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation.pxx"
 #include <StepBasic_ExternalSource.hxx>
 #include <StepBasic_ProductDefinitionReferenceWithLocalRepresentation.hxx>
 #include <StepBasic_ProductDefinitionContext.hxx>
@@ -22,88 +22,91 @@
 #include <StepData_StepReaderData.hxx>
 #include <StepData_StepWriter.hxx>
 
-//=======================================================================
-//function : RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation
-//purpose  : 
-//=======================================================================
-RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::
-  RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation () {}
+//=================================================================================================
 
-//=======================================================================
-//function : ReadStep
-//purpose  : 
-//=======================================================================
-void RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::ReadStep
-  (const Handle(StepData_StepReaderData)& data,
-   const Standard_Integer num,
-   Handle(Interface_Check)& ach,
-   const Handle(StepBasic_ProductDefinitionReferenceWithLocalRepresentation)& ent) const
+RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::
+  RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation()
+{
+}
+
+//=================================================================================================
+
+void RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::ReadStep(
+  const Handle(StepData_StepReaderData)&                                     data,
+  const Standard_Integer                                                     num,
+  Handle(Interface_Check)&                                                   ach,
+  const Handle(StepBasic_ProductDefinitionReferenceWithLocalRepresentation)& ent) const
 {
   // Number of Parameter Control
-  if (!data->CheckNbParams(num, 5, ach, "product_definition_reference_with_local_representation")) return;
+  if (!data->CheckNbParams(num, 5, ach, "product_definition_reference_with_local_representation"))
+    return;
 
   // Own field source
   Handle(StepBasic_ExternalSource) aSource;
-  data->ReadEntity(num, 1,"source", ach, STANDARD_TYPE(StepBasic_ExternalSource), aSource);
+  data->ReadEntity(num, 1, "source", ach, STANDARD_TYPE(StepBasic_ExternalSource), aSource);
 
   // Inherited field : id
   Handle(TCollection_HAsciiString) aId;
-  data->ReadString (num, 2, "id", ach, aId);
-  
+  data->ReadString(num, 2, "id", ach, aId);
+
   // Inherited field : description
   Handle(TCollection_HAsciiString) aDescription;
-  if (data->IsParamDefined (num, 3)) {
-    data->ReadString (num, 3, "description", ach, aDescription);
+  if (data->IsParamDefined(num, 3))
+  {
+    data->ReadString(num, 3, "description", ach, aDescription);
   }
 
   // Inherited field : formation
   Handle(StepBasic_ProductDefinitionFormation) aFormation;
-  data->ReadEntity(num, 4, "formation", ach, STANDARD_TYPE(StepBasic_ProductDefinitionFormation), aFormation);
-  
+  data->ReadEntity(num,
+                   4,
+                   "formation",
+                   ach,
+                   STANDARD_TYPE(StepBasic_ProductDefinitionFormation),
+                   aFormation);
+
   // Inherited : frame_of_reference
   Handle(StepBasic_ProductDefinitionContext) aFrameOfReference;
-  data->ReadEntity(num, 5,"frame_of_reference", ach, STANDARD_TYPE(StepBasic_ProductDefinitionContext), aFrameOfReference);
-  
+  data->ReadEntity(num,
+                   5,
+                   "frame_of_reference",
+                   ach,
+                   STANDARD_TYPE(StepBasic_ProductDefinitionContext),
+                   aFrameOfReference);
+
   //  Initialisation of the read entity
   ent->Init(aSource, aId, aDescription, aFormation, aFrameOfReference);
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : WriteStep
-//purpose  : 
-//=======================================================================
-void RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::WriteStep
-  (StepData_StepWriter& SW,
-   const Handle(StepBasic_ProductDefinitionReferenceWithLocalRepresentation)& ent) const
+void RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::WriteStep(
+  StepData_StepWriter&                                                       SW,
+  const Handle(StepBasic_ProductDefinitionReferenceWithLocalRepresentation)& ent) const
 {
   // Own field : source
   SW.Send(ent->Source());
 
   // Inherited field : id
   SW.Send(ent->Id());
-  
+
   // Inherited field : description
   SW.Send(ent->Description());
-  
+
   // Inherited field : formation
   SW.Send(ent->Formation());
-  
+
   // Inherited field : frame_of_reference
   SW.Send(ent->FrameOfReference());
 }
 
+//=================================================================================================
 
-//=======================================================================
-//function : Share
-//purpose  : 
-//=======================================================================
 void RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation::Share(
   const Handle(StepBasic_ProductDefinitionReferenceWithLocalRepresentation)& ent,
-  Interface_EntityIterator& iter) const
+  Interface_EntityIterator&                                                  iter) const
 {
   iter.GetOneItem(ent->Source());
   iter.GetOneItem(ent->Formation());
   iter.GetOneItem(ent->FrameOfReference());
 }
-
