@@ -14,19 +14,17 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <STEPSelections_AssemblyComponent.hxx>
 #include <StepShape_ShapeDefinitionRepresentation.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(STEPSelections_AssemblyComponent,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(STEPSelections_AssemblyComponent, Standard_Transient)
 
-STEPSelections_AssemblyComponent::STEPSelections_AssemblyComponent() 
-{
-}
+STEPSelections_AssemblyComponent::STEPSelections_AssemblyComponent() {}
 
-STEPSelections_AssemblyComponent::STEPSelections_AssemblyComponent(const Handle(StepShape_ShapeDefinitionRepresentation)& sdr,
-								 const Handle(STEPSelections_HSequenceOfAssemblyLink)& list)
+STEPSelections_AssemblyComponent::STEPSelections_AssemblyComponent(
+  const Handle(StepShape_ShapeDefinitionRepresentation)& sdr,
+  const Handle(STEPSelections_HSequenceOfAssemblyLink)&  list)
 {
-  mySDR = sdr;
+  mySDR  = sdr;
   myList = list;
 }
