@@ -18,56 +18,53 @@
 #include <gp_Vec.hxx>
 #include <TopLoc_Location.hxx>
 
+IMPLEMENT_STANDARD_RTTIEXT(Select3D_SensitiveSegment, Select3D_SensitiveEntity)
 
-IMPLEMENT_STANDARD_RTTIEXT(Select3D_SensitiveSegment,Select3D_SensitiveEntity)
+//=================================================================================================
 
-//=====================================================
-// Function : Create
-// Purpose  : Constructor
-//=====================================================
-Select3D_SensitiveSegment::Select3D_SensitiveSegment (const Handle(SelectMgr_EntityOwner)& theOwnerId,
-                                                      const gp_Pnt& theFirstPnt,
-                                                      const gp_Pnt& theLastPnt)
-: Select3D_SensitiveEntity (theOwnerId)
+Select3D_SensitiveSegment::Select3D_SensitiveSegment(
+  const Handle(SelectMgr_EntityOwner)& theOwnerId,
+  const gp_Pnt&                        theFirstPnt,
+  const gp_Pnt&                        theLastPnt)
+    : Select3D_SensitiveEntity(theOwnerId)
 {
   mySFactor = 3;
-  myStart = theFirstPnt;
-  myEnd = theLastPnt;
+  myStart   = theFirstPnt;
+  myEnd     = theLastPnt;
 }
 
 // =======================================================================
 // function : Matches
 // purpose  : Checks whether the segment overlaps current selecting volume
 // =======================================================================
-Standard_Boolean Select3D_SensitiveSegment::Matches (SelectBasics_SelectingVolumeManager& theMgr,
-                                                     SelectBasics_PickResult& thePickResult)
+Standard_Boolean Select3D_SensitiveSegment::Matches(SelectBasics_SelectingVolumeManager& theMgr,
+                                                    SelectBasics_PickResult& thePickResult)
 {
   if (!theMgr.IsOverlapAllowed()) // check for inclusion
   {
     if (theMgr.GetActiveSelectionType() == SelectMgr_SelectionType_Polyline)
     {
-      return theMgr.OverlapsSegment (myStart, myEnd, thePickResult);
+      return theMgr.OverlapsSegment(myStart, myEnd, thePickResult);
     }
-    return theMgr.OverlapsPoint (myStart, thePickResult) && theMgr.OverlapsPoint (myEnd, thePickResult);
+    return theMgr.OverlapsPoint(myStart, thePickResult)
+           && theMgr.OverlapsPoint(myEnd, thePickResult);
   }
 
-  if (!theMgr.OverlapsSegment (myStart, myEnd, thePickResult)) // check for overlap
+  if (!theMgr.OverlapsSegment(myStart, myEnd, thePickResult)) // check for overlap
   {
     return Standard_False;
   }
 
-  thePickResult.SetDistToGeomCenter (theMgr.DistToGeometryCenter(CenterOfGeometry()));
+  thePickResult.SetDistToGeomCenter(theMgr.DistToGeometryCenter(CenterOfGeometry()));
   return Standard_True;
 }
 
-//=======================================================================
-//function : GetConnected
-//purpose  :
-//=======================================================================
+//=================================================================================================
+
 Handle(Select3D_SensitiveEntity) Select3D_SensitiveSegment::GetConnected()
 {
   Handle(Select3D_SensitiveSegment) aNewEntity =
-    new Select3D_SensitiveSegment (myOwnerId, myStart, myEnd);
+    new Select3D_SensitiveSegment(myOwnerId, myStart, myEnd);
 
   return aNewEntity;
 }
@@ -89,13 +86,13 @@ gp_Pnt Select3D_SensitiveSegment::CenterOfGeometry() const
 //=======================================================================
 Select3D_BndBox3d Select3D_SensitiveSegment::BoundingBox()
 {
-  const SelectMgr_Vec3 aMinPnt (Min (myStart.X(), myEnd.X()),
-                                Min (myStart.Y(), myEnd.Y()),
-                                Min (myStart.Z(), myEnd.Z()));
-  const SelectMgr_Vec3 aMaxPnt (Max (myStart.X(), myEnd.X()),
-                                Max (myStart.Y(), myEnd.Y()),
-                                Max (myStart.Z(), myEnd.Z()));
-  return Select3D_BndBox3d (aMinPnt, aMaxPnt);
+  const SelectMgr_Vec3 aMinPnt(Min(myStart.X(), myEnd.X()),
+                               Min(myStart.Y(), myEnd.Y()),
+                               Min(myStart.Z(), myEnd.Z()));
+  const SelectMgr_Vec3 aMaxPnt(Max(myStart.X(), myEnd.X()),
+                               Max(myStart.Y(), myEnd.Y()),
+                               Max(myStart.Z(), myEnd.Z()));
+  return Select3D_BndBox3d(aMinPnt, aMaxPnt);
 }
 
 //=======================================================================
@@ -107,18 +104,17 @@ Standard_Integer Select3D_SensitiveSegment::NbSubElements() const
   return 2;
 }
 
-//=======================================================================
-//function : DumpJson
-//purpose  :
-//=======================================================================
-void Select3D_SensitiveSegment::DumpJson (Standard_OStream& theOStream, Standard_Integer theDepth) const
-{
-  OCCT_DUMP_TRANSIENT_CLASS_BEGIN (theOStream)
-  OCCT_DUMP_BASE_CLASS (theOStream, theDepth, Select3D_SensitiveEntity)
+//=================================================================================================
 
-  OCCT_DUMP_FIELD_VALUES_DUMPED (theOStream, theDepth, &myStart)
-  OCCT_DUMP_FIELD_VALUES_DUMPED (theOStream, theDepth, &myEnd)
+void Select3D_SensitiveSegment::DumpJson(Standard_OStream& theOStream,
+                                         Standard_Integer  theDepth) const
+{
+  OCCT_DUMP_TRANSIENT_CLASS_BEGIN(theOStream)
+  OCCT_DUMP_BASE_CLASS(theOStream, theDepth, Select3D_SensitiveEntity)
+
+  OCCT_DUMP_FIELD_VALUES_DUMPED(theOStream, theDepth, &myStart)
+  OCCT_DUMP_FIELD_VALUES_DUMPED(theOStream, theDepth, &myEnd)
 
   Select3D_BndBox3d aBoundingBox = ((Select3D_SensitiveSegment*)this)->BoundingBox();
-  OCCT_DUMP_FIELD_VALUES_DUMPED (theOStream, theDepth, &aBoundingBox)
+  OCCT_DUMP_FIELD_VALUES_DUMPED(theOStream, theDepth, &aBoundingBox)
 }
