@@ -12,25 +12,21 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <SelectMgr_AndFilter.hxx>
 #include <SelectMgr_EntityOwner.hxx>
 #include <SelectMgr_Filter.hxx>
 #include <SelectMgr_ListIteratorOfListOfFilter.hxx>
 #include <Standard_Type.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(SelectMgr_AndFilter,SelectMgr_CompositionFilter)
+IMPLEMENT_STANDARD_RTTIEXT(SelectMgr_AndFilter, SelectMgr_CompositionFilter)
 
-SelectMgr_AndFilter::SelectMgr_AndFilter()
-{
-}
-Standard_Boolean SelectMgr_AndFilter::IsOk(const Handle(SelectMgr_EntityOwner)& anobj) const 
+SelectMgr_AndFilter::SelectMgr_AndFilter() {}
+
+Standard_Boolean SelectMgr_AndFilter::IsOk(const Handle(SelectMgr_EntityOwner)& anobj) const
 {
   SelectMgr_ListIteratorOfListOfFilter it(myFilters);
-  for ( ; it.More();it.Next()) 
-    if(!it.Value()->IsOk(anobj)) 
+  for (; it.More(); it.Next())
+    if (!it.Value()->IsOk(anobj))
       return Standard_False;
   return Standard_True;
 }
-
-
