@@ -18,9 +18,14 @@
 #include <Standard_CString.hxx>
 #include <Standard_ProgramError.hxx>
 
-const Handle(Standard_Type)& Standard_Transient::get_type_descriptor ()
+const Handle(Standard_Type)& Standard_Transient::get_type_descriptor()
 {
-  return opencascade::type_instance<Standard_Transient>::get();
+  static const Handle(Standard_Type) THE_TYPE_INSTANCE =
+    Standard_Type::Register(typeid(Standard_Transient),
+                            get_type_name(),
+                            sizeof(Standard_Transient),
+                            nullptr);
+  return THE_TYPE_INSTANCE;
 }
 
 //
@@ -32,7 +37,7 @@ const Handle(Standard_Type)& Standard_Transient::DynamicType() const
 
 //
 //
-Standard_Boolean Standard_Transient::IsInstance(const Handle(Standard_Type) &AType) const
+Standard_Boolean Standard_Transient::IsInstance(const Handle(Standard_Type)& AType) const
 {
   return (AType == DynamicType());
 }
@@ -41,21 +46,21 @@ Standard_Boolean Standard_Transient::IsInstance(const Handle(Standard_Type) &ATy
 //
 Standard_Boolean Standard_Transient::IsInstance(const Standard_CString theTypeName) const
 {
-  return IsEqual ( DynamicType()->Name(), theTypeName );
+  return IsEqual(DynamicType()->Name(), theTypeName);
 }
 
 //
 //
-Standard_Boolean Standard_Transient::IsKind (const Handle(Standard_Type)& aType) const
+Standard_Boolean Standard_Transient::IsKind(const Handle(Standard_Type)& aType) const
 {
-  return DynamicType()->SubType ( aType );
+  return DynamicType()->SubType(aType);
 }
 
 //
 //
-Standard_Boolean Standard_Transient::IsKind (const Standard_CString theTypeName) const
+Standard_Boolean Standard_Transient::IsKind(const Standard_CString theTypeName) const
 {
-  return DynamicType()->SubType ( theTypeName );
+  return DynamicType()->SubType(theTypeName);
 }
 
 //
@@ -63,6 +68,7 @@ Standard_Boolean Standard_Transient::IsKind (const Standard_CString theTypeName)
 Standard_Transient* Standard_Transient::This() const
 {
   if (GetRefCount() == 0)
-    throw Standard_ProgramError("Attempt to create handle to object created in stack, not yet constructed, or destroyed");
-  return const_cast<Standard_Transient*> (this);
+    throw Standard_ProgramError(
+      "Attempt to create handle to object created in stack, not yet constructed, or destroyed");
+  return const_cast<Standard_Transient*>(this);
 }
