@@ -18,12 +18,8 @@
 #include <Standard_Type.hxx>
 #include <StepAP214_Class.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepAP214_Class,StepBasic_Group)
+IMPLEMENT_STANDARD_RTTIEXT(StepAP214_Class, StepBasic_Group)
 
-//=======================================================================
-//function : StepAP214_Class
-//purpose  : 
-//=======================================================================
-StepAP214_Class::StepAP214_Class ()
-{
-}
+//=================================================================================================
+
+StepAP214_Class::StepAP214_Class() {}
