@@ -11,28 +11,25 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepBasic_ApprovalRole.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepBasic_ApprovalRole,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(StepBasic_ApprovalRole, Standard_Transient)
 
-StepBasic_ApprovalRole::StepBasic_ApprovalRole ()  {}
+StepBasic_ApprovalRole::StepBasic_ApprovalRole() {}
 
-void StepBasic_ApprovalRole::Init(
-	const Handle(TCollection_HAsciiString)& aRole)
+void StepBasic_ApprovalRole::Init(const Handle(TCollection_HAsciiString)& aRole)
 {
-	// --- classe own fields ---
-	role = aRole;
+  // --- classe own fields ---
+  role = aRole;
 }
 
-
 void StepBasic_ApprovalRole::SetRole(const Handle(TCollection_HAsciiString)& aRole)
 {
-	role = aRole;
+  role = aRole;
 }
 
 Handle(TCollection_HAsciiString) StepBasic_ApprovalRole::Role() const
 {
-	return role;
+  return role;
 }
