@@ -11,33 +11,32 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepBasic_ApplicationContext.hxx>
 #include <StepBasic_ProductDefinitionContext.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepBasic_ProductDefinitionContext,StepBasic_ApplicationContextElement)
+IMPLEMENT_STANDARD_RTTIEXT(StepBasic_ProductDefinitionContext, StepBasic_ApplicationContextElement)
 
-StepBasic_ProductDefinitionContext::StepBasic_ProductDefinitionContext ()  {}
+StepBasic_ProductDefinitionContext::StepBasic_ProductDefinitionContext() {}
 
 void StepBasic_ProductDefinitionContext::Init(
-	const Handle(TCollection_HAsciiString)& aName,
-	const Handle(StepBasic_ApplicationContext)& aFrameOfReference,
-	const Handle(TCollection_HAsciiString)& aLifeCycleStage)
+  const Handle(TCollection_HAsciiString)&     aName,
+  const Handle(StepBasic_ApplicationContext)& aFrameOfReference,
+  const Handle(TCollection_HAsciiString)&     aLifeCycleStage)
 {
-	// --- classe own fields ---
-	lifeCycleStage = aLifeCycleStage;
-	// --- classe inherited fields ---
-	StepBasic_ApplicationContextElement::Init(aName, aFrameOfReference);
+  // --- classe own fields ---
+  lifeCycleStage = aLifeCycleStage;
+  // --- classe inherited fields ---
+  StepBasic_ApplicationContextElement::Init(aName, aFrameOfReference);
 }
 
-
-void StepBasic_ProductDefinitionContext::SetLifeCycleStage(const Handle(TCollection_HAsciiString)& aLifeCycleStage)
+void StepBasic_ProductDefinitionContext::SetLifeCycleStage(
+  const Handle(TCollection_HAsciiString)& aLifeCycleStage)
 {
-	lifeCycleStage = aLifeCycleStage;
+  lifeCycleStage = aLifeCycleStage;
 }
 
 Handle(TCollection_HAsciiString) StepBasic_ProductDefinitionContext::LifeCycleStage() const
 {
-	return lifeCycleStage;
+  return lifeCycleStage;
 }
