@@ -11,21 +11,24 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepData_FieldListN.hxx>
 
-StepData_FieldListN::StepData_FieldListN  (const Standard_Integer nb)
-:  thefields ( (nb == 0 ? 0 : 1),nb)    {  }
+StepData_FieldListN::StepData_FieldListN(const Standard_Integer nb)
+    : thefields((nb == 0 ? 0 : 1), nb)
+{
+}
 
-Standard_Integer  StepData_FieldListN::NbFields () const
-{  return thefields.Upper();  }
+Standard_Integer StepData_FieldListN::NbFields() const
+{
+  return thefields.Upper();
+}
 
-const StepData_Field&  StepData_FieldListN::Field (const Standard_Integer num) const
+const StepData_Field& StepData_FieldListN::Field(const Standard_Integer num) const
 {
   return thefields.Value(num);
 }
 
-StepData_Field&  StepData_FieldListN::CField (const Standard_Integer num)
+StepData_Field& StepData_FieldListN::CField(const Standard_Integer num)
 {
   return thefields.ChangeValue(num);
 }
