@@ -11,18 +11,30 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Standard_Type.hxx>
 #include <StepData_SelectReal.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepData_SelectReal,StepData_SelectMember)
+IMPLEMENT_STANDARD_RTTIEXT(StepData_SelectReal, StepData_SelectMember)
 
 //  Definitions : cf Field
 #define KindReal 5
 
-StepData_SelectReal::StepData_SelectReal  ()    {  theval = 0.0;  }
+StepData_SelectReal::StepData_SelectReal()
+{
+  theval = 0.0;
+}
 
-Standard_Integer  StepData_SelectReal::Kind () const    {  return KindReal;  }
+Standard_Integer StepData_SelectReal::Kind() const
+{
+  return KindReal;
+}
 
-Standard_Real  StepData_SelectReal::Real () const    { return theval;  }
-void  StepData_SelectReal::SetReal (const Standard_Real val)    {  theval = val;  }
+Standard_Real StepData_SelectReal::Real() const
+{
+  return theval;
+}
+
+void StepData_SelectReal::SetReal(const Standard_Real val)
+{
+  theval = val;
+}
