@@ -17,12 +17,8 @@
 
 #include <StepDimTol_CylindricityTolerance.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_CylindricityTolerance,StepDimTol_GeometricTolerance)
+IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_CylindricityTolerance, StepDimTol_GeometricTolerance)
 
-//=======================================================================
-//function : StepDimTol_CylindricityTolerance
-//purpose  : 
-//=======================================================================
-StepDimTol_CylindricityTolerance::StepDimTol_CylindricityTolerance ()
-{
-}
+//=================================================================================================
+
+StepDimTol_CylindricityTolerance::StepDimTol_CylindricityTolerance() {}
