@@ -17,12 +17,8 @@
 
 #include <StepDimTol_LineProfileTolerance.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_LineProfileTolerance,StepDimTol_GeometricTolerance)
+IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_LineProfileTolerance, StepDimTol_GeometricTolerance)
 
-//=======================================================================
-//function : StepDimTol_LineProfileTolerance
-//purpose  : 
-//=======================================================================
-StepDimTol_LineProfileTolerance::StepDimTol_LineProfileTolerance ()
-{
-}
+//=================================================================================================
+
+StepDimTol_LineProfileTolerance::StepDimTol_LineProfileTolerance() {}
