@@ -15,13 +15,8 @@
 
 #include <StepDimTol_NonUniformZoneDefinition.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_NonUniformZoneDefinition,StepDimTol_ToleranceZoneDefinition)
+IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_NonUniformZoneDefinition, StepDimTol_ToleranceZoneDefinition)
 
-//=======================================================================
-//function : StepDimTol_NonUniformZoneDefinition
-//purpose  : 
-//=======================================================================
+//=================================================================================================
 
-StepDimTol_NonUniformZoneDefinition::StepDimTol_NonUniformZoneDefinition ()
-{
-}
+StepDimTol_NonUniformZoneDefinition::StepDimTol_NonUniformZoneDefinition() {}
