@@ -17,12 +17,9 @@
 
 #include <StepDimTol_ParallelismTolerance.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_ParallelismTolerance,StepDimTol_GeometricToleranceWithDatumReference)
+IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_ParallelismTolerance,
+                           StepDimTol_GeometricToleranceWithDatumReference)
 
-//=======================================================================
-//function : StepDimTol_ParallelismTolerance
-//purpose  : 
-//=======================================================================
-StepDimTol_ParallelismTolerance::StepDimTol_ParallelismTolerance ()
-{
-}
+//=================================================================================================
+
+StepDimTol_ParallelismTolerance::StepDimTol_ParallelismTolerance() {}
