@@ -17,12 +17,8 @@
 
 #include <StepDimTol_SurfaceProfileTolerance.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_SurfaceProfileTolerance,StepDimTol_GeometricTolerance)
+IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_SurfaceProfileTolerance, StepDimTol_GeometricTolerance)
 
-//=======================================================================
-//function : StepDimTol_SurfaceProfileTolerance
-//purpose  : 
-//=======================================================================
-StepDimTol_SurfaceProfileTolerance::StepDimTol_SurfaceProfileTolerance ()
-{
-}
+//=================================================================================================
+
+StepDimTol_SurfaceProfileTolerance::StepDimTol_SurfaceProfileTolerance() {}
