@@ -17,12 +17,9 @@
 
 #include <StepDimTol_SymmetryTolerance.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_SymmetryTolerance,StepDimTol_GeometricToleranceWithDatumReference)
+IMPLEMENT_STANDARD_RTTIEXT(StepDimTol_SymmetryTolerance,
+                           StepDimTol_GeometricToleranceWithDatumReference)
 
-//=======================================================================
-//function : StepDimTol_SymmetryTolerance
-//purpose  : 
-//=======================================================================
-StepDimTol_SymmetryTolerance::StepDimTol_SymmetryTolerance ()
-{
-}
+//=================================================================================================
+
+StepDimTol_SymmetryTolerance::StepDimTol_SymmetryTolerance() {}
