@@ -18,12 +18,8 @@
 #include <Standard_Type.hxx>
 #include <StepFEA_GeometricNode.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepFEA_GeometricNode,StepFEA_NodeRepresentation)
+IMPLEMENT_STANDARD_RTTIEXT(StepFEA_GeometricNode, StepFEA_NodeRepresentation)
 
-//=======================================================================
-//function : StepFEA_GeometricNode
-//purpose  : 
-//=======================================================================
-StepFEA_GeometricNode::StepFEA_GeometricNode ()
-{
-}
+//=================================================================================================
+
+StepFEA_GeometricNode::StepFEA_GeometricNode() {}
