@@ -11,35 +11,32 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepGeom_Axis2Placement3d.hxx>
 #include <StepGeom_DegenerateToroidalSurface.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepGeom_DegenerateToroidalSurface,StepGeom_ToroidalSurface)
+IMPLEMENT_STANDARD_RTTIEXT(StepGeom_DegenerateToroidalSurface, StepGeom_ToroidalSurface)
 
-StepGeom_DegenerateToroidalSurface::StepGeom_DegenerateToroidalSurface ()  {}
+StepGeom_DegenerateToroidalSurface::StepGeom_DegenerateToroidalSurface() {}
 
-void StepGeom_DegenerateToroidalSurface::Init(
-	const Handle(TCollection_HAsciiString)& aName,
-	const Handle(StepGeom_Axis2Placement3d)& aPosition,
-	const Standard_Real aMajorRadius,
-	const Standard_Real aMinorRadius,
-	const Standard_Boolean aSelectOuter)
+void StepGeom_DegenerateToroidalSurface::Init(const Handle(TCollection_HAsciiString)&  aName,
+                                              const Handle(StepGeom_Axis2Placement3d)& aPosition,
+                                              const Standard_Real                      aMajorRadius,
+                                              const Standard_Real                      aMinorRadius,
+                                              const Standard_Boolean                   aSelectOuter)
 {
-	// --- classe own fields ---
-	selectOuter = aSelectOuter;
-	// --- classe inherited fields ---
-	StepGeom_ToroidalSurface::Init(aName, aPosition, aMajorRadius, aMinorRadius);
+  // --- classe own fields ---
+  selectOuter = aSelectOuter;
+  // --- classe inherited fields ---
+  StepGeom_ToroidalSurface::Init(aName, aPosition, aMajorRadius, aMinorRadius);
 }
 
-
 void StepGeom_DegenerateToroidalSurface::SetSelectOuter(const Standard_Boolean aSelectOuter)
 {
-	selectOuter = aSelectOuter;
+  selectOuter = aSelectOuter;
 }
 
 Standard_Boolean StepGeom_DegenerateToroidalSurface::SelectOuter() const
 {
-	return selectOuter;
+  return selectOuter;
 }
