@@ -11,34 +11,32 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepGeom_Curve.hxx>
 #include <StepGeom_SurfaceOfLinearExtrusion.hxx>
 #include <StepGeom_Vector.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepGeom_SurfaceOfLinearExtrusion,StepGeom_SweptSurface)
+IMPLEMENT_STANDARD_RTTIEXT(StepGeom_SurfaceOfLinearExtrusion, StepGeom_SweptSurface)
 
-StepGeom_SurfaceOfLinearExtrusion::StepGeom_SurfaceOfLinearExtrusion ()  {}
+StepGeom_SurfaceOfLinearExtrusion::StepGeom_SurfaceOfLinearExtrusion() {}
 
-void StepGeom_SurfaceOfLinearExtrusion::Init(
-	const Handle(TCollection_HAsciiString)& aName,
-	const Handle(StepGeom_Curve)& aSweptCurve,
-	const Handle(StepGeom_Vector)& aExtrusionAxis)
+void StepGeom_SurfaceOfLinearExtrusion::Init(const Handle(TCollection_HAsciiString)& aName,
+                                             const Handle(StepGeom_Curve)&           aSweptCurve,
+                                             const Handle(StepGeom_Vector)&          aExtrusionAxis)
 {
-	// --- classe own fields ---
-	extrusionAxis = aExtrusionAxis;
-	// --- classe inherited fields ---
-	StepGeom_SweptSurface::Init(aName, aSweptCurve);
+  // --- classe own fields ---
+  extrusionAxis = aExtrusionAxis;
+  // --- classe inherited fields ---
+  StepGeom_SweptSurface::Init(aName, aSweptCurve);
 }
 
-
-void StepGeom_SurfaceOfLinearExtrusion::SetExtrusionAxis(const Handle(StepGeom_Vector)& aExtrusionAxis)
+void StepGeom_SurfaceOfLinearExtrusion::SetExtrusionAxis(
+  const Handle(StepGeom_Vector)& aExtrusionAxis)
 {
-	extrusionAxis = aExtrusionAxis;
+  extrusionAxis = aExtrusionAxis;
 }
 
 Handle(StepGeom_Vector) StepGeom_SurfaceOfLinearExtrusion::ExtrusionAxis() const
 {
-	return extrusionAxis;
+  return extrusionAxis;
 }
