@@ -15,15 +15,10 @@
 
 // Generator:	ExpToCas (EXPRESS -> CASCADE/XSTEP Translator) V1.2
 
-#include <Standard_Type.hxx>
 #include <StepRepr_MaterialProperty.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepRepr_MaterialProperty,StepRepr_PropertyDefinition)
+IMPLEMENT_STANDARD_RTTIEXT(StepRepr_MaterialProperty, StepRepr_PropertyDefinition)
 
-//=======================================================================
-//function : StepRepr_MaterialProperty
-//purpose  : 
-//=======================================================================
-StepRepr_MaterialProperty::StepRepr_MaterialProperty ()
-{
-}
+//=================================================================================================
+
+StepRepr_MaterialProperty::StepRepr_MaterialProperty() {}
