@@ -15,15 +15,14 @@
 
 // Generator:	ExpToCas (EXPRESS -> CASCADE/XSTEP Translator) V1.2
 
-#include <Standard_Type.hxx>
 #include <StepRepr_StructuralResponsePropertyDefinitionRepresentation.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepRepr_StructuralResponsePropertyDefinitionRepresentation,StepRepr_PropertyDefinitionRepresentation)
+IMPLEMENT_STANDARD_RTTIEXT(StepRepr_StructuralResponsePropertyDefinitionRepresentation,
+                           StepRepr_PropertyDefinitionRepresentation)
 
-//=======================================================================
-//function : StepRepr_StructuralResponsePropertyDefinitionRepresentation
-//purpose  : 
-//=======================================================================
-StepRepr_StructuralResponsePropertyDefinitionRepresentation::StepRepr_StructuralResponsePropertyDefinitionRepresentation ()
+//=================================================================================================
+
+StepRepr_StructuralResponsePropertyDefinitionRepresentation::
+  StepRepr_StructuralResponsePropertyDefinitionRepresentation()
 {
 }
