@@ -11,31 +11,29 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepGeom_Direction.hxx>
 #include <StepShape_ExtrudedFaceSolid.hxx>
 #include <StepShape_FaceSurface.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepShape_ExtrudedFaceSolid,StepShape_SweptFaceSolid)
+IMPLEMENT_STANDARD_RTTIEXT(StepShape_ExtrudedFaceSolid, StepShape_SweptFaceSolid)
 
-StepShape_ExtrudedFaceSolid::StepShape_ExtrudedFaceSolid ()  {}
+StepShape_ExtrudedFaceSolid::StepShape_ExtrudedFaceSolid() {}
 
-void StepShape_ExtrudedFaceSolid::Init(
-	const Handle(TCollection_HAsciiString)& aName,
-	const Handle(StepShape_FaceSurface)& aSweptArea,
-	const Handle(StepGeom_Direction)& aExtrudedDirection,
-	const Standard_Real aDepth)
+void StepShape_ExtrudedFaceSolid::Init(const Handle(TCollection_HAsciiString)& aName,
+                                       const Handle(StepShape_FaceSurface)&    aSweptArea,
+                                       const Handle(StepGeom_Direction)&       aExtrudedDirection,
+                                       const Standard_Real                     aDepth)
 {
   // --- classe own fields ---
   extrudedDirection = aExtrudedDirection;
-  depth = aDepth;
+  depth             = aDepth;
   // --- classe inherited fields ---
   StepShape_SweptFaceSolid::Init(aName, aSweptArea);
 }
 
-
-void StepShape_ExtrudedFaceSolid::SetExtrudedDirection(const Handle(StepGeom_Direction)& aExtrudedDirection)
+void StepShape_ExtrudedFaceSolid::SetExtrudedDirection(
+  const Handle(StepGeom_Direction)& aExtrudedDirection)
 {
   extrudedDirection = aExtrudedDirection;
 }
