@@ -11,44 +11,41 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepShape_FaceBound.hxx>
 #include <StepShape_Loop.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepShape_FaceBound,StepShape_TopologicalRepresentationItem)
+IMPLEMENT_STANDARD_RTTIEXT(StepShape_FaceBound, StepShape_TopologicalRepresentationItem)
 
-StepShape_FaceBound::StepShape_FaceBound ()  {}
+StepShape_FaceBound::StepShape_FaceBound() {}
 
-void StepShape_FaceBound::Init(
-	const Handle(TCollection_HAsciiString)& aName,
-	const Handle(StepShape_Loop)& aBound,
-	const Standard_Boolean aOrientation)
+void StepShape_FaceBound::Init(const Handle(TCollection_HAsciiString)& aName,
+                               const Handle(StepShape_Loop)&           aBound,
+                               const Standard_Boolean                  aOrientation)
 {
-	// --- classe own fields ---
-	bound = aBound;
-	orientation = aOrientation;
-	// --- classe inherited fields ---
-	StepRepr_RepresentationItem::Init(aName);
+  // --- classe own fields ---
+  bound       = aBound;
+  orientation = aOrientation;
+  // --- classe inherited fields ---
+  StepRepr_RepresentationItem::Init(aName);
 }
 
-
 void StepShape_FaceBound::SetBound(const Handle(StepShape_Loop)& aBound)
 {
-	bound = aBound;
+  bound = aBound;
 }
 
 Handle(StepShape_Loop) StepShape_FaceBound::Bound() const
 {
-	return bound;
+  return bound;
 }
 
 void StepShape_FaceBound::SetOrientation(const Standard_Boolean aOrientation)
 {
-	orientation = aOrientation;
+  orientation = aOrientation;
 }
 
 Standard_Boolean StepShape_FaceBound::Orientation() const
 {
-	return orientation;
+  return orientation;
 }
