@@ -11,10 +11,9 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepVisual_DraughtingAnnotationOccurrence.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepVisual_DraughtingAnnotationOccurrence,StepVisual_AnnotationOccurrence)
-
-StepVisual_DraughtingAnnotationOccurrence::StepVisual_DraughtingAnnotationOccurrence ()  {}
+IMPLEMENT_STANDARD_RTTIEXT(StepVisual_DraughtingAnnotationOccurrence,
+                           StepVisual_AnnotationOccurrence)
 
+StepVisual_DraughtingAnnotationOccurrence::StepVisual_DraughtingAnnotationOccurrence() {}
