@@ -11,11 +11,13 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Standard_Type.hxx>
 #include <StepVisual_MechanicalDesignGeometricPresentationArea.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepVisual_MechanicalDesignGeometricPresentationArea,StepVisual_PresentationArea)
-
-StepVisual_MechanicalDesignGeometricPresentationArea::StepVisual_MechanicalDesignGeometricPresentationArea ()  {}
+IMPLEMENT_STANDARD_RTTIEXT(StepVisual_MechanicalDesignGeometricPresentationArea,
+                           StepVisual_PresentationArea)
 
+StepVisual_MechanicalDesignGeometricPresentationArea::
+  StepVisual_MechanicalDesignGeometricPresentationArea()
+{
+}
