@@ -11,51 +11,51 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepVisual_SurfaceSideStyle.hxx>
 #include <StepVisual_SurfaceStyleElementSelect.hxx>
 #include <TCollection_HAsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepVisual_SurfaceSideStyle,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(StepVisual_SurfaceSideStyle, Standard_Transient)
 
-StepVisual_SurfaceSideStyle::StepVisual_SurfaceSideStyle ()  {}
+StepVisual_SurfaceSideStyle::StepVisual_SurfaceSideStyle() {}
 
 void StepVisual_SurfaceSideStyle::Init(
-	const Handle(TCollection_HAsciiString)& aName,
-	const Handle(StepVisual_HArray1OfSurfaceStyleElementSelect)& aStyles)
+  const Handle(TCollection_HAsciiString)&                      aName,
+  const Handle(StepVisual_HArray1OfSurfaceStyleElementSelect)& aStyles)
 {
-	// --- classe own fields ---
-	name = aName;
-	styles = aStyles;
+  // --- classe own fields ---
+  name   = aName;
+  styles = aStyles;
 }
 
-
 void StepVisual_SurfaceSideStyle::SetName(const Handle(TCollection_HAsciiString)& aName)
 {
-	name = aName;
+  name = aName;
 }
 
 Handle(TCollection_HAsciiString) StepVisual_SurfaceSideStyle::Name() const
 {
-	return name;
+  return name;
 }
 
-void StepVisual_SurfaceSideStyle::SetStyles(const Handle(StepVisual_HArray1OfSurfaceStyleElementSelect)& aStyles)
+void StepVisual_SurfaceSideStyle::SetStyles(
+  const Handle(StepVisual_HArray1OfSurfaceStyleElementSelect)& aStyles)
 {
-	styles = aStyles;
+  styles = aStyles;
 }
 
 Handle(StepVisual_HArray1OfSurfaceStyleElementSelect) StepVisual_SurfaceSideStyle::Styles() const
 {
-	return styles;
+  return styles;
 }
 
-StepVisual_SurfaceStyleElementSelect StepVisual_SurfaceSideStyle::StylesValue(const Standard_Integer num) const
+StepVisual_SurfaceStyleElementSelect StepVisual_SurfaceSideStyle::StylesValue(
+  const Standard_Integer num) const
 {
-	return styles->Value(num);
+  return styles->Value(num);
 }
 
-Standard_Integer StepVisual_SurfaceSideStyle::NbStyles () const
+Standard_Integer StepVisual_SurfaceSideStyle::NbStyles() const
 {
   return (styles.IsNull()) ? 0 : styles->Length();
 }
