@@ -11,40 +11,37 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <StepVisual_SurfaceSideStyle.hxx>
 #include <StepVisual_SurfaceStyleUsage.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(StepVisual_SurfaceStyleUsage,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(StepVisual_SurfaceStyleUsage, Standard_Transient)
 
-StepVisual_SurfaceStyleUsage::StepVisual_SurfaceStyleUsage ()  {}
+StepVisual_SurfaceStyleUsage::StepVisual_SurfaceStyleUsage() {}
 
-void StepVisual_SurfaceStyleUsage::Init(
-	const StepVisual_SurfaceSide aSide,
-	const Handle(StepVisual_SurfaceSideStyle)& aStyle)
+void StepVisual_SurfaceStyleUsage::Init(const StepVisual_SurfaceSide               aSide,
+                                        const Handle(StepVisual_SurfaceSideStyle)& aStyle)
 {
-	// --- classe own fields ---
-	side = aSide;
-	style = aStyle;
+  // --- classe own fields ---
+  side  = aSide;
+  style = aStyle;
 }
 
-
 void StepVisual_SurfaceStyleUsage::SetSide(const StepVisual_SurfaceSide aSide)
 {
-	side = aSide;
+  side = aSide;
 }
 
 StepVisual_SurfaceSide StepVisual_SurfaceStyleUsage::Side() const
 {
-	return side;
+  return side;
 }
 
 void StepVisual_SurfaceStyleUsage::SetStyle(const Handle(StepVisual_SurfaceSideStyle)& aStyle)
 {
-	style = aStyle;
+  style = aStyle;
 }
 
 Handle(StepVisual_SurfaceSideStyle) StepVisual_SurfaceStyleUsage::Style() const
 {
-	return style;
+  return style;
 }
