@@ -12,33 +12,36 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <Standard_Type.hxx>
 #include <Storage_Root.hxx>
 #include <Storage_Schema.hxx>
 #include <TCollection_AsciiString.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(Storage_Root,Standard_Transient)
+IMPLEMENT_STANDARD_RTTIEXT(Storage_Root, Standard_Transient)
 
 Storage_Root::Storage_Root()
-  : myRef (0) {}
+    : myRef(0)
+{
+}
 
-Storage_Root::Storage_Root (const TCollection_AsciiString&    theName,
-                            const Handle(Standard_Persistent)& theObject)
-  : myName   (theName)
-  , myObject (theObject)
-  , myRef    (0)
-{}
+Storage_Root::Storage_Root(const TCollection_AsciiString&     theName,
+                           const Handle(Standard_Persistent)& theObject)
+    : myName(theName),
+      myObject(theObject),
+      myRef(0)
+{
+}
 
-Storage_Root::Storage_Root (const TCollection_AsciiString& theName,
-                            const Standard_Integer         theRef,
-                            const TCollection_AsciiString& theType)
-  : myName (theName)
-  , myType (theType)
-  , myRef  (theRef)
-{}
+Storage_Root::Storage_Root(const TCollection_AsciiString& theName,
+                           const Standard_Integer         theRef,
+                           const TCollection_AsciiString& theType)
+    : myName(theName),
+      myType(theType),
+      myRef(theRef)
+{
+}
 
-void Storage_Root::SetName (const TCollection_AsciiString& theName) 
+void Storage_Root::SetName(const TCollection_AsciiString& theName)
 {
   myName = theName;
 }
@@ -48,7 +51,7 @@ TCollection_AsciiString Storage_Root::Name() const
   return myName;
 }
 
-void Storage_Root::SetObject(const Handle(Standard_Persistent)& anObject) 
+void Storage_Root::SetObject(const Handle(Standard_Persistent)& anObject)
 {
   myObject = anObject;
 }
@@ -63,7 +66,7 @@ TCollection_AsciiString Storage_Root::Type() const
   return myType;
 }
 
-void Storage_Root::SetReference(const Standard_Integer aRef) 
+void Storage_Root::SetReference(const Standard_Integer aRef)
 {
   myRef = aRef;
 }
@@ -73,7 +76,7 @@ Standard_Integer Storage_Root::Reference() const
   return myRef;
 }
 
-void Storage_Root::SetType(const TCollection_AsciiString& aType) 
+void Storage_Root::SetType(const TCollection_AsciiString& aType)
 {
   myType = aType;
 }
