@@ -13,7 +13,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <TFunction_DataMapOfLabelListOfLabel.hxx>
 #include <TFunction_DriverTable.hxx>
 #include <TFunction_Function.hxx>
@@ -22,11 +21,11 @@
 #include <TFunction_Scope.hxx>
 
 //=======================================================================
-//function : NewFunction
-//purpose  : Static method to create a new function.
+// function : NewFunction
+// purpose  : Static method to create a new function.
 //=======================================================================
-Standard_Boolean TFunction_IFunction::NewFunction(const TDF_Label& L, const Standard_GUID& ID) 
-{ 
+Standard_Boolean TFunction_IFunction::NewFunction(const TDF_Label& L, const Standard_GUID& ID)
+{
   // Set Function (ID, code of failure)
   TFunction_Function::Set(L, ID)->SetFailure(0);
 
@@ -43,20 +42,20 @@ Standard_Boolean TFunction_IFunction::NewFunction(const TDF_Label& L, const Stan
 }
 
 //=======================================================================
-//function : DeleteFunction
-//purpose  : Static method to delete a function.
+// function : DeleteFunction
+// purpose  : Static method to delete a function.
 //=======================================================================
 
-Standard_Boolean TFunction_IFunction::DeleteFunction(const TDF_Label& L) 
-{ 
+Standard_Boolean TFunction_IFunction::DeleteFunction(const TDF_Label& L)
+{
   // Delete Function
   Handle(TFunction_Function) func;
   if (L.FindAttribute(TFunction_Function::GetID(), func))
     L.ForgetAttribute(func);
 
   // Take the scope of functions
-  Handle(TFunction_Scope) scope = TFunction_Scope::Set(L);
-  const Standard_Integer funcID = scope->GetFunctions().Find2(L);
+  Handle(TFunction_Scope) scope  = TFunction_Scope::Set(L);
+  const Standard_Integer  funcID = scope->GetFunctions().Find2(L);
 
   // Delete graph node
   Handle(TFunction_GraphNode) graphNode;
@@ -68,23 +67,23 @@ Standard_Boolean TFunction_IFunction::DeleteFunction(const TDF_Label& L)
     TColStd_MapIteratorOfMapOfInteger itrm(prev);
     for (; itrm.More(); itrm.Next())
     {
-      const Standard_Integer ID = itrm.Key();
-      const TDF_Label& La = scope->GetFunctions().Find1(ID);
+      const Standard_Integer      ID = itrm.Key();
+      const TDF_Label&            La = scope->GetFunctions().Find1(ID);
       Handle(TFunction_GraphNode) G;
       if (La.FindAttribute(TFunction_GraphNode::GetID(), G))
       {
-	G->RemoveNext(funcID);
+        G->RemoveNext(funcID);
       }
     }
     // Disconnect next functions
     for (itrm.Initialize(next); itrm.More(); itrm.Next())
     {
-      const Standard_Integer ID = itrm.Key();
-      const TDF_Label& La = scope->GetFunctions().Find1(ID);
+      const Standard_Integer      ID = itrm.Key();
+      const TDF_Label&            La = scope->GetFunctions().Find1(ID);
       Handle(TFunction_GraphNode) G;
       if (La.FindAttribute(TFunction_GraphNode::GetID(), G))
       {
-	G->RemovePrevious(funcID);
+        G->RemovePrevious(funcID);
       }
     }
 
@@ -98,8 +97,8 @@ Standard_Boolean TFunction_IFunction::DeleteFunction(const TDF_Label& L)
 }
 
 //=======================================================================
-//function : UpdateDependencies
-//purpose  : Updates the dependencies of all functions.
+// function : UpdateDependencies
+// purpose  : Updates the dependencies of all functions.
 //=======================================================================
 
 Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access)
@@ -108,12 +107,12 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access
   Handle(TFunction_Scope) scope = TFunction_Scope::Set(Access);
 
   // Make a data map of function - results.
-  TFunction_DataMapOfLabelListOfLabel table;
+  TFunction_DataMapOfLabelListOfLabel                  table;
   TFunction_DoubleMapIteratorOfDoubleMapOfIntegerLabel itrm(scope->GetFunctions());
   for (; itrm.More(); itrm.Next())
   {
     // Label of the function
-    const TDF_Label& L = itrm.Key2();
+    const TDF_Label&    L = itrm.Key2();
     TFunction_IFunction iFunction(L);
 
     // Take the driver.
@@ -125,7 +124,7 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access
 
     // Fill-in the table
     table.Bind(L, res);
-    
+
     // Clean the graph node
     Handle(TFunction_GraphNode) graphNode = iFunction.GetGraphNode();
     graphNode->RemoveAllPrevious();
@@ -137,7 +136,7 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access
   for (itrm.Initialize(scope->GetFunctions()); itrm.More(); itrm.Next())
   {
     // Label of the functions
-    const TDF_Label& L = itrm.Key2();
+    const TDF_Label&    L = itrm.Key2();
     TFunction_IFunction iFunction(L);
 
     // Take the driver.
@@ -146,9 +145,9 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access
     // Take the arguments.
     TDF_LabelList args;
     driver->Arguments(args);
-    
+
     // Make a map of arguments
-    TDF_LabelMap argsMap;
+    TDF_LabelMap                argsMap;
     TDF_ListIteratorOfLabelList itrl(args);
     for (; itrl.More(); itrl.Next())
       argsMap.Add(itrl.Value());
@@ -161,18 +160,18 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access
     {
       const TDF_Label& anotherL = itrd.Key();
       if (L == anotherL)
-	continue;
+        continue;
       const TDF_LabelList& anotherRes = itrd.Value();
 
       for (itrl.Initialize(anotherRes); itrl.More(); itrl.Next())
       {
-	if (argsMap.Contains(itrl.Value()))
-	{
-	  iFunction.GetGraphNode()->AddPrevious(anotherL);
+        if (argsMap.Contains(itrl.Value()))
+        {
+          iFunction.GetGraphNode()->AddPrevious(anotherL);
 
-	  TFunction_IFunction iAnotherFunction(anotherL);
-	  iAnotherFunction.GetGraphNode()->AddNext(funcID);
-	}
+          TFunction_IFunction iAnotherFunction(anotherL);
+          iAnotherFunction.GetGraphNode()->AddNext(funcID);
+        }
       }
     }
   }
@@ -180,20 +179,11 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies(const TDF_Label& Access
   return Standard_True;
 }
 
-//=======================================================================
-//function : Create
-//purpose  : Constructor
-//=======================================================================
+//=================================================================================================
 
-TFunction_IFunction::TFunction_IFunction() 
-{  
+TFunction_IFunction::TFunction_IFunction() {}
 
-}
-
-//=======================================================================
-//function : Create
-//purpose  : Constructor
-//=======================================================================
+//=================================================================================================
 
 TFunction_IFunction::TFunction_IFunction(const TDF_Label& L)
 {
@@ -201,8 +191,8 @@ TFunction_IFunction::TFunction_IFunction(const TDF_Label& L)
 }
 
 //=======================================================================
-//function : Init
-//purpose  : Initializes the interface.
+// function : Init
+// purpose  : Initializes the interface.
 //=======================================================================
 
 void TFunction_IFunction::Init(const TDF_Label& L)
@@ -211,8 +201,8 @@ void TFunction_IFunction::Init(const TDF_Label& L)
 }
 
 //=======================================================================
-//function : Label
-//purpose  : Returns the label of the interface.
+// function : Label
+// purpose  : Returns the label of the interface.
 //=======================================================================
 
 const TDF_Label& TFunction_IFunction::Label() const
@@ -221,20 +211,20 @@ const TDF_Label& TFunction_IFunction::Label() const
 }
 
 //=======================================================================
-//function : UpdateDependencies
-//purpose  : Updates the dependencies of this function only.
+// function : UpdateDependencies
+// purpose  : Updates the dependencies of this function only.
 //=======================================================================
 
 Standard_Boolean TFunction_IFunction::UpdateDependencies() const
 {
   // Take the arguments & results of the functions
-  TDF_LabelList args, res;
+  TDF_LabelList            args, res;
   Handle(TFunction_Driver) D = GetDriver();
   D->Arguments(args);
   D->Results(res);
 
   // Insert the arguments and results into maps for fast searching.
-  TDF_LabelMap argsMap, resMap;
+  TDF_LabelMap                argsMap, resMap;
   TDF_ListIteratorOfLabelList itrl(args);
   for (; itrl.More(); itrl.Next())
   {
@@ -246,7 +236,7 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies() const
   }
 
   // Consider all other functions checking their attitude to this function.
-  Handle(TFunction_Scope) scope = TFunction_Scope::Set(myLabel);
+  Handle(TFunction_Scope)                              scope = TFunction_Scope::Set(myLabel);
   TFunction_DoubleMapIteratorOfDoubleMapOfIntegerLabel itrm(scope->GetFunctions());
   for (; itrm.More(); itrm.Next())
   {
@@ -265,9 +255,9 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies() const
     {
       if (resMap.Contains(itrl.Value()))
       {
-	// Our function is a previous one for this function.
-	GetGraphNode()->AddNext(scope->GetFunctions().Find2(L));
-	iFunc.GetGraphNode()->AddPrevious(scope->GetFunctions().Find2(myLabel));
+        // Our function is a previous one for this function.
+        GetGraphNode()->AddNext(scope->GetFunctions().Find2(L));
+        iFunc.GetGraphNode()->AddPrevious(scope->GetFunctions().Find2(myLabel));
       }
     }
 
@@ -280,9 +270,9 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies() const
     {
       if (argsMap.Contains(itrl.Value()))
       {
-	// Our function is a next one for this function.
-	GetGraphNode()->AddPrevious(scope->GetFunctions().Find2(L));
-	iFunc.GetGraphNode()->AddNext(scope->GetFunctions().Find2(myLabel));
+        // Our function is a next one for this function.
+        GetGraphNode()->AddPrevious(scope->GetFunctions().Find2(L));
+        iFunc.GetGraphNode()->AddNext(scope->GetFunctions().Find2(myLabel));
       }
     }
   }
@@ -291,8 +281,8 @@ Standard_Boolean TFunction_IFunction::UpdateDependencies() const
 }
 
 //=======================================================================
-//function : Arguments
-//purpose  : The method fills-in the list by labels, 
+// function : Arguments
+// purpose  : The method fills-in the list by labels,
 //           where the arguments of the function are located.
 //=======================================================================
 
@@ -303,8 +293,8 @@ void TFunction_IFunction::Arguments(TDF_LabelList& args) const
 }
 
 //=======================================================================
-//function : Results
-//purpose  : The method fills-in the list by labels,
+// function : Results
+// purpose  : The method fills-in the list by labels,
 //           where the results of the function are located.
 //=======================================================================
 
@@ -315,15 +305,15 @@ void TFunction_IFunction::Results(TDF_LabelList& res) const
 }
 
 //=======================================================================
-//function : GetPrevious
-//purpose  : Returns a list of previous functions.
+// function : GetPrevious
+// purpose  : Returns a list of previous functions.
 //=======================================================================
 
 void TFunction_IFunction::GetPrevious(TDF_LabelList& prev) const
 {
   Handle(TFunction_GraphNode) graph = GetGraphNode();
-  const TColStd_MapOfInteger& map = graph->GetPrevious();
-  Handle(TFunction_Scope) scope = TFunction_Scope::Set(myLabel);
+  const TColStd_MapOfInteger& map   = graph->GetPrevious();
+  Handle(TFunction_Scope)     scope = TFunction_Scope::Set(myLabel);
 
   TColStd_MapIteratorOfMapOfInteger itrm(map);
   for (; itrm.More(); itrm.Next())
@@ -337,15 +327,15 @@ void TFunction_IFunction::GetPrevious(TDF_LabelList& prev) const
 }
 
 //=======================================================================
-//function : GetNext
-//purpose  : Returns a list of next functions.
+// function : GetNext
+// purpose  : Returns a list of next functions.
 //=======================================================================
 
 void TFunction_IFunction::GetNext(TDF_LabelList& next) const
 {
   Handle(TFunction_GraphNode) graph = GetGraphNode();
-  const TColStd_MapOfInteger& map = graph->GetNext();
-  Handle(TFunction_Scope) scope = TFunction_Scope::Set(myLabel);
+  const TColStd_MapOfInteger& map   = graph->GetNext();
+  Handle(TFunction_Scope)     scope = TFunction_Scope::Set(myLabel);
 
   TColStd_MapIteratorOfMapOfInteger itrm(map);
   for (; itrm.More(); itrm.Next())
@@ -359,8 +349,8 @@ void TFunction_IFunction::GetNext(TDF_LabelList& next) const
 }
 
 //=======================================================================
-//function : GetStatus
-//purpose  : Returns the execution status of the function.
+// function : GetStatus
+// purpose  : Returns the execution status of the function.
 //=======================================================================
 
 TFunction_ExecutionStatus TFunction_IFunction::GetStatus() const
@@ -370,8 +360,8 @@ TFunction_ExecutionStatus TFunction_IFunction::GetStatus() const
 }
 
 //=======================================================================
-//function : SetStatus
-//purpose  : Defines an execution status for a function.
+// function : SetStatus
+// purpose  : Defines an execution status for a function.
 //=======================================================================
 
 void TFunction_IFunction::SetStatus(const TFunction_ExecutionStatus status) const
@@ -381,8 +371,8 @@ void TFunction_IFunction::SetStatus(const TFunction_ExecutionStatus status) cons
 }
 
 //=======================================================================
-//function : GetFunctions
-//purpose  : Returns the scope of functions.
+// function : GetFunctions
+// purpose  : Returns the scope of functions.
 //=======================================================================
 
 const TFunction_DoubleMapOfIntegerLabel& TFunction_IFunction::GetAllFunctions() const
@@ -391,8 +381,8 @@ const TFunction_DoubleMapOfIntegerLabel& TFunction_IFunction::GetAllFunctions()
 }
 
 //=======================================================================
-//function : GetLogbook
-//purpose  : Returns the Logbook.
+// function : GetLogbook
+// purpose  : Returns the Logbook.
 //=======================================================================
 
 Handle(TFunction_Logbook) TFunction_IFunction::GetLogbook() const
@@ -401,31 +391,34 @@ Handle(TFunction_Logbook) TFunction_IFunction::GetLogbook() const
 }
 
 //=======================================================================
-//function : GetDriver
-//purpose  : Returns the function driver.
+// function : GetDriver
+// purpose  : Returns the function driver.
 //=======================================================================
 
 Handle(TFunction_Driver) TFunction_IFunction::GetDriver(const Standard_Integer thread) const
 {
-  Handle(TFunction_Driver) driver;
+  Handle(TFunction_Driver)   driver;
   Handle(TFunction_Function) func;
   if (!myLabel.FindAttribute(TFunction_Function::GetID(), func))
-    throw Standard_NoSuchObject("TFunction_IFunction::GetDriver(): A Function is not found attached to this label");
+    throw Standard_NoSuchObject(
+      "TFunction_IFunction::GetDriver(): A Function is not found attached to this label");
   if (!TFunction_DriverTable::Get()->FindDriver(func->GetDriverGUID(), driver, thread))
-    throw Standard_NoSuchObject("TFunction_IFunction::GetDriver(): A driver is not found for this ID");
+    throw Standard_NoSuchObject(
+      "TFunction_IFunction::GetDriver(): A driver is not found for this ID");
   driver->Init(myLabel);
   return driver;
 }
 
 //=======================================================================
-//function : GetGraphNode
-//purpose  : Returns a graph node of the function.
+// function : GetGraphNode
+// purpose  : Returns a graph node of the function.
 //=======================================================================
 
 Handle(TFunction_GraphNode) TFunction_IFunction::GetGraphNode() const
 {
   Handle(TFunction_GraphNode) graphNode;
   if (!myLabel.FindAttribute(TFunction_GraphNode::GetID(), graphNode))
-    throw Standard_NoSuchObject("TFunction_IFunction::GetStatus(): A graph node is not found attached to this label");
+    throw Standard_NoSuchObject(
+      "TFunction_IFunction::GetStatus(): A graph node is not found attached to this label");
   return graphNode;
 }
