@@ -11,16 +11,11 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <AIS_InteractiveObject.hxx>
 #include <Standard_Type.hxx>
 #include <TDF_Label.hxx>
 #include <TPrsStd_Driver.hxx>
 
-IMPLEMENT_STANDARD_RTTIEXT(TPrsStd_Driver,Standard_Transient)
-
-TPrsStd_Driver::TPrsStd_Driver()
-{}
-
-
+IMPLEMENT_STANDARD_RTTIEXT(TPrsStd_Driver, Standard_Transient)
 
+TPrsStd_Driver::TPrsStd_Driver() {}
