@@ -11,11 +11,11 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-//:S4134 abv 10.03.99: working methods moved from package TopoDSToGBWire
-//:j1 modified by abv 22 Oct 98: CSR BUC60401
+//: S4134 abv 10.03.99: working methods moved from package TopoDSToGBWire
+//: j1 modified by abv 22 Oct 98: CSR BUC60401
 // - unused parts of code dropped
 // - fixed trimming of circles and ellipses (radians used instead of degrees)
-//szv#4 S4163
+// szv#4 S4163
 
 #include <Adaptor3d_CurveOnSurface.hxx>
 #include <BRep_Tool.hxx>
@@ -57,7 +57,7 @@
 // Purpose :
 // ============================================================================
 TopoDSToStep_WireframeBuilder::TopoDSToStep_WireframeBuilder()
-: myError(TopoDSToStep_BuilderOther)
+    : myError(TopoDSToStep_BuilderOther)
 {
   done = Standard_False;
 }
@@ -67,9 +67,10 @@ TopoDSToStep_WireframeBuilder::TopoDSToStep_WireframeBuilder()
 // Purpose :
 // ============================================================================
 
- TopoDSToStep_WireframeBuilder::TopoDSToStep_WireframeBuilder(const TopoDS_Shape& aShape,
-                                                              TopoDSToStep_Tool& aTool,
-                                                              const StepData_Factors& theLocalFactors)
+TopoDSToStep_WireframeBuilder::TopoDSToStep_WireframeBuilder(
+  const TopoDS_Shape&     aShape,
+  TopoDSToStep_Tool&      aTool,
+  const StepData_Factors& theLocalFactors)
 {
   done = Standard_False;
   Init(aShape, aTool, theLocalFactors);
@@ -79,10 +80,9 @@ void TopoDSToStep_WireframeBuilder::Init(const TopoDS_Shape& aShape,
                                          TopoDSToStep_Tool& /* T */,
                                          const StepData_Factors& theLocalFactors)
 {
-  Handle(TColStd_HSequenceOfTransient) itemList =
-    new TColStd_HSequenceOfTransient();
-  MoniTool_DataMapOfShapeTransient aPmsMap;
-  done = GetTrimmedCurveFromShape(aShape, aPmsMap, itemList, theLocalFactors);
+  Handle(TColStd_HSequenceOfTransient) itemList = new TColStd_HSequenceOfTransient();
+  MoniTool_DataMapOfShapeTransient     aPmsMap;
+  done     = GetTrimmedCurveFromShape(aShape, aPmsMap, itemList, theLocalFactors);
   myResult = itemList;
 }
 
@@ -91,9 +91,9 @@ void TopoDSToStep_WireframeBuilder::Init(const TopoDS_Shape& aShape,
 // Purpose :
 // ============================================================================
 
-TopoDSToStep_BuilderError TopoDSToStep_WireframeBuilder::Error() const 
+TopoDSToStep_BuilderError TopoDSToStep_WireframeBuilder::Error() const
 {
-	return myError;
+  return myError;
 }
 
 // ============================================================================
@@ -101,65 +101,62 @@ TopoDSToStep_BuilderError TopoDSToStep_WireframeBuilder::Error() const
 // Purpose :
 // ============================================================================
 
-const Handle(TColStd_HSequenceOfTransient)& TopoDSToStep_WireframeBuilder::Value() const 
+const Handle(TColStd_HSequenceOfTransient)& TopoDSToStep_WireframeBuilder::Value() const
 {
-  StdFail_NotDone_Raise_if (!done, "TopoDSToStep_WireframeBuilder::Value() - no result");
+  StdFail_NotDone_Raise_if(!done, "TopoDSToStep_WireframeBuilder::Value() - no result");
   return myResult;
 }
 
-
 // ============================================================================
-//:S4134: abv 10 Mar 99: the methods below moved from package TopoDSToGBWire
+//: S4134: abv 10 Mar 99: the methods below moved from package TopoDSToGBWire
 
 #define Nbpt 23
 
-static Handle(StepGeom_TrimmedCurve) MakeTrimmedCurve (const Handle(StepGeom_Curve) &C,
-						       const Handle(StepGeom_CartesianPoint)& P1,
-						       const Handle(StepGeom_CartesianPoint)& P2,
-						       Standard_Real trim1,
-						       Standard_Real trim2,
-						       Standard_Boolean sense)
+static Handle(StepGeom_TrimmedCurve) MakeTrimmedCurve(const Handle(StepGeom_Curve)&          C,
+                                                      const Handle(StepGeom_CartesianPoint)& P1,
+                                                      const Handle(StepGeom_CartesianPoint)& P2,
+                                                      Standard_Real                          trim1,
+                                                      Standard_Real                          trim2,
+                                                      Standard_Boolean                       sense)
 {
-  Handle(StepGeom_HArray1OfTrimmingSelect) aSTS1 =
-    new StepGeom_HArray1OfTrimmingSelect(1,2);
-  StepGeom_TrimmingSelect tSel;
+  Handle(StepGeom_HArray1OfTrimmingSelect) aSTS1 = new StepGeom_HArray1OfTrimmingSelect(1, 2);
+  StepGeom_TrimmingSelect                  tSel;
   tSel.SetValue(P1);
-  aSTS1->SetValue(1,tSel);
+  aSTS1->SetValue(1, tSel);
   tSel.SetParameterValue(trim1);
-  aSTS1->SetValue(2,tSel);
-    
-  Handle(StepGeom_HArray1OfTrimmingSelect) aSTS2 =
-    new StepGeom_HArray1OfTrimmingSelect(1,2);
+  aSTS1->SetValue(2, tSel);
+
+  Handle(StepGeom_HArray1OfTrimmingSelect) aSTS2 = new StepGeom_HArray1OfTrimmingSelect(1, 2);
   tSel.SetValue(P2);
-  aSTS2->SetValue(1,tSel);
+  aSTS2->SetValue(1, tSel);
   tSel.SetParameterValue(trim2);
-  aSTS2->SetValue(2,tSel);
-    
-  Handle(TCollection_HAsciiString) empty = 
-      new TCollection_HAsciiString("");
-  Handle(StepGeom_TrimmedCurve) pmsTC = new StepGeom_TrimmedCurve;
-  pmsTC->Init(empty,C,aSTS1,aSTS2,sense,StepGeom_tpParameter);
+  aSTS2->SetValue(2, tSel);
+
+  Handle(TCollection_HAsciiString) empty = new TCollection_HAsciiString("");
+  Handle(StepGeom_TrimmedCurve)    pmsTC = new StepGeom_TrimmedCurve;
+  pmsTC->Init(empty, C, aSTS1, aSTS2, sense, StepGeom_tpParameter);
   return pmsTC;
 }
-  
-Standard_Boolean TopoDSToStep_WireframeBuilder::
-  GetTrimmedCurveFromEdge(const TopoDS_Edge& theEdge,
-                          const TopoDS_Face& theFace,
-                          MoniTool_DataMapOfShapeTransient& theMap,
-                          Handle(TColStd_HSequenceOfTransient)& theCurveList,
-                          const StepData_Factors& theLocalFactors) const
+
+Standard_Boolean TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromEdge(
+  const TopoDS_Edge&                    theEdge,
+  const TopoDS_Face&                    theFace,
+  MoniTool_DataMapOfShapeTransient&     theMap,
+  Handle(TColStd_HSequenceOfTransient)& theCurveList,
+  const StepData_Factors&               theLocalFactors) const
 {
-  if (theEdge.Orientation() == TopAbs_INTERNAL ||
-      theEdge.Orientation() == TopAbs_EXTERNAL )
+  if (theEdge.Orientation() == TopAbs_INTERNAL || theEdge.Orientation() == TopAbs_EXTERNAL)
   {
 #ifdef OCCT_DEBUG
-    std::cout <<"Warning: TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromEdge: Edge is internal or external; dropped" << std::endl;
+    std::cout << "Warning: TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromEdge: Edge is "
+                 "internal or external; dropped"
+              << std::endl;
 #endif
     return Standard_False;
   }
-  //szv#4:S4163:12Mar99 SGI warns
-  TopoDS_Shape aSh = theEdge.Oriented(TopAbs_FORWARD);
-  TopoDS_Edge anEdge = TopoDS::Edge ( aSh );
+  // szv#4:S4163:12Mar99 SGI warns
+  TopoDS_Shape aSh    = theEdge.Oriented(TopAbs_FORWARD);
+  TopoDS_Edge  anEdge = TopoDS::Edge(aSh);
 
   // resulting curve
   Handle(StepGeom_Curve) aSGC;
@@ -169,22 +166,22 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
   }
 
   BRepAdaptor_Curve aCA;
-  try 
+  try
   {
     OCC_CATCH_SIGNALS
-    aCA.Initialize (anEdge);
+    aCA.Initialize(anEdge);
   }
-  catch (Standard_NullObject const&) 
+  catch (Standard_NullObject const&)
   {
     return Standard_False;
   }
 
-  TopoDS_Vertex aVFirst, aVLast;
+  TopoDS_Vertex                   aVFirst, aVLast;
   Handle(StepGeom_CartesianPoint) aSGCP1, aSGCP2;
   for (TopExp_Explorer anExp(anEdge, TopAbs_VERTEX); anExp.More(); anExp.Next())
   {
     TopoDS_Vertex aVertex = TopoDS::Vertex(anExp.Value());
-    gp_Pnt aGpP = BRep_Tool::Pnt(aVertex);
+    gp_Pnt        aGpP    = BRep_Tool::Pnt(aVertex);
     if (aVertex.Orientation() == TopAbs_FORWARD)
     {
       aVFirst = aVertex;
@@ -201,7 +198,7 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
     }
   }
 
-  Standard_Real aFirst, aLast;
+  Standard_Real      aFirst, aLast;
   Handle(Geom_Curve) aC = BRep_Tool::Curve(anEdge, aFirst, aLast);
 
   if (!aC.IsNull())
@@ -221,7 +218,8 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
     Standard_Real aTrim1 = aCA.FirstParameter();
     Standard_Real aTrim2 = aCA.LastParameter();
 
-    if (aVFirst.IsNull() && aVLast.IsNull() && Precision::IsInfinite(aFirst) && Precision::IsInfinite(aLast))
+    if (aVFirst.IsNull() && aVLast.IsNull() && Precision::IsInfinite(aFirst)
+        && Precision::IsInfinite(aLast))
     {
       GeomToStep_MakeCurve aCurveMaker(aC, theLocalFactors);
       if (aCurveMaker.IsDone())
@@ -263,9 +261,9 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
     Standard_Boolean aIPlan = Standard_False;
     if (!theFace.IsNull())
     {
-      Standard_Real aCF, aCL;
+      Standard_Real        aCF, aCL;
       Handle(Geom2d_Curve) aC2d = BRep_Tool::CurveOnSurface(anEdge, theFace, aCF, aCL);
-      Handle(Geom_Surface) aS = BRep_Tool::Surface(theFace);
+      Handle(Geom_Surface) aS   = BRep_Tool::Surface(theFace);
       if (aS->IsKind(STANDARD_TYPE(Geom_Plane)) && aC2d->IsKind(STANDARD_TYPE(Geom2d_Line)))
       {
         aIPlan = Standard_True;
@@ -276,31 +274,34 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
     // these are computed after ! (U1 and U2) -> cf and cl instead
     if (aIPlan)
     {
-      gp_Pnt aPnt1 = aCA.Value(aCA.FirstParameter()), aPnt2 = aCA.Value(aCA.LastParameter());
-      gp_Vec aV(aPnt1, aPnt2);
+      gp_Pnt        aPnt1 = aCA.Value(aCA.FirstParameter()), aPnt2 = aCA.Value(aCA.LastParameter());
+      gp_Vec        aV(aPnt1, aPnt2);
       Standard_Real aLength = aV.Magnitude();
       if (aLength >= Precision::Confusion())
       {
-        Handle(Geom_Line) aL = new Geom_Line(aPnt1, gp_Dir(aV));
+        Handle(Geom_Line)   aL = new Geom_Line(aPnt1, gp_Dir(aV));
         GeomToStep_MakeLine aGTSML(aL, theLocalFactors);
         aSGC = aGTSML.Value();
         aSGC = MakeTrimmedCurve(aGTSML.Value(), aSGCP1, aSGCP2, 0, aLength, Standard_True);
       }
 #ifdef OCCT_DEBUG
-      else std::cout << "Warning: TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromEdge: Null-length curve not mapped" << std::endl;
+      else
+        std::cout << "Warning: TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromEdge: Null-length "
+                     "curve not mapped"
+                  << std::endl;
 #endif
     }
     else
-    {         
-      TColgp_Array1OfPnt aPoints(1, Nbpt);
-      TColStd_Array1OfReal aKnots(1, Nbpt);
+    {
+      TColgp_Array1OfPnt      aPoints(1, Nbpt);
+      TColStd_Array1OfReal    aKnots(1, Nbpt);
       TColStd_Array1OfInteger aMult(1, Nbpt);
-      Standard_Real aU1 = aCA.FirstParameter();
-      Standard_Real aU2 = aCA.LastParameter();
+      Standard_Real           aU1 = aCA.FirstParameter();
+      Standard_Real           aU2 = aCA.LastParameter();
       for (Standard_Integer i = 1; i <= Nbpt; i++)
       {
         Standard_Real aU = aU1 + (i - 1) * (aU2 - aU1) / (Nbpt - 1);
-        gp_Pnt aP = aCA.Value(aU);
+        gp_Pnt        aP = aCA.Value(aU);
         aPoints.SetValue(i, aP);
         aKnots.SetValue(i, aU);
         aMult.SetValue(i, 1);
@@ -309,7 +310,7 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
       aPoints.SetValue(Nbpt, BRep_Tool::Pnt(aVLast));
       aMult.SetValue(1, 2);
       aMult.SetValue(Nbpt, 2);
-      Handle(Geom_Curve) aBSCurve = new Geom_BSplineCurve(aPoints, aKnots, aMult, 1);
+      Handle(Geom_Curve)   aBSCurve = new Geom_BSplineCurve(aPoints, aKnots, aMult, 1);
       GeomToStep_MakeCurve aGTSMC(aBSCurve, theLocalFactors);
       aSGC = aGTSMC.Value();
     }
@@ -325,102 +326,119 @@ Standard_Boolean TopoDSToStep_WireframeBuilder::
   return Standard_True;
 }
 
-
-Standard_Boolean TopoDSToStep_WireframeBuilder::
-  GetTrimmedCurveFromFace(const TopoDS_Face& aFace, 
-                          MoniTool_DataMapOfShapeTransient& aMap, 
-                          Handle(TColStd_HSequenceOfTransient)& aCurveList,
-                          const StepData_Factors& theLocalFactors) const
+Standard_Boolean TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromFace(
+  const TopoDS_Face&                    aFace,
+  MoniTool_DataMapOfShapeTransient&     aMap,
+  Handle(TColStd_HSequenceOfTransient)& aCurveList,
+  const StepData_Factors&               theLocalFactors) const
 {
-  TopoDS_Shape curShape;
-  TopoDS_Edge  curEdge;
-  TopExp_Explorer  exp;
+  TopoDS_Shape    curShape;
+  TopoDS_Edge     curEdge;
+  TopExp_Explorer exp;
+  // clang-format off
   Standard_Boolean result = Standard_False; //szv#4:S4163:12Mar99 `done` hid one from this, initialisation needed
+  // clang-format on
 
-  for (exp.Init(aFace,TopAbs_EDGE); exp.More(); exp.Next()){
+  for (exp.Init(aFace, TopAbs_EDGE); exp.More(); exp.Next())
+  {
     curShape = exp.Current();
     curEdge  = TopoDS::Edge(curShape);
-    if (GetTrimmedCurveFromEdge(curEdge, aFace, aMap, aCurveList, theLocalFactors)) result = Standard_True;
+    if (GetTrimmedCurveFromEdge(curEdge, aFace, aMap, aCurveList, theLocalFactors))
+      result = Standard_True;
   }
   return result;
 }
 
-Standard_Boolean TopoDSToStep_WireframeBuilder::
-  GetTrimmedCurveFromShape(const TopoDS_Shape& aShape, 
-                           MoniTool_DataMapOfShapeTransient& aMap,  
-                           Handle(TColStd_HSequenceOfTransient)& aCurveList,
-                           const StepData_Factors& theLocalFactors) const
+Standard_Boolean TopoDSToStep_WireframeBuilder::GetTrimmedCurveFromShape(
+  const TopoDS_Shape&                   aShape,
+  MoniTool_DataMapOfShapeTransient&     aMap,
+  Handle(TColStd_HSequenceOfTransient)& aCurveList,
+  const StepData_Factors&               theLocalFactors) const
 {
-  TopoDS_Iterator  It;
+  TopoDS_Iterator It;
+  // clang-format off
   Standard_Boolean result = Standard_False; //szv#4:S4163:12Mar99 `done` hid one from this, initialisation needed
+  // clang-format on
 
-  //szv#4:S4163:12Mar99 optimized
-  switch (aShape.ShapeType()) {
-    case TopAbs_EDGE : {
+  // szv#4:S4163:12Mar99 optimized
+  switch (aShape.ShapeType())
+  {
+    case TopAbs_EDGE: {
       const TopoDS_Edge& curEdge = TopoDS::Edge(aShape);
-      TopoDS_Face nulFace;
+      TopoDS_Face        nulFace;
       result = GetTrimmedCurveFromEdge(curEdge, nulFace, aMap, aCurveList, theLocalFactors);
       break;
     }
-    case TopAbs_WIRE : {
-      TopoDS_Face nulFace;
-      TopoDS_Shape curShape;
-      TopoDS_Edge  curEdge;
-      TopExp_Explorer  exp;
+    case TopAbs_WIRE: {
+      TopoDS_Face     nulFace;
+      TopoDS_Shape    curShape;
+      TopoDS_Edge     curEdge;
+      TopExp_Explorer exp;
 
-      for (exp.Init(aShape,TopAbs_EDGE); exp.More(); exp.Next()){
-	curShape = exp.Current();
-	curEdge  = TopoDS::Edge(curShape);
-	if (GetTrimmedCurveFromEdge(curEdge, nulFace, aMap, aCurveList, theLocalFactors)) result = Standard_True;
+      for (exp.Init(aShape, TopAbs_EDGE); exp.More(); exp.Next())
+      {
+        curShape = exp.Current();
+        curEdge  = TopoDS::Edge(curShape);
+        if (GetTrimmedCurveFromEdge(curEdge, nulFace, aMap, aCurveList, theLocalFactors))
+          result = Standard_True;
       }
       break;
     }
-    case TopAbs_FACE : {
+    case TopAbs_FACE: {
       const TopoDS_Face& curFace = TopoDS::Face(aShape);
       result = GetTrimmedCurveFromFace(curFace, aMap, aCurveList, theLocalFactors);
       break;
     }
-    case TopAbs_SHELL : {
-      TopoDS_Shell Sh = TopoDS::Shell(aShape);	  
+    case TopAbs_SHELL: {
+      TopoDS_Shell Sh = TopoDS::Shell(aShape);
       It.Initialize(Sh);
-      for (;It.More();It.Next()) {
-	TopoDS_Face curFace = TopoDS::Face(It.Value());
-	if (GetTrimmedCurveFromFace(curFace, aMap, aCurveList, theLocalFactors)) result = Standard_True;
+      for (; It.More(); It.Next())
+      {
+        TopoDS_Face curFace = TopoDS::Face(It.Value());
+        if (GetTrimmedCurveFromFace(curFace, aMap, aCurveList, theLocalFactors))
+          result = Standard_True;
 #ifdef OCCT_DEBUG
-	if(!result) {
-	  std::cout << "ERROR extracting trimmedCurve from Face" << std::endl;
-	  //BRepTools::Dump(curFace,std::cout);  std::cout<<std::endl;
-	}
+        if (!result)
+        {
+          std::cout << "ERROR extracting trimmedCurve from Face" << std::endl;
+          // BRepTools::Dump(curFace,std::cout);  std::cout<<std::endl;
+        }
 #endif
       }
       break;
     }
-    case TopAbs_SOLID : {
+    case TopAbs_SOLID: {
       It.Initialize(aShape);
-      for (;It.More();It.Next()) {
-	if  (It.Value().ShapeType() == TopAbs_SHELL) {
-	  if (GetTrimmedCurveFromShape(It.Value(), aMap, aCurveList, theLocalFactors)) result = Standard_True;
-	}
-      } 
-      break;
-    }
-    case TopAbs_COMPOUND : {
-      It.Initialize(aShape);
-      for (;It.More();It.Next()) {
-/*	  if  ((It.Value().ShapeType() == TopAbs_SHELL) ||
-	       (It.Value().ShapeType() == TopAbs_COMPOUND)) {
-	    result = GetTrimmedCurveFromShape(It.Value(), aMap, aCurveList);
-	    break;
-	  }
-	  else if (It.Value().ShapeType() == TopAbs_FACE) {
-	    result = GetTrimmedCurveFromFace(TopoDS::Face(It.Value()), aMap, aCurveList);
-	    break;
-	  } */
-	if (GetTrimmedCurveFromShape(It.Value(), aMap, aCurveList, theLocalFactors)) result = Standard_True;
+      for (; It.More(); It.Next())
+      {
+        if (It.Value().ShapeType() == TopAbs_SHELL)
+        {
+          if (GetTrimmedCurveFromShape(It.Value(), aMap, aCurveList, theLocalFactors))
+            result = Standard_True;
+        }
       }
       break;
     }
-    default : break;
+    case TopAbs_COMPOUND: {
+      It.Initialize(aShape);
+      for (; It.More(); It.Next())
+      {
+        /*	  if  ((It.Value().ShapeType() == TopAbs_SHELL) ||
+                   (It.Value().ShapeType() == TopAbs_COMPOUND)) {
+                result = GetTrimmedCurveFromShape(It.Value(), aMap, aCurveList);
+                break;
+              }
+              else if (It.Value().ShapeType() == TopAbs_FACE) {
+                result = GetTrimmedCurveFromFace(TopoDS::Face(It.Value()), aMap, aCurveList);
+                break;
+              } */
+        if (GetTrimmedCurveFromShape(It.Value(), aMap, aCurveList, theLocalFactors))
+          result = Standard_True;
+      }
+      break;
+    }
+    default:
+      break;
   }
   return result;
 }
