@@ -11,28 +11,27 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <TCollection_AsciiString.hxx>
 #include <Vrml_WWWInline.hxx>
 
 Vrml_WWWInline::Vrml_WWWInline()
 {
   myName = "";
-  gp_Vec tmpVec(0,0,0);
-  myBboxSize = tmpVec;
+  gp_Vec tmpVec(0, 0, 0);
+  myBboxSize   = tmpVec;
   myBboxCenter = tmpVec;
 }
 
 Vrml_WWWInline::Vrml_WWWInline(const TCollection_AsciiString& aName,
-			       const gp_Vec& aBboxSize,
-			       const gp_Vec& aBboxCenter)
+                               const gp_Vec&                  aBboxSize,
+                               const gp_Vec&                  aBboxCenter)
 {
-  myName = aName;
-  myBboxSize = aBboxSize;
+  myName       = aName;
+  myBboxSize   = aBboxSize;
   myBboxCenter = aBboxCenter;
 }
 
-void Vrml_WWWInline::SetName(const TCollection_AsciiString& aName) 
+void Vrml_WWWInline::SetName(const TCollection_AsciiString& aName)
 {
   myName = aName;
 }
@@ -42,7 +41,7 @@ TCollection_AsciiString Vrml_WWWInline::Name() const
   return myName;
 }
 
-void Vrml_WWWInline::SetBboxSize(const gp_Vec& aBboxSize) 
+void Vrml_WWWInline::SetBboxSize(const gp_Vec& aBboxSize)
 {
   myBboxSize = aBboxSize;
 }
@@ -52,7 +51,7 @@ gp_Vec Vrml_WWWInline::BboxSize() const
   return myBboxSize;
 }
 
-void Vrml_WWWInline::SetBboxCenter(const gp_Vec& aBboxCenter) 
+void Vrml_WWWInline::SetBboxCenter(const gp_Vec& aBboxCenter)
 {
   myBboxCenter = aBboxCenter;
 }
@@ -64,30 +63,28 @@ gp_Vec Vrml_WWWInline::BboxCenter() const
 
 Standard_OStream& Vrml_WWWInline::Print(Standard_OStream& anOStream) const
 {
- anOStream  << "WWWInline {\n";
+  anOStream << "WWWInline {\n";
 
- if ( !(myName.IsEqual ("") ) )
-   {
-    anOStream  << "    name\t";
+  if (!(myName.IsEqual("")))
+  {
+    anOStream << "    name\t";
     anOStream << '"' << myName << '"' << "\n";
-   }
+  }
 
- if ( Abs(myBboxSize.X() - 0) > 0.0001 || 
-     Abs(myBboxSize.Y() - 0) > 0.0001 || 
-     Abs(myBboxSize.Z() - 0) > 0.0001 ) 
-   {
-    anOStream  << "    bboxSize\t";
+  if (Abs(myBboxSize.X() - 0) > 0.0001 || Abs(myBboxSize.Y() - 0) > 0.0001
+      || Abs(myBboxSize.Z() - 0) > 0.0001)
+  {
+    anOStream << "    bboxSize\t";
     anOStream << myBboxSize.X() << " " << myBboxSize.Y() << " " << myBboxSize.Z() << "\n";
-   }
+  }
 
- if ( Abs(myBboxCenter.X() - 0) > 0.0001 || 
-     Abs(myBboxCenter.Y() - 0) > 0.0001 || 
-     Abs(myBboxCenter.Z() - 0) > 0.0001 ) 
-   {
-    anOStream  << "    bboxCenter\t";
+  if (Abs(myBboxCenter.X() - 0) > 0.0001 || Abs(myBboxCenter.Y() - 0) > 0.0001
+      || Abs(myBboxCenter.Z() - 0) > 0.0001)
+  {
+    anOStream << "    bboxCenter\t";
     anOStream << myBboxCenter.X() << " " << myBboxCenter.Y() << " " << myBboxCenter.Z() << "\n";
-   }
+  }
 
- anOStream  << "}\n";
- return anOStream;
+  anOStream << "}\n";
+  return anOStream;
 }
