@@ -18,7 +18,10 @@
 #include <TopoDS_Shape.hxx>
 #include <VrmlAPI_Writer.hxx>
 
-Standard_Boolean VrmlAPI::Write(const TopoDS_Shape& aShape, const Standard_CString aFileName, const Standard_Integer aVersion)  {
+Standard_Boolean VrmlAPI::Write(const TopoDS_Shape&    aShape,
+                                const Standard_CString aFileName,
+                                const Standard_Integer aVersion)
+{
   VrmlAPI_Writer writer;
   return writer.Write(aShape, aFileName, aVersion);
 }
