@@ -17,10 +17,7 @@
 
 #include <Standard_Dump.hxx>
 
-XCAFDoc_AssemblyItemId::XCAFDoc_AssemblyItemId()
-{
-
-}
+XCAFDoc_AssemblyItemId::XCAFDoc_AssemblyItemId() {}
 
 XCAFDoc_AssemblyItemId::XCAFDoc_AssemblyItemId(const TColStd_ListOfAsciiString& thePath)
 {
@@ -32,18 +29,16 @@ XCAFDoc_AssemblyItemId::XCAFDoc_AssemblyItemId(const TCollection_AsciiString& th
   Init(theString);
 }
 
-void 
-XCAFDoc_AssemblyItemId::Init(const TColStd_ListOfAsciiString& thePath)
+void XCAFDoc_AssemblyItemId::Init(const TColStd_ListOfAsciiString& thePath)
 {
   myPath = thePath;
 }
 
-void 
-XCAFDoc_AssemblyItemId::Init(const TCollection_AsciiString& theString)
+void XCAFDoc_AssemblyItemId::Init(const TCollection_AsciiString& theString)
 {
   myPath.Clear();
 
-  for (Standard_Integer iEntry = 1; ; ++iEntry)
+  for (Standard_Integer iEntry = 1;; ++iEntry)
   {
     TCollection_AsciiString anEntry = theString.Token("/", iEntry);
     if (anEntry.IsEmpty())
@@ -53,20 +48,17 @@ XCAFDoc_AssemblyItemId::Init(const TCollection_AsciiString& theString)
   }
 }
 
-Standard_Boolean 
-XCAFDoc_AssemblyItemId::IsNull() const
+Standard_Boolean XCAFDoc_AssemblyItemId::IsNull() const
 {
   return myPath.IsEmpty();
 }
 
-void 
-XCAFDoc_AssemblyItemId::Nullify()
+void XCAFDoc_AssemblyItemId::Nullify()
 {
   myPath.Clear();
 }
 
-Standard_Boolean 
-XCAFDoc_AssemblyItemId::IsChild(const XCAFDoc_AssemblyItemId& theOther) const
+Standard_Boolean XCAFDoc_AssemblyItemId::IsChild(const XCAFDoc_AssemblyItemId& theOther) const
 {
   if (myPath.Size() <= theOther.myPath.Size())
     return Standard_False;
@@ -81,14 +73,12 @@ XCAFDoc_AssemblyItemId::IsChild(const XCAFDoc_AssemblyItemId& theOther) const
   return Standard_True;
 }
 
-Standard_Boolean 
-XCAFDoc_AssemblyItemId::IsDirectChild(const XCAFDoc_AssemblyItemId& theOther) const
+Standard_Boolean XCAFDoc_AssemblyItemId::IsDirectChild(const XCAFDoc_AssemblyItemId& theOther) const
 {
   return ((myPath.Size() == theOther.myPath.Size() - 1) && IsChild(theOther));
 }
 
-Standard_Boolean 
-XCAFDoc_AssemblyItemId::IsEqual(const XCAFDoc_AssemblyItemId& theOther) const
+Standard_Boolean XCAFDoc_AssemblyItemId::IsEqual(const XCAFDoc_AssemblyItemId& theOther) const
 {
   if (this == &theOther)
     return Standard_True;
@@ -106,14 +96,12 @@ XCAFDoc_AssemblyItemId::IsEqual(const XCAFDoc_AssemblyItemId& theOther) const
   return Standard_True;
 }
 
-const 
-TColStd_ListOfAsciiString& XCAFDoc_AssemblyItemId::GetPath() const
+const TColStd_ListOfAsciiString& XCAFDoc_AssemblyItemId::GetPath() const
 {
   return myPath;
 }
 
-TCollection_AsciiString 
-XCAFDoc_AssemblyItemId::ToString() const
+TCollection_AsciiString XCAFDoc_AssemblyItemId::ToString() const
 {
   TCollection_AsciiString aStr;
   for (TColStd_ListOfAsciiString::Iterator anIt(myPath); anIt.More(); anIt.Next())
@@ -125,17 +113,15 @@ XCAFDoc_AssemblyItemId::ToString() const
   return aStr;
 }
 
-//=======================================================================
-//function : DumpJson
-//purpose  : 
-//=======================================================================
-void XCAFDoc_AssemblyItemId::DumpJson (Standard_OStream& theOStream, Standard_Integer) const
-{
-  OCCT_DUMP_CLASS_BEGIN (theOStream, XCAFDoc_AssemblyItemId)
+//=================================================================================================
 
-  for (TColStd_ListOfAsciiString::Iterator aPathIt (myPath); aPathIt.More(); aPathIt.Next())
+void XCAFDoc_AssemblyItemId::DumpJson(Standard_OStream& theOStream, Standard_Integer) const
+{
+  OCCT_DUMP_CLASS_BEGIN(theOStream, XCAFDoc_AssemblyItemId)
+
+  for (TColStd_ListOfAsciiString::Iterator aPathIt(myPath); aPathIt.More(); aPathIt.Next())
   {
     TCollection_AsciiString aPath = aPathIt.Value();
-    OCCT_DUMP_FIELD_VALUE_STRING (theOStream, aPath)
+    OCCT_DUMP_FIELD_VALUE_STRING(theOStream, aPath)
   }
 }
