@@ -24,34 +24,30 @@
 
 #include <stdio.h>
 
-IMPLEMENT_STANDARD_RTTIEXT(XmlMDataXtd_PositionDriver,XmlMDF_ADriver)
+IMPLEMENT_STANDARD_RTTIEXT(XmlMDataXtd_PositionDriver, XmlMDF_ADriver)
 
-//=======================================================================
-//function : XmlMDataXtd_PositionDriver
-//purpose  : Constructor
-//=======================================================================
-XmlMDataXtd_PositionDriver::XmlMDataXtd_PositionDriver
-                        (const Handle(Message_Messenger)& theMsgDriver)
-: XmlMDF_ADriver (theMsgDriver, NULL)
-{}
+//=================================================================================================
+
+XmlMDataXtd_PositionDriver::XmlMDataXtd_PositionDriver(
+  const Handle(Message_Messenger)& theMsgDriver)
+    : XmlMDF_ADriver(theMsgDriver, NULL)
+{
+}
+
+//=================================================================================================
 
-//=======================================================================
-//function : NewEmpty
-//purpose  : 
-//=======================================================================
 Handle(TDF_Attribute) XmlMDataXtd_PositionDriver::NewEmpty() const
 {
   return (new TDataXtd_Position());
 }
 
 //=======================================================================
-//function : Paste
-//purpose  : persistent -> transient (retrieve)
+// function : Paste
+// purpose  : persistent -> transient (retrieve)
 //=======================================================================
-Standard_Boolean XmlMDataXtd_PositionDriver::Paste
-                (const XmlObjMgt_Persistent&  theSource,
-                 const Handle(TDF_Attribute)& theTarget,
-                 XmlObjMgt_RRelocationTable&  ) const
+Standard_Boolean XmlMDataXtd_PositionDriver::Paste(const XmlObjMgt_Persistent&  theSource,
+                                                   const Handle(TDF_Attribute)& theTarget,
+                                                   XmlObjMgt_RRelocationTable&) const
 {
   Handle(TDataXtd_Position) aTPos = Handle(TDataXtd_Position)::DownCast(theTarget);
 
@@ -59,22 +55,22 @@ Standard_Boolean XmlMDataXtd_PositionDriver::Paste
   XmlObjMgt_DOMString aPosStr = XmlObjMgt::GetStringValue(theSource.Element());
   if (aPosStr == NULL)
   {
-    myMessageDriver->Send ("Cannot retrieve position string from element", Message_Fail);
+    myMessageDriver->Send("Cannot retrieve position string from element", Message_Fail);
     return Standard_False;
   }
 
-  gp_Pnt aPos;
-  Standard_Real aValue;
+  gp_Pnt           aPos;
+  Standard_Real    aValue;
   Standard_CString aValueStr = Standard_CString(aPosStr.GetString());
 
   // X
   if (!XmlObjMgt::GetReal(aValueStr, aValue))
   {
     TCollection_ExtendedString aMessageString =
-      TCollection_ExtendedString
-        ("Cannot retrieve X coordinate for TDataXtd_Position attribute as \"")
-          + aValueStr + "\"";
-    myMessageDriver->Send (aMessageString, Message_Fail);
+      TCollection_ExtendedString(
+        "Cannot retrieve X coordinate for TDataXtd_Position attribute as \"")
+      + aValueStr + "\"";
+    myMessageDriver->Send(aMessageString, Message_Fail);
     return Standard_False;
   }
   aPos.SetX(aValue);
@@ -83,10 +79,10 @@ Standard_Boolean XmlMDataXtd_PositionDriver::Paste
   if (!XmlObjMgt::GetReal(aValueStr, aValue))
   {
     TCollection_ExtendedString aMessageString =
-      TCollection_ExtendedString
-        ("Cannot retrieve Y coordinate for TDataXtd_Position attribute as \"")
-          + aValueStr + "\"";
-    myMessageDriver->Send (aMessageString, Message_Fail);
+      TCollection_ExtendedString(
+        "Cannot retrieve Y coordinate for TDataXtd_Position attribute as \"")
+      + aValueStr + "\"";
+    myMessageDriver->Send(aMessageString, Message_Fail);
     return Standard_False;
   }
   aPos.SetY(aValue);
@@ -95,10 +91,10 @@ Standard_Boolean XmlMDataXtd_PositionDriver::Paste
   if (!XmlObjMgt::GetReal(aValueStr, aValue))
   {
     TCollection_ExtendedString aMessageString =
-      TCollection_ExtendedString
-        ("Cannot retrieve Z coordinate for TDataXtd_Position attribute as \"")
-          + aValueStr + "\"";
-    myMessageDriver->Send (aMessageString, Message_Fail);
+      TCollection_ExtendedString(
+        "Cannot retrieve Z coordinate for TDataXtd_Position attribute as \"")
+      + aValueStr + "\"";
+    myMessageDriver->Send(aMessageString, Message_Fail);
     return Standard_False;
   }
   aPos.SetZ(aValue);
@@ -109,20 +105,19 @@ Standard_Boolean XmlMDataXtd_PositionDriver::Paste
 }
 
 //=======================================================================
-//function : Paste
-//purpose  : transient -> persistent (store)
+// function : Paste
+// purpose  : transient -> persistent (store)
 //=======================================================================
-void XmlMDataXtd_PositionDriver::Paste
-                (const Handle(TDF_Attribute)& theSource,
-                 XmlObjMgt_Persistent&        theTarget,
-                 XmlObjMgt_SRelocationTable&  ) const
+void XmlMDataXtd_PositionDriver::Paste(const Handle(TDF_Attribute)& theSource,
+                                       XmlObjMgt_Persistent&        theTarget,
+                                       XmlObjMgt_SRelocationTable&) const
 {
   Handle(TDataXtd_Position) aTPos = Handle(TDataXtd_Position)::DownCast(theSource);
   if (!aTPos.IsNull())
   {
     gp_Pnt aPos = aTPos->GetPosition();
-    char buf [75]; // (24 + 1) * 3
-    Sprintf (buf, "%.17g %.17g %.17g", aPos.X(), aPos.Y(), aPos.Z());
+    char   buf[75]; // (24 + 1) * 3
+    Sprintf(buf, "%.17g %.17g %.17g", aPos.X(), aPos.Y(), aPos.Z());
     XmlObjMgt::SetStringValue(theTarget.Element(), buf);
   }
 }
