@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <gce_MakeParab.hxx>
 #include <gp_Ax1.hxx>
 #include <gp_Ax2.hxx>
@@ -22,31 +21,32 @@
 #include <gp_Pnt.hxx>
 #include <StdFail_NotDone.hxx>
 
-gce_MakeParab::gce_MakeParab(const gp_Ax2&       A2    ,
-			     const Standard_Real Focal ) 
+gce_MakeParab::gce_MakeParab(const gp_Ax2& A2, const Standard_Real Focal)
 {
-  if (Focal < 0.0) { TheError = gce_NullFocusLength; }
-  else {
-    TheParab = gp_Parab(A2,Focal);
+  if (Focal < 0.0)
+  {
+    TheError = gce_NullFocusLength;
+  }
+  else
+  {
+    TheParab = gp_Parab(A2, Focal);
     TheError = gce_Done;
   }
 }
 
-gce_MakeParab::gce_MakeParab(const gp_Ax1& D ,
-			     const gp_Pnt& F )
+gce_MakeParab::gce_MakeParab(const gp_Ax1& D, const gp_Pnt& F)
 {
-  TheParab = gp_Parab(D,F);
+  TheParab = gp_Parab(D, F);
   TheError = gce_Done;
 }
 
-const gp_Parab& gce_MakeParab::Value () const
+const gp_Parab& gce_MakeParab::Value() const
 {
-  StdFail_NotDone_Raise_if (TheError != gce_Done,
-                            "gce_MakeParab::Value() - no result");
+  StdFail_NotDone_Raise_if(TheError != gce_Done, "gce_MakeParab::Value() - no result");
   return TheParab;
 }
 
-const gp_Parab& gce_MakeParab::Operator() const 
+const gp_Parab& gce_MakeParab::Operator() const
 {
   return Value();
 }
@@ -55,4 +55,3 @@ gce_MakeParab::operator gp_Parab() const
 {
   return Value();
 }
-
