@@ -14,7 +14,6 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <gce_MakeScale.hxx>
 #include <gp_Pnt.hxx>
 #include <gp_Trsf.hxx>
@@ -22,18 +21,17 @@
 //=========================================================================
 //   Creation d un homothetie de gp de centre Point et de rapport Scale.  +
 //=========================================================================
-gce_MakeScale::
-  gce_MakeScale(const gp_Pnt&       Point ,
-		const Standard_Real Scale ) {
-   TheScale.SetScale(Point,Scale);
- }
-
-const gp_Trsf& gce_MakeScale::Value() const
-{ 
-  return TheScale; 
+gce_MakeScale::gce_MakeScale(const gp_Pnt& Point, const Standard_Real Scale)
+{
+  TheScale.SetScale(Point, Scale);
 }
 
-const gp_Trsf& gce_MakeScale::Operator() const 
+const gp_Trsf& gce_MakeScale::Value() const
+{
+  return TheScale;
+}
+
+const gp_Trsf& gce_MakeScale::Operator() const
 {
   return TheScale;
 }
