@@ -18,33 +18,38 @@
 #include <gp_Ax2.hxx>
 #include <gp_Pnt.hxx>
 
-void gp_Circ::Mirror (const gp_Pnt& P)
-{ pos.Mirror(P); }
-
-gp_Circ gp_Circ::Mirrored (const gp_Pnt& P) const
+void gp_Circ::Mirror(const gp_Pnt& P)
 {
-  gp_Circ C = *this;
-  C.pos.Mirror (P);
-  return C; 
+  pos.Mirror(P);
 }
 
-void gp_Circ::Mirror (const gp_Ax1& A1)
-{ pos.Mirror(A1); }
-
-gp_Circ gp_Circ::Mirrored (const gp_Ax1& A1) const
+gp_Circ gp_Circ::Mirrored(const gp_Pnt& P) const
 {
   gp_Circ C = *this;
-  C.pos.Mirror (A1);
-  return C; 
+  C.pos.Mirror(P);
+  return C;
 }
 
-void gp_Circ::Mirror (const gp_Ax2& A2)
-{ pos.Mirror(A2); }
+void gp_Circ::Mirror(const gp_Ax1& A1)
+{
+  pos.Mirror(A1);
+}
 
-gp_Circ gp_Circ::Mirrored (const gp_Ax2& A2) const
+gp_Circ gp_Circ::Mirrored(const gp_Ax1& A1) const
 {
   gp_Circ C = *this;
-  C.pos.Mirror (A2);
-  return C; 
+  C.pos.Mirror(A1);
+  return C;
 }
 
+void gp_Circ::Mirror(const gp_Ax2& A2)
+{
+  pos.Mirror(A2);
+}
+
+gp_Circ gp_Circ::Mirrored(const gp_Ax2& A2) const
+{
+  gp_Circ C = *this;
+  C.pos.Mirror(A2);
+  return C;
+}
