@@ -20,33 +20,38 @@
 #include <gp_Ax2.hxx>
 #include <gp_Pnt.hxx>
 
-void gp_Parab::Mirror (const gp_Pnt& P)
-{ pos.Mirror (P); }
-
-gp_Parab gp_Parab::Mirrored (const gp_Pnt& P) const
+void gp_Parab::Mirror(const gp_Pnt& P)
 {
-  gp_Parab Prb = *this;
-  Prb.pos.Mirror (P);
-  return Prb;     
+  pos.Mirror(P);
 }
 
-void gp_Parab::Mirror (const gp_Ax1& A1)
-{ pos.Mirror (A1); }
-
-gp_Parab gp_Parab::Mirrored (const gp_Ax1& A1) const
+gp_Parab gp_Parab::Mirrored(const gp_Pnt& P) const
 {
   gp_Parab Prb = *this;
-  Prb.pos.Mirror (A1);
-  return Prb;     
+  Prb.pos.Mirror(P);
+  return Prb;
 }
 
-void gp_Parab::Mirror (const gp_Ax2& A2)
-{ pos.Mirror (A2); }
+void gp_Parab::Mirror(const gp_Ax1& A1)
+{
+  pos.Mirror(A1);
+}
 
-gp_Parab gp_Parab::Mirrored (const gp_Ax2& A2) const
+gp_Parab gp_Parab::Mirrored(const gp_Ax1& A1) const
 {
   gp_Parab Prb = *this;
-  Prb.pos.Mirror (A2);
-  return Prb;     
+  Prb.pos.Mirror(A1);
+  return Prb;
 }
 
+void gp_Parab::Mirror(const gp_Ax2& A2)
+{
+  pos.Mirror(A2);
+}
+
+gp_Parab gp_Parab::Mirrored(const gp_Ax2& A2) const
+{
+  gp_Parab Prb = *this;
+  Prb.pos.Mirror(A2);
+  return Prb;
+}
