@@ -12,21 +12,14 @@
 // Alternatively, this file may be used under the terms of Open CASCADE
 // commercial license or contractual agreement.
 
-
 #include <math_FunctionSet.hxx>
 
-//=======================================================================
-//function : ~math_FunctionSet
-//purpose  : Destructor
-//=======================================================================
-math_FunctionSet::~math_FunctionSet()
-{
-}
+//=================================================================================================
+
+math_FunctionSet::~math_FunctionSet() {}
+
+//=================================================================================================
 
-//=======================================================================
-//function : GetStateNumber
-//purpose  : 
-//=======================================================================
 Standard_Integer math_FunctionSet::GetStateNumber()
 {
   return 0;
